# Generated from PBXProj.g4 by ANTLR 4.13.1
# encoding: utf-8
from antlr4 import *
from io import StringIO
import sys
if sys.version_info[1] > 5:
	from typing import TextIO
else:
	from typing.io import TextIO

def serializedATN():
    return [
        4,1,164,2058,2,0,7,0,2,1,7,1,2,2,7,2,2,3,7,3,2,4,7,4,2,5,7,5,2,6,
        7,6,2,7,7,7,2,8,7,8,2,9,7,9,2,10,7,10,2,11,7,11,2,12,7,12,2,13,7,
        13,2,14,7,14,2,15,7,15,2,16,7,16,2,17,7,17,2,18,7,18,2,19,7,19,2,
        20,7,20,2,21,7,21,2,22,7,22,2,23,7,23,2,24,7,24,2,25,7,25,2,26,7,
        26,2,27,7,27,2,28,7,28,2,29,7,29,2,30,7,30,2,31,7,31,2,32,7,32,2,
        33,7,33,2,34,7,34,2,35,7,35,2,36,7,36,2,37,7,37,2,38,7,38,2,39,7,
        39,2,40,7,40,2,41,7,41,2,42,7,42,2,43,7,43,2,44,7,44,2,45,7,45,2,
        46,7,46,2,47,7,47,2,48,7,48,2,49,7,49,2,50,7,50,2,51,7,51,2,52,7,
        52,2,53,7,53,2,54,7,54,2,55,7,55,2,56,7,56,2,57,7,57,2,58,7,58,2,
        59,7,59,2,60,7,60,2,61,7,61,2,62,7,62,2,63,7,63,2,64,7,64,2,65,7,
        65,2,66,7,66,2,67,7,67,2,68,7,68,2,69,7,69,2,70,7,70,2,71,7,71,2,
        72,7,72,2,73,7,73,2,74,7,74,2,75,7,75,2,76,7,76,2,77,7,77,2,78,7,
        78,2,79,7,79,2,80,7,80,2,81,7,81,2,82,7,82,2,83,7,83,2,84,7,84,2,
        85,7,85,2,86,7,86,2,87,7,87,2,88,7,88,2,89,7,89,2,90,7,90,2,91,7,
        91,2,92,7,92,2,93,7,93,2,94,7,94,2,95,7,95,2,96,7,96,2,97,7,97,2,
        98,7,98,2,99,7,99,2,100,7,100,2,101,7,101,2,102,7,102,2,103,7,103,
        2,104,7,104,2,105,7,105,2,106,7,106,2,107,7,107,2,108,7,108,2,109,
        7,109,2,110,7,110,2,111,7,111,2,112,7,112,2,113,7,113,2,114,7,114,
        2,115,7,115,2,116,7,116,2,117,7,117,2,118,7,118,2,119,7,119,2,120,
        7,120,2,121,7,121,2,122,7,122,2,123,7,123,2,124,7,124,2,125,7,125,
        2,126,7,126,2,127,7,127,2,128,7,128,2,129,7,129,2,130,7,130,2,131,
        7,131,2,132,7,132,2,133,7,133,2,134,7,134,2,135,7,135,2,136,7,136,
        2,137,7,137,2,138,7,138,2,139,7,139,2,140,7,140,2,141,7,141,2,142,
        7,142,2,143,7,143,2,144,7,144,2,145,7,145,2,146,7,146,2,147,7,147,
        2,148,7,148,2,149,7,149,2,150,7,150,2,151,7,151,2,152,7,152,2,153,
        7,153,2,154,7,154,2,155,7,155,2,156,7,156,2,157,7,157,2,158,7,158,
        2,159,7,159,2,160,7,160,2,161,7,161,2,162,7,162,2,163,7,163,2,164,
        7,164,2,165,7,165,2,166,7,166,2,167,7,167,2,168,7,168,2,169,7,169,
        2,170,7,170,2,171,7,171,2,172,7,172,2,173,7,173,2,174,7,174,2,175,
        7,175,2,176,7,176,2,177,7,177,2,178,7,178,2,179,7,179,2,180,7,180,
        2,181,7,181,2,182,7,182,2,183,7,183,2,184,7,184,2,185,7,185,2,186,
        7,186,2,187,7,187,2,188,7,188,2,189,7,189,2,190,7,190,2,191,7,191,
        2,192,7,192,2,193,7,193,2,194,7,194,2,195,7,195,2,196,7,196,2,197,
        7,197,2,198,7,198,2,199,7,199,2,200,7,200,2,201,7,201,2,202,7,202,
        2,203,7,203,2,204,7,204,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
        1,2,1,2,1,2,1,2,1,2,1,3,1,3,1,3,1,3,1,3,1,3,1,4,1,4,1,4,1,4,1,4,
        1,5,1,5,1,5,1,5,3,5,441,8,5,1,5,3,5,444,8,5,1,5,3,5,447,8,5,1,5,
        3,5,450,8,5,1,5,3,5,453,8,5,1,5,3,5,456,8,5,1,5,3,5,459,8,5,1,5,
        3,5,462,8,5,1,5,3,5,465,8,5,1,5,3,5,468,8,5,1,5,1,5,3,5,472,8,5,
        1,5,3,5,475,8,5,1,5,3,5,478,8,5,1,5,1,5,3,5,482,8,5,1,5,3,5,485,
        8,5,1,5,3,5,488,8,5,1,5,3,5,491,8,5,1,5,3,5,494,8,5,1,5,3,5,497,
        8,5,1,5,3,5,500,8,5,1,5,1,5,1,5,3,5,505,8,5,1,5,3,5,508,8,5,1,5,
        3,5,511,8,5,1,5,1,5,1,5,1,6,1,6,1,6,1,6,1,6,1,7,4,7,522,8,7,11,7,
        12,7,523,1,8,4,8,527,8,8,11,8,12,8,528,1,9,4,9,532,8,9,11,9,12,9,
        533,1,10,4,10,537,8,10,11,10,12,10,538,1,11,4,11,542,8,11,11,11,
        12,11,543,1,12,4,12,547,8,12,11,12,12,12,548,1,13,4,13,552,8,13,
        11,13,12,13,553,1,14,4,14,557,8,14,11,14,12,14,558,1,15,4,15,562,
        8,15,11,15,12,15,563,1,16,4,16,567,8,16,11,16,12,16,568,1,17,4,17,
        572,8,17,11,17,12,17,573,1,18,4,18,577,8,18,11,18,12,18,578,1,19,
        4,19,582,8,19,11,19,12,19,583,1,20,4,20,587,8,20,11,20,12,20,588,
        1,21,4,21,592,8,21,11,21,12,21,593,1,22,4,22,597,8,22,11,22,12,22,
        598,1,23,4,23,602,8,23,11,23,12,23,603,1,24,4,24,607,8,24,11,24,
        12,24,608,1,25,4,25,612,8,25,11,25,12,25,613,1,26,4,26,617,8,26,
        11,26,12,26,618,1,27,4,27,622,8,27,11,27,12,27,623,1,28,4,28,627,
        8,28,11,28,12,28,628,1,29,4,29,632,8,29,11,29,12,29,633,1,30,4,30,
        637,8,30,11,30,12,30,638,1,31,4,31,642,8,31,11,31,12,31,643,1,32,
        4,32,647,8,32,11,32,12,32,648,1,33,4,33,652,8,33,11,33,12,33,653,
        1,34,1,34,1,34,1,34,1,34,1,34,1,34,3,34,663,8,34,1,34,3,34,666,8,
        34,1,34,1,34,1,34,3,34,671,8,34,1,34,1,34,1,34,1,35,1,35,1,35,1,
        35,1,35,3,35,681,8,35,1,35,3,35,684,8,35,1,35,3,35,687,8,35,1,35,
        3,35,690,8,35,1,35,3,35,693,8,35,1,35,1,35,1,35,1,36,1,36,1,36,1,
        36,1,36,1,36,3,36,704,8,36,1,36,1,36,1,36,1,36,1,36,3,36,711,8,36,
        1,36,3,36,714,8,36,1,36,1,36,1,36,1,37,1,37,1,37,1,37,1,37,3,37,
        724,8,37,1,37,3,37,727,8,37,1,37,1,37,1,37,1,38,1,38,1,38,1,38,1,
        38,1,38,1,38,1,38,1,38,1,38,1,38,1,39,1,39,1,39,1,39,1,39,1,39,3,
        39,749,8,39,1,39,1,39,3,39,753,8,39,1,39,3,39,756,8,39,1,39,1,39,
        1,39,1,39,1,40,1,40,1,40,1,40,1,40,3,40,767,8,40,1,40,3,40,770,8,
        40,1,40,3,40,773,8,40,1,40,3,40,776,8,40,1,40,3,40,779,8,40,1,40,
        3,40,782,8,40,1,40,3,40,785,8,40,1,40,3,40,788,8,40,1,40,3,40,791,
        8,40,1,40,3,40,794,8,40,1,40,3,40,797,8,40,1,40,3,40,800,8,40,1,
        40,3,40,803,8,40,1,40,3,40,806,8,40,1,40,3,40,809,8,40,1,40,3,40,
        812,8,40,1,40,3,40,815,8,40,1,40,1,40,1,40,1,41,1,41,1,41,1,41,1,
        41,1,41,1,41,1,41,1,41,1,42,1,42,1,42,1,42,1,42,1,42,1,42,1,42,1,
        42,1,42,1,42,1,42,1,43,1,43,1,43,1,43,1,43,1,43,1,43,1,43,1,43,1,
        43,1,44,1,44,1,44,1,44,1,44,1,44,3,44,857,8,44,1,44,3,44,860,8,44,
        1,44,3,44,863,8,44,1,44,3,44,866,8,44,1,44,3,44,869,8,44,1,44,1,
        44,3,44,873,8,44,1,44,3,44,876,8,44,1,44,3,44,879,8,44,1,44,1,44,
        1,44,1,45,1,45,1,45,1,45,1,45,1,45,1,45,1,45,1,45,1,45,1,46,1,46,
        1,46,1,46,1,46,1,46,1,46,1,46,3,46,902,8,46,1,46,3,46,905,8,46,1,
        46,1,46,1,46,3,46,910,8,46,1,46,3,46,913,8,46,1,46,1,46,3,46,917,
        8,46,1,46,1,46,1,46,1,46,1,47,1,47,1,47,1,47,1,47,1,47,1,47,1,47,
        1,47,1,47,1,47,1,47,1,47,1,47,1,47,1,47,1,48,1,48,1,48,1,48,1,48,
        3,48,944,8,48,1,48,1,48,3,48,948,8,48,1,48,3,48,951,8,48,1,48,3,
        48,954,8,48,1,48,3,48,957,8,48,1,48,1,48,3,48,961,8,48,1,48,1,48,
        3,48,965,8,48,1,48,3,48,968,8,48,1,48,3,48,971,8,48,1,48,1,48,3,
        48,975,8,48,1,48,3,48,978,8,48,1,48,1,48,1,48,1,48,1,49,1,49,1,49,
        1,49,1,49,1,49,3,49,990,8,49,1,49,1,49,1,49,1,49,1,49,1,49,1,50,
        1,50,1,50,1,50,1,50,1,50,1,50,1,50,1,50,1,50,1,51,1,51,1,51,1,51,
        1,51,3,51,1013,8,51,1,51,1,51,1,51,3,51,1018,8,51,1,51,3,51,1021,
        8,51,1,51,3,51,1024,8,51,1,51,3,51,1027,8,51,1,51,3,51,1030,8,51,
        1,51,1,51,1,51,1,51,3,51,1036,8,51,1,51,1,51,1,51,1,52,1,52,1,52,
        1,52,1,52,1,52,1,52,1,52,1,52,1,52,1,52,1,52,1,52,1,52,1,52,1,52,
        1,52,1,53,1,53,1,53,1,53,1,53,1,53,1,53,1,53,1,53,1,53,1,54,1,54,
        1,54,1,54,1,54,3,54,1073,8,54,1,54,3,54,1076,8,54,1,54,3,54,1079,
        8,54,1,54,3,54,1082,8,54,1,54,3,54,1085,8,54,1,54,3,54,1088,8,54,
        1,54,1,54,1,54,1,55,1,55,1,55,1,55,1,55,1,55,1,55,3,55,1100,8,55,
        1,55,1,55,1,55,1,55,1,56,1,56,1,56,1,56,1,56,3,56,1111,8,56,1,56,
        1,56,1,56,1,56,1,56,1,57,1,57,1,57,1,57,1,57,1,57,1,57,3,57,1125,
        8,57,1,57,1,57,1,57,1,58,1,58,1,58,1,58,1,58,1,58,1,58,1,58,1,58,
        1,59,1,59,1,59,1,59,1,59,3,59,1144,8,59,1,59,1,59,1,59,1,59,1,60,
        1,60,1,60,1,60,1,60,1,60,1,60,3,60,1157,8,60,1,60,1,60,1,60,1,60,
        1,60,1,60,1,61,1,61,1,61,1,61,1,61,1,62,1,62,1,62,1,62,1,62,1,63,
        1,63,1,63,1,63,1,63,1,64,1,64,1,64,1,64,1,64,1,65,1,65,1,65,1,65,
        1,65,1,66,1,66,1,66,1,66,1,66,1,67,1,67,1,67,1,67,1,67,1,68,1,68,
        1,68,1,68,1,68,1,69,1,69,1,69,1,69,1,69,1,70,1,70,1,70,1,70,1,70,
        1,71,1,71,1,71,1,71,1,71,1,72,1,72,1,72,1,72,1,72,1,73,1,73,1,73,
        1,73,1,73,1,74,1,74,1,74,1,74,1,74,1,75,1,75,1,75,1,75,1,75,1,76,
        1,76,1,76,1,76,1,76,1,77,1,77,1,77,1,77,1,77,1,78,1,78,1,78,1,78,
        1,78,1,79,1,79,1,79,1,79,1,79,1,80,1,80,1,80,1,80,1,80,1,81,1,81,
        1,81,1,81,1,81,1,82,1,82,1,82,1,82,1,82,1,83,1,83,1,83,1,83,1,83,
        1,84,1,84,1,84,1,84,1,84,1,85,1,85,1,85,1,85,1,85,1,86,1,86,1,86,
        1,86,1,86,1,87,1,87,1,87,1,87,1,87,1,88,1,88,1,88,1,88,1,88,1,89,
        1,89,1,89,1,89,1,89,1,90,1,90,1,90,1,90,1,90,1,91,1,91,1,91,1,91,
        1,91,1,92,1,92,1,92,1,92,1,92,1,93,1,93,1,93,1,93,1,93,1,94,1,94,
        1,94,1,94,1,94,1,95,1,95,1,95,1,95,1,95,1,96,1,96,1,96,1,96,1,96,
        1,97,1,97,1,97,1,97,1,97,1,98,1,98,1,98,1,98,5,98,1354,8,98,10,98,
        12,98,1357,9,98,1,98,1,98,1,98,1,99,1,99,1,99,1,99,1,99,1,100,1,
        100,1,100,1,100,1,100,1,101,1,101,1,101,1,101,1,101,1,102,1,102,
        1,102,1,102,1,102,1,103,1,103,1,103,1,103,1,103,1,104,1,104,1,104,
        1,104,1,104,1,105,1,105,1,105,1,105,1,105,1,106,1,106,1,106,1,106,
        1,106,1,107,1,107,1,107,1,107,1,107,1,108,1,108,1,108,1,108,1,108,
        1,109,1,109,1,109,1,109,1,109,1,110,1,110,1,110,1,110,1,110,1,111,
        1,111,1,111,1,111,5,111,1426,8,111,10,111,12,111,1429,9,111,1,111,
        1,111,1,111,1,112,1,112,1,112,1,112,1,112,1,113,1,113,1,113,1,113,
        1,113,1,114,1,114,1,114,1,114,1,114,1,115,1,115,1,115,1,115,1,115,
        1,116,1,116,1,116,1,116,1,116,1,117,1,117,1,117,1,117,1,117,1,118,
        1,118,1,118,1,118,1,118,1,119,1,119,1,119,1,119,1,119,1,120,1,120,
        1,120,5,120,1477,8,120,10,120,12,120,1480,9,120,1,120,1,120,1,121,
        1,121,1,121,1,121,1,121,1,121,5,121,1490,8,121,10,121,12,121,1493,
        9,121,1,121,3,121,1496,8,121,1,121,1,121,3,121,1500,8,121,1,122,
        1,122,1,122,5,122,1505,8,122,10,122,12,122,1508,9,122,1,122,1,122,
        1,123,1,123,1,123,1,123,1,123,1,124,1,124,1,124,1,124,1,124,1,125,
        1,125,1,125,1,125,1,125,1,126,1,126,1,126,1,126,1,126,1,127,1,127,
        1,127,1,127,1,127,1,128,1,128,1,128,1,128,1,128,1,129,1,129,1,129,
        1,129,1,129,1,130,1,130,1,130,1,130,1,130,1,131,1,131,1,131,1,131,
        1,131,1,132,1,132,1,132,1,132,1,132,1,133,1,133,1,133,1,133,1,133,
        1,134,1,134,1,134,1,134,1,134,1,135,1,135,1,135,1,135,1,135,1,136,
        1,136,1,136,1,136,1,136,1,137,1,137,1,137,1,137,1,137,1,138,1,138,
        1,138,1,138,1,138,1,139,1,139,1,139,1,139,1,139,1,140,1,140,1,140,
        1,140,1,140,1,141,1,141,1,141,1,141,1,141,1,142,1,142,1,142,1,142,
        1,142,1,143,1,143,1,143,1,143,1,143,1,144,1,144,1,144,1,144,1,144,
        1,145,1,145,1,145,1,145,3,145,1626,8,145,1,145,3,145,1629,8,145,
        1,145,3,145,1632,8,145,1,145,3,145,1635,8,145,1,145,3,145,1638,8,
        145,1,145,3,145,1641,8,145,1,145,3,145,1644,8,145,1,145,3,145,1647,
        8,145,1,145,3,145,1650,8,145,1,145,1,145,1,145,1,146,1,146,1,146,
        1,146,1,146,1,147,1,147,1,147,1,147,1,147,1,148,1,148,1,148,1,148,
        1,148,1,149,1,149,1,149,1,149,1,149,1,150,1,150,1,150,1,150,1,150,
        1,151,1,151,1,151,1,151,1,151,1,152,1,152,1,152,1,152,1,152,1,153,
        1,153,1,153,1,153,5,153,1694,8,153,10,153,12,153,1697,9,153,1,153,
        1,153,1,153,1,154,1,154,1,154,1,154,3,154,1706,8,154,1,154,3,154,
        1709,8,154,1,154,3,154,1712,8,154,1,154,3,154,1715,8,154,1,154,3,
        154,1718,8,154,1,154,3,154,1721,8,154,1,154,3,154,1724,8,154,1,154,
        3,154,1727,8,154,1,154,1,154,1,154,1,155,1,155,1,155,1,155,1,155,
        1,156,1,156,1,156,1,156,1,156,1,157,1,157,1,157,1,157,1,157,1,158,
        1,158,1,158,1,158,1,158,1,159,1,159,1,159,1,159,1,159,1,160,1,160,
        1,160,1,160,1,160,1,161,1,161,1,161,1,161,1,161,1,162,1,162,1,162,
        1,162,1,162,1,163,1,163,1,163,1,163,1,163,1,164,1,164,1,164,1,164,
        1,164,1,165,1,165,1,165,1,165,1,165,1,166,1,166,1,166,1,166,1,166,
        1,167,1,167,1,167,1,167,1,167,1,168,1,168,1,168,1,168,1,168,1,169,
        1,169,1,169,1,169,1,169,1,169,1,169,1,169,1,169,1,169,1,169,1,169,
        3,169,1814,8,169,1,170,1,170,1,170,1,170,1,170,1,171,1,171,1,171,
        1,171,1,171,1,172,1,172,1,172,1,172,1,172,1,173,1,173,1,173,1,173,
        1,173,1,174,1,174,1,174,1,174,1,174,1,175,1,175,1,175,1,175,1,175,
        1,176,1,176,1,176,1,176,1,176,1,177,1,177,1,177,1,177,1,177,1,178,
        1,178,1,178,1,178,1,178,1,179,1,179,1,179,1,179,1,179,1,180,1,180,
        1,180,1,180,1,180,1,181,1,181,1,181,1,181,1,181,1,182,1,182,1,182,
        1,182,1,182,1,183,1,183,1,183,1,183,1,183,1,184,1,184,1,184,1,184,
        1,184,1,185,1,185,1,185,1,185,5,185,1895,8,185,10,185,12,185,1898,
        9,185,1,185,1,185,1,185,1,186,1,186,1,186,1,186,1,186,1,187,1,187,
        1,187,1,187,1,187,1,188,1,188,1,188,1,188,1,188,1,189,5,189,1919,
        8,189,10,189,12,189,1922,9,189,1,190,1,190,1,190,1,190,1,190,1,190,
        1,190,1,190,1,190,1,190,1,190,1,190,1,191,1,191,1,191,1,191,1,191,
        1,192,1,192,1,192,1,192,1,192,1,193,1,193,1,193,1,193,1,193,1,193,
        1,193,1,193,1,193,1,193,1,193,1,193,1,193,1,193,1,193,1,193,1,193,
        1,193,1,193,1,193,1,193,1,193,1,193,1,193,1,193,1,193,3,193,1972,
        8,193,1,193,1,193,5,193,1976,8,193,10,193,12,193,1979,9,193,1,193,
        3,193,1982,8,193,1,193,1,193,1,193,3,193,1987,8,193,1,194,1,194,
        1,194,1,194,1,194,1,195,1,195,1,195,1,195,1,195,1,196,1,196,1,196,
        1,196,1,196,1,197,1,197,1,197,1,197,5,197,2008,8,197,10,197,12,197,
        2011,9,197,1,197,1,197,1,197,1,198,1,198,1,198,1,198,5,198,2020,
        8,198,10,198,12,198,2023,9,198,1,198,1,198,1,198,1,199,1,199,1,199,
        1,199,1,199,1,200,1,200,1,200,1,200,1,200,1,201,1,201,1,201,1,201,
        1,201,1,202,1,202,1,202,1,202,1,202,1,202,3,202,2049,8,202,1,203,
        1,203,1,203,3,203,2054,8,203,1,204,1,204,1,204,0,0,205,0,2,4,6,8,
        10,12,14,16,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,48,50,52,
        54,56,58,60,62,64,66,68,70,72,74,76,78,80,82,84,86,88,90,92,94,96,
        98,100,102,104,106,108,110,112,114,116,118,120,122,124,126,128,130,
        132,134,136,138,140,142,144,146,148,150,152,154,156,158,160,162,
        164,166,168,170,172,174,176,178,180,182,184,186,188,190,192,194,
        196,198,200,202,204,206,208,210,212,214,216,218,220,222,224,226,
        228,230,232,234,236,238,240,242,244,246,248,250,252,254,256,258,
        260,262,264,266,268,270,272,274,276,278,280,282,284,286,288,290,
        292,294,296,298,300,302,304,306,308,310,312,314,316,318,320,322,
        324,326,328,330,332,334,336,338,340,342,344,346,348,350,352,354,
        356,358,360,362,364,366,368,370,372,374,376,378,380,382,384,386,
        388,390,392,394,396,398,400,402,404,406,408,0,2,2,0,13,13,158,158,
        8,0,8,9,12,12,14,16,20,29,32,37,39,46,48,140,142,155,2022,0,410,
        1,0,0,0,2,412,1,0,0,0,4,420,1,0,0,0,6,425,1,0,0,0,8,431,1,0,0,0,
        10,436,1,0,0,0,12,515,1,0,0,0,14,521,1,0,0,0,16,526,1,0,0,0,18,531,
        1,0,0,0,20,536,1,0,0,0,22,541,1,0,0,0,24,546,1,0,0,0,26,551,1,0,
        0,0,28,556,1,0,0,0,30,561,1,0,0,0,32,566,1,0,0,0,34,571,1,0,0,0,
        36,576,1,0,0,0,38,581,1,0,0,0,40,586,1,0,0,0,42,591,1,0,0,0,44,596,
        1,0,0,0,46,601,1,0,0,0,48,606,1,0,0,0,50,611,1,0,0,0,52,616,1,0,
        0,0,54,621,1,0,0,0,56,626,1,0,0,0,58,631,1,0,0,0,60,636,1,0,0,0,
        62,641,1,0,0,0,64,646,1,0,0,0,66,651,1,0,0,0,68,655,1,0,0,0,70,675,
        1,0,0,0,72,697,1,0,0,0,74,718,1,0,0,0,76,731,1,0,0,0,78,742,1,0,
        0,0,80,761,1,0,0,0,82,819,1,0,0,0,84,828,1,0,0,0,86,840,1,0,0,0,
        88,850,1,0,0,0,90,883,1,0,0,0,92,893,1,0,0,0,94,922,1,0,0,0,96,938,
        1,0,0,0,98,983,1,0,0,0,100,997,1,0,0,0,102,1007,1,0,0,0,104,1040,
        1,0,0,0,106,1057,1,0,0,0,108,1067,1,0,0,0,110,1092,1,0,0,0,112,1105,
        1,0,0,0,114,1117,1,0,0,0,116,1129,1,0,0,0,118,1138,1,0,0,0,120,1149,
        1,0,0,0,122,1164,1,0,0,0,124,1169,1,0,0,0,126,1174,1,0,0,0,128,1179,
        1,0,0,0,130,1184,1,0,0,0,132,1189,1,0,0,0,134,1194,1,0,0,0,136,1199,
        1,0,0,0,138,1204,1,0,0,0,140,1209,1,0,0,0,142,1214,1,0,0,0,144,1219,
        1,0,0,0,146,1224,1,0,0,0,148,1229,1,0,0,0,150,1234,1,0,0,0,152,1239,
        1,0,0,0,154,1244,1,0,0,0,156,1249,1,0,0,0,158,1254,1,0,0,0,160,1259,
        1,0,0,0,162,1264,1,0,0,0,164,1269,1,0,0,0,166,1274,1,0,0,0,168,1279,
        1,0,0,0,170,1284,1,0,0,0,172,1289,1,0,0,0,174,1294,1,0,0,0,176,1299,
        1,0,0,0,178,1304,1,0,0,0,180,1309,1,0,0,0,182,1314,1,0,0,0,184,1319,
        1,0,0,0,186,1324,1,0,0,0,188,1329,1,0,0,0,190,1334,1,0,0,0,192,1339,
        1,0,0,0,194,1344,1,0,0,0,196,1349,1,0,0,0,198,1361,1,0,0,0,200,1366,
        1,0,0,0,202,1371,1,0,0,0,204,1376,1,0,0,0,206,1381,1,0,0,0,208,1386,
        1,0,0,0,210,1391,1,0,0,0,212,1396,1,0,0,0,214,1401,1,0,0,0,216,1406,
        1,0,0,0,218,1411,1,0,0,0,220,1416,1,0,0,0,222,1421,1,0,0,0,224,1433,
        1,0,0,0,226,1438,1,0,0,0,228,1443,1,0,0,0,230,1448,1,0,0,0,232,1453,
        1,0,0,0,234,1458,1,0,0,0,236,1463,1,0,0,0,238,1468,1,0,0,0,240,1473,
        1,0,0,0,242,1499,1,0,0,0,244,1501,1,0,0,0,246,1511,1,0,0,0,248,1516,
        1,0,0,0,250,1521,1,0,0,0,252,1526,1,0,0,0,254,1531,1,0,0,0,256,1536,
        1,0,0,0,258,1541,1,0,0,0,260,1546,1,0,0,0,262,1551,1,0,0,0,264,1556,
        1,0,0,0,266,1561,1,0,0,0,268,1566,1,0,0,0,270,1571,1,0,0,0,272,1576,
        1,0,0,0,274,1581,1,0,0,0,276,1586,1,0,0,0,278,1591,1,0,0,0,280,1596,
        1,0,0,0,282,1601,1,0,0,0,284,1606,1,0,0,0,286,1611,1,0,0,0,288,1616,
        1,0,0,0,290,1621,1,0,0,0,292,1654,1,0,0,0,294,1659,1,0,0,0,296,1664,
        1,0,0,0,298,1669,1,0,0,0,300,1674,1,0,0,0,302,1679,1,0,0,0,304,1684,
        1,0,0,0,306,1689,1,0,0,0,308,1701,1,0,0,0,310,1731,1,0,0,0,312,1736,
        1,0,0,0,314,1741,1,0,0,0,316,1746,1,0,0,0,318,1751,1,0,0,0,320,1756,
        1,0,0,0,322,1761,1,0,0,0,324,1766,1,0,0,0,326,1771,1,0,0,0,328,1776,
        1,0,0,0,330,1781,1,0,0,0,332,1786,1,0,0,0,334,1791,1,0,0,0,336,1796,
        1,0,0,0,338,1813,1,0,0,0,340,1815,1,0,0,0,342,1820,1,0,0,0,344,1825,
        1,0,0,0,346,1830,1,0,0,0,348,1835,1,0,0,0,350,1840,1,0,0,0,352,1845,
        1,0,0,0,354,1850,1,0,0,0,356,1855,1,0,0,0,358,1860,1,0,0,0,360,1865,
        1,0,0,0,362,1870,1,0,0,0,364,1875,1,0,0,0,366,1880,1,0,0,0,368,1885,
        1,0,0,0,370,1890,1,0,0,0,372,1902,1,0,0,0,374,1907,1,0,0,0,376,1912,
        1,0,0,0,378,1920,1,0,0,0,380,1923,1,0,0,0,382,1935,1,0,0,0,384,1940,
        1,0,0,0,386,1986,1,0,0,0,388,1988,1,0,0,0,390,1993,1,0,0,0,392,1998,
        1,0,0,0,394,2003,1,0,0,0,396,2015,1,0,0,0,398,2027,1,0,0,0,400,2032,
        1,0,0,0,402,2037,1,0,0,0,404,2048,1,0,0,0,406,2053,1,0,0,0,408,2055,
        1,0,0,0,410,411,3,2,1,0,411,1,1,0,0,0,412,413,5,1,0,0,413,414,3,
        4,2,0,414,415,3,6,3,0,415,416,3,8,4,0,416,417,3,10,5,0,417,418,3,
        12,6,0,418,419,5,2,0,0,419,3,1,0,0,0,420,421,5,8,0,0,421,422,5,3,
        0,0,422,423,5,13,0,0,423,424,5,4,0,0,424,5,1,0,0,0,425,426,5,9,0,
        0,426,427,5,3,0,0,427,428,5,1,0,0,428,429,5,2,0,0,429,430,5,4,0,
        0,430,7,1,0,0,0,431,432,5,14,0,0,432,433,5,3,0,0,433,434,5,13,0,
        0,434,435,5,4,0,0,435,9,1,0,0,0,436,437,5,15,0,0,437,438,5,3,0,0,
        438,440,5,1,0,0,439,441,3,14,7,0,440,439,1,0,0,0,440,441,1,0,0,0,
        441,443,1,0,0,0,442,444,3,16,8,0,443,442,1,0,0,0,443,444,1,0,0,0,
        444,446,1,0,0,0,445,447,3,18,9,0,446,445,1,0,0,0,446,447,1,0,0,0,
        447,449,1,0,0,0,448,450,3,20,10,0,449,448,1,0,0,0,449,450,1,0,0,
        0,450,452,1,0,0,0,451,453,3,22,11,0,452,451,1,0,0,0,452,453,1,0,
        0,0,453,455,1,0,0,0,454,456,3,24,12,0,455,454,1,0,0,0,455,456,1,
        0,0,0,456,458,1,0,0,0,457,459,3,26,13,0,458,457,1,0,0,0,458,459,
        1,0,0,0,459,461,1,0,0,0,460,462,3,28,14,0,461,460,1,0,0,0,461,462,
        1,0,0,0,462,464,1,0,0,0,463,465,3,30,15,0,464,463,1,0,0,0,464,465,
        1,0,0,0,465,467,1,0,0,0,466,468,3,32,16,0,467,466,1,0,0,0,467,468,
        1,0,0,0,468,469,1,0,0,0,469,471,3,34,17,0,470,472,3,36,18,0,471,
        470,1,0,0,0,471,472,1,0,0,0,472,474,1,0,0,0,473,475,3,40,20,0,474,
        473,1,0,0,0,474,475,1,0,0,0,475,477,1,0,0,0,476,478,3,38,19,0,477,
        476,1,0,0,0,477,478,1,0,0,0,478,479,1,0,0,0,479,481,3,42,21,0,480,
        482,3,44,22,0,481,480,1,0,0,0,481,482,1,0,0,0,482,484,1,0,0,0,483,
        485,3,46,23,0,484,483,1,0,0,0,484,485,1,0,0,0,485,487,1,0,0,0,486,
        488,3,48,24,0,487,486,1,0,0,0,487,488,1,0,0,0,488,490,1,0,0,0,489,
        491,3,50,25,0,490,489,1,0,0,0,490,491,1,0,0,0,491,493,1,0,0,0,492,
        494,3,52,26,0,493,492,1,0,0,0,493,494,1,0,0,0,494,496,1,0,0,0,495,
        497,3,54,27,0,496,495,1,0,0,0,496,497,1,0,0,0,497,499,1,0,0,0,498,
        500,3,56,28,0,499,498,1,0,0,0,499,500,1,0,0,0,500,501,1,0,0,0,501,
        502,3,58,29,0,502,504,3,60,30,0,503,505,3,62,31,0,504,503,1,0,0,
        0,504,505,1,0,0,0,505,507,1,0,0,0,506,508,3,64,32,0,507,506,1,0,
        0,0,507,508,1,0,0,0,508,510,1,0,0,0,509,511,3,66,33,0,510,509,1,
        0,0,0,510,511,1,0,0,0,511,512,1,0,0,0,512,513,5,2,0,0,513,514,5,
        4,0,0,514,11,1,0,0,0,515,516,5,16,0,0,516,517,5,3,0,0,517,518,5,
        156,0,0,518,519,5,4,0,0,519,13,1,0,0,0,520,522,3,68,34,0,521,520,
        1,0,0,0,522,523,1,0,0,0,523,521,1,0,0,0,523,524,1,0,0,0,524,15,1,
        0,0,0,525,527,3,70,35,0,526,525,1,0,0,0,527,528,1,0,0,0,528,526,
        1,0,0,0,528,529,1,0,0,0,529,17,1,0,0,0,530,532,3,72,36,0,531,530,
        1,0,0,0,532,533,1,0,0,0,533,531,1,0,0,0,533,534,1,0,0,0,534,19,1,
        0,0,0,535,537,3,74,37,0,536,535,1,0,0,0,537,538,1,0,0,0,538,536,
        1,0,0,0,538,539,1,0,0,0,539,21,1,0,0,0,540,542,3,76,38,0,541,540,
        1,0,0,0,542,543,1,0,0,0,543,541,1,0,0,0,543,544,1,0,0,0,544,23,1,
        0,0,0,545,547,3,78,39,0,546,545,1,0,0,0,547,548,1,0,0,0,548,546,
        1,0,0,0,548,549,1,0,0,0,549,25,1,0,0,0,550,552,3,80,40,0,551,550,
        1,0,0,0,552,553,1,0,0,0,553,551,1,0,0,0,553,554,1,0,0,0,554,27,1,
        0,0,0,555,557,3,82,41,0,556,555,1,0,0,0,557,558,1,0,0,0,558,556,
        1,0,0,0,558,559,1,0,0,0,559,29,1,0,0,0,560,562,3,84,42,0,561,560,
        1,0,0,0,562,563,1,0,0,0,563,561,1,0,0,0,563,564,1,0,0,0,564,31,1,
        0,0,0,565,567,3,86,43,0,566,565,1,0,0,0,567,568,1,0,0,0,568,566,
        1,0,0,0,568,569,1,0,0,0,569,33,1,0,0,0,570,572,3,88,44,0,571,570,
        1,0,0,0,572,573,1,0,0,0,573,571,1,0,0,0,573,574,1,0,0,0,574,35,1,
        0,0,0,575,577,3,90,45,0,576,575,1,0,0,0,577,578,1,0,0,0,578,576,
        1,0,0,0,578,579,1,0,0,0,579,37,1,0,0,0,580,582,3,92,46,0,581,580,
        1,0,0,0,582,583,1,0,0,0,583,581,1,0,0,0,583,584,1,0,0,0,584,39,1,
        0,0,0,585,587,3,94,47,0,586,585,1,0,0,0,587,588,1,0,0,0,588,586,
        1,0,0,0,588,589,1,0,0,0,589,41,1,0,0,0,590,592,3,96,48,0,591,590,
        1,0,0,0,592,593,1,0,0,0,593,591,1,0,0,0,593,594,1,0,0,0,594,43,1,
        0,0,0,595,597,3,98,49,0,596,595,1,0,0,0,597,598,1,0,0,0,598,596,
        1,0,0,0,598,599,1,0,0,0,599,45,1,0,0,0,600,602,3,100,50,0,601,600,
        1,0,0,0,602,603,1,0,0,0,603,601,1,0,0,0,603,604,1,0,0,0,604,47,1,
        0,0,0,605,607,3,102,51,0,606,605,1,0,0,0,607,608,1,0,0,0,608,606,
        1,0,0,0,608,609,1,0,0,0,609,49,1,0,0,0,610,612,3,104,52,0,611,610,
        1,0,0,0,612,613,1,0,0,0,613,611,1,0,0,0,613,614,1,0,0,0,614,51,1,
        0,0,0,615,617,3,106,53,0,616,615,1,0,0,0,617,618,1,0,0,0,618,616,
        1,0,0,0,618,619,1,0,0,0,619,53,1,0,0,0,620,622,3,108,54,0,621,620,
        1,0,0,0,622,623,1,0,0,0,623,621,1,0,0,0,623,624,1,0,0,0,624,55,1,
        0,0,0,625,627,3,110,55,0,626,625,1,0,0,0,627,628,1,0,0,0,628,626,
        1,0,0,0,628,629,1,0,0,0,629,57,1,0,0,0,630,632,3,112,56,0,631,630,
        1,0,0,0,632,633,1,0,0,0,633,631,1,0,0,0,633,634,1,0,0,0,634,59,1,
        0,0,0,635,637,3,114,57,0,636,635,1,0,0,0,637,638,1,0,0,0,638,636,
        1,0,0,0,638,639,1,0,0,0,639,61,1,0,0,0,640,642,3,116,58,0,641,640,
        1,0,0,0,642,643,1,0,0,0,643,641,1,0,0,0,643,644,1,0,0,0,644,63,1,
        0,0,0,645,647,3,118,59,0,646,645,1,0,0,0,647,648,1,0,0,0,648,646,
        1,0,0,0,648,649,1,0,0,0,649,65,1,0,0,0,650,652,3,120,60,0,651,650,
        1,0,0,0,652,653,1,0,0,0,653,651,1,0,0,0,653,654,1,0,0,0,654,67,1,
        0,0,0,655,656,5,156,0,0,656,657,5,3,0,0,657,658,5,1,0,0,658,659,
        3,122,61,0,659,660,3,246,123,0,660,662,3,248,124,0,661,663,3,370,
        185,0,662,661,1,0,0,0,662,663,1,0,0,0,663,665,1,0,0,0,664,666,3,
        192,96,0,665,664,1,0,0,0,665,666,1,0,0,0,666,667,1,0,0,0,667,668,
        3,260,130,0,668,670,3,228,114,0,669,671,3,262,131,0,670,669,1,0,
        0,0,670,671,1,0,0,0,671,672,1,0,0,0,672,673,5,2,0,0,673,674,5,4,
        0,0,674,69,1,0,0,0,675,676,5,156,0,0,676,677,5,3,0,0,677,678,5,1,
        0,0,678,680,3,124,62,0,679,681,3,178,89,0,680,679,1,0,0,0,680,681,
        1,0,0,0,681,683,1,0,0,0,682,684,3,212,106,0,683,682,1,0,0,0,683,
        684,1,0,0,0,684,686,1,0,0,0,685,687,3,214,107,0,686,685,1,0,0,0,
        686,687,1,0,0,0,687,689,1,0,0,0,688,690,3,180,90,0,689,688,1,0,0,
        0,689,690,1,0,0,0,690,692,1,0,0,0,691,693,3,394,197,0,692,691,1,
        0,0,0,692,693,1,0,0,0,693,694,1,0,0,0,694,695,5,2,0,0,695,696,5,
        4,0,0,696,71,1,0,0,0,697,698,5,156,0,0,698,699,5,3,0,0,699,700,5,
        1,0,0,700,701,3,126,63,0,701,703,3,276,138,0,702,704,3,278,139,0,
        703,702,1,0,0,0,703,704,1,0,0,0,704,705,1,0,0,0,705,706,3,364,182,
        0,706,707,3,280,140,0,707,708,3,282,141,0,708,710,3,284,142,0,709,
        711,3,286,143,0,710,709,1,0,0,0,710,711,1,0,0,0,711,713,1,0,0,0,
        712,714,3,288,144,0,713,712,1,0,0,0,713,714,1,0,0,0,714,715,1,0,
        0,0,715,716,5,2,0,0,716,717,5,4,0,0,717,73,1,0,0,0,718,719,5,156,
        0,0,719,720,5,3,0,0,720,721,5,1,0,0,721,723,3,128,64,0,722,724,3,
        370,185,0,723,722,1,0,0,0,723,724,1,0,0,0,724,726,1,0,0,0,725,727,
        3,228,114,0,726,725,1,0,0,0,726,727,1,0,0,0,727,728,1,0,0,0,728,
        729,5,2,0,0,729,730,5,4,0,0,730,75,1,0,0,0,731,732,5,156,0,0,732,
        733,5,3,0,0,733,734,5,1,0,0,734,735,3,130,65,0,735,736,3,182,91,
        0,736,737,3,184,92,0,737,738,3,186,93,0,738,739,3,188,94,0,739,740,
        5,2,0,0,740,741,5,4,0,0,741,77,1,0,0,0,742,743,5,156,0,0,743,744,
        5,3,0,0,744,745,5,1,0,0,745,746,3,132,66,0,746,748,3,234,117,0,747,
        749,3,374,187,0,748,747,1,0,0,0,748,749,1,0,0,0,749,750,1,0,0,0,
        750,752,3,376,188,0,751,753,3,236,118,0,752,751,1,0,0,0,752,753,
        1,0,0,0,753,755,1,0,0,0,754,756,3,228,114,0,755,754,1,0,0,0,755,
        756,1,0,0,0,756,757,1,0,0,0,757,758,3,238,119,0,758,759,5,2,0,0,
        759,760,5,4,0,0,760,79,1,0,0,0,761,762,5,156,0,0,762,763,5,3,0,0,
        763,764,5,1,0,0,764,766,3,134,67,0,765,767,3,192,96,0,766,765,1,
        0,0,0,766,767,1,0,0,0,767,769,1,0,0,0,768,770,3,190,95,0,769,768,
        1,0,0,0,769,770,1,0,0,0,770,772,1,0,0,0,771,773,3,194,97,0,772,771,
        1,0,0,0,772,773,1,0,0,0,773,775,1,0,0,0,774,776,3,190,95,0,775,774,
        1,0,0,0,775,776,1,0,0,0,776,778,1,0,0,0,777,779,3,202,101,0,778,
        777,1,0,0,0,778,779,1,0,0,0,779,781,1,0,0,0,780,782,3,204,102,0,
        781,780,1,0,0,0,781,782,1,0,0,0,782,784,1,0,0,0,783,785,3,200,100,
        0,784,783,1,0,0,0,784,785,1,0,0,0,785,787,1,0,0,0,786,788,3,268,
        134,0,787,786,1,0,0,0,787,788,1,0,0,0,788,790,1,0,0,0,789,791,3,
        228,114,0,790,789,1,0,0,0,790,791,1,0,0,0,791,793,1,0,0,0,792,794,
        3,230,115,0,793,792,1,0,0,0,793,794,1,0,0,0,794,796,1,0,0,0,795,
        797,3,274,137,0,796,795,1,0,0,0,796,797,1,0,0,0,797,799,1,0,0,0,
        798,800,3,272,136,0,799,798,1,0,0,0,799,800,1,0,0,0,800,802,1,0,
        0,0,801,803,3,232,116,0,802,801,1,0,0,0,802,803,1,0,0,0,803,805,
        1,0,0,0,804,806,3,206,103,0,805,804,1,0,0,0,805,806,1,0,0,0,806,
        808,1,0,0,0,807,809,3,270,135,0,808,807,1,0,0,0,808,809,1,0,0,0,
        809,811,1,0,0,0,810,812,3,208,104,0,811,810,1,0,0,0,811,812,1,0,
        0,0,812,814,1,0,0,0,813,815,3,210,105,0,814,813,1,0,0,0,814,815,
        1,0,0,0,815,816,1,0,0,0,816,817,5,2,0,0,817,818,5,4,0,0,818,81,1,
        0,0,0,819,820,5,156,0,0,820,821,5,3,0,0,821,822,5,1,0,0,822,823,
        3,136,68,0,823,824,3,382,191,0,824,825,3,360,180,0,825,826,5,2,0,
        0,826,827,5,4,0,0,827,83,1,0,0,0,828,829,5,156,0,0,829,830,5,3,0,
        0,830,831,5,1,0,0,831,832,3,138,69,0,832,833,3,384,192,0,833,834,
        3,196,98,0,834,835,3,198,99,0,835,836,3,230,115,0,836,837,3,232,
        116,0,837,838,5,2,0,0,838,839,5,4,0,0,839,85,1,0,0,0,840,841,5,156,
        0,0,841,842,5,3,0,0,842,843,5,1,0,0,843,844,3,140,70,0,844,845,3,
        234,117,0,845,846,3,236,118,0,846,847,3,238,119,0,847,848,5,2,0,
        0,848,849,5,4,0,0,849,87,1,0,0,0,850,851,5,156,0,0,851,852,5,3,0,
        0,852,853,5,1,0,0,853,854,3,142,71,0,854,856,3,216,108,0,855,857,
        3,192,96,0,856,855,1,0,0,0,856,857,1,0,0,0,857,859,1,0,0,0,858,860,
        3,204,102,0,859,858,1,0,0,0,859,860,1,0,0,0,860,862,1,0,0,0,861,
        863,3,202,101,0,862,861,1,0,0,0,862,863,1,0,0,0,863,865,1,0,0,0,
        864,866,3,228,114,0,865,864,1,0,0,0,865,866,1,0,0,0,866,868,1,0,
        0,0,867,869,3,230,115,0,868,867,1,0,0,0,868,869,1,0,0,0,869,870,
        1,0,0,0,870,872,3,232,116,0,871,873,3,206,103,0,872,871,1,0,0,0,
        872,873,1,0,0,0,873,875,1,0,0,0,874,876,3,208,104,0,875,874,1,0,
        0,0,875,876,1,0,0,0,876,878,1,0,0,0,877,879,3,210,105,0,878,877,
        1,0,0,0,878,879,1,0,0,0,879,880,1,0,0,0,880,881,5,2,0,0,881,882,
        5,4,0,0,882,89,1,0,0,0,883,884,5,156,0,0,884,885,5,3,0,0,885,886,
        5,1,0,0,886,887,3,144,72,0,887,888,3,234,117,0,888,889,3,236,118,
        0,889,890,3,238,119,0,890,891,5,2,0,0,891,892,5,4,0,0,892,91,1,0,
        0,0,893,894,5,156,0,0,894,895,5,3,0,0,895,896,5,1,0,0,896,897,3,
        146,73,0,897,898,3,246,123,0,898,899,3,248,124,0,899,901,3,250,125,
        0,900,902,3,192,96,0,901,900,1,0,0,0,901,902,1,0,0,0,902,904,1,0,
        0,0,903,905,3,370,185,0,904,903,1,0,0,0,904,905,1,0,0,0,905,906,
        1,0,0,0,906,907,3,260,130,0,907,909,3,228,114,0,908,910,3,218,109,
        0,909,908,1,0,0,0,909,910,1,0,0,0,910,912,1,0,0,0,911,913,3,226,
        113,0,912,911,1,0,0,0,912,913,1,0,0,0,913,914,1,0,0,0,914,916,3,
        262,131,0,915,917,3,264,132,0,916,915,1,0,0,0,916,917,1,0,0,0,917,
        918,1,0,0,0,918,919,3,266,133,0,919,920,5,2,0,0,920,921,5,4,0,0,
        921,93,1,0,0,0,922,923,5,156,0,0,923,924,5,3,0,0,924,925,5,1,0,0,
        925,926,3,148,74,0,926,927,3,252,126,0,927,928,3,246,123,0,928,929,
        3,248,124,0,929,930,3,254,127,0,930,931,3,256,128,0,931,932,3,260,
        130,0,932,933,3,228,114,0,933,934,3,258,129,0,934,935,3,262,131,
        0,935,936,5,2,0,0,936,937,5,4,0,0,937,95,1,0,0,0,938,939,5,156,0,
        0,939,940,5,3,0,0,940,941,5,1,0,0,941,943,3,150,75,0,942,944,3,290,
        145,0,943,942,1,0,0,0,943,944,1,0,0,0,944,945,1,0,0,0,945,947,3,
        246,123,0,946,948,3,370,185,0,947,946,1,0,0,0,947,948,1,0,0,0,948,
        950,1,0,0,0,949,951,3,372,186,0,950,949,1,0,0,0,950,951,1,0,0,0,
        951,953,1,0,0,0,952,954,3,320,160,0,953,952,1,0,0,0,953,954,1,0,
        0,0,954,956,1,0,0,0,955,957,3,322,161,0,956,955,1,0,0,0,956,957,
        1,0,0,0,957,958,1,0,0,0,958,960,3,324,162,0,959,961,3,326,163,0,
        960,959,1,0,0,0,960,961,1,0,0,0,961,962,1,0,0,0,962,964,3,328,164,
        0,963,965,3,332,166,0,964,963,1,0,0,0,964,965,1,0,0,0,965,967,1,
        0,0,0,966,968,3,334,167,0,967,966,1,0,0,0,967,968,1,0,0,0,968,970,
        1,0,0,0,969,971,3,330,165,0,970,969,1,0,0,0,970,971,1,0,0,0,971,
        972,1,0,0,0,972,974,3,336,168,0,973,975,3,338,169,0,974,973,1,0,
        0,0,974,975,1,0,0,0,975,977,1,0,0,0,976,978,3,340,170,0,977,976,
        1,0,0,0,977,978,1,0,0,0,978,979,1,0,0,0,979,980,3,342,171,0,980,
        981,5,2,0,0,981,982,5,4,0,0,982,97,1,0,0,0,983,984,5,156,0,0,984,
        985,5,3,0,0,985,986,5,1,0,0,986,987,3,152,76,0,987,989,3,364,182,
        0,988,990,3,228,114,0,989,988,1,0,0,0,989,990,1,0,0,0,990,991,1,
        0,0,0,991,992,3,230,115,0,992,993,3,366,183,0,993,994,3,232,116,
        0,994,995,5,2,0,0,995,996,5,4,0,0,996,99,1,0,0,0,997,998,5,156,0,
        0,998,999,5,3,0,0,999,1000,5,1,0,0,1000,1001,3,154,77,0,1001,1002,
        3,234,117,0,1002,1003,3,236,118,0,1003,1004,3,238,119,0,1004,1005,
        5,2,0,0,1005,1006,5,4,0,0,1006,101,1,0,0,0,1007,1008,5,156,0,0,1008,
        1009,5,3,0,0,1009,1010,5,1,0,0,1010,1012,3,156,78,0,1011,1013,3,
        176,88,0,1012,1011,1,0,0,0,1012,1013,1,0,0,0,1013,1014,1,0,0,0,1014,
        1015,3,234,117,0,1015,1017,3,236,118,0,1016,1018,3,344,172,0,1017,
        1016,1,0,0,0,1017,1018,1,0,0,0,1018,1020,1,0,0,0,1019,1021,3,346,
        173,0,1020,1019,1,0,0,0,1020,1021,1,0,0,0,1021,1023,1,0,0,0,1022,
        1024,3,228,114,0,1023,1022,1,0,0,0,1023,1024,1,0,0,0,1024,1026,1,
        0,0,0,1025,1027,3,348,174,0,1026,1025,1,0,0,0,1026,1027,1,0,0,0,
        1027,1029,1,0,0,0,1028,1030,3,350,175,0,1029,1028,1,0,0,0,1029,1030,
        1,0,0,0,1030,1031,1,0,0,0,1031,1032,3,238,119,0,1032,1033,3,352,
        176,0,1033,1035,3,356,178,0,1034,1036,3,358,179,0,1035,1034,1,0,
        0,0,1035,1036,1,0,0,0,1036,1037,1,0,0,0,1037,1038,5,2,0,0,1038,1039,
        5,4,0,0,1039,103,1,0,0,0,1040,1041,5,156,0,0,1041,1042,5,3,0,0,1042,
        1043,5,1,0,0,1043,1044,3,158,79,0,1044,1045,3,234,117,0,1045,1046,
        3,236,118,0,1046,1047,3,344,172,0,1047,1048,3,346,173,0,1048,1049,
        3,228,114,0,1049,1050,3,348,174,0,1050,1051,3,350,175,0,1051,1052,
        3,238,119,0,1052,1053,3,352,176,0,1053,1054,3,354,177,0,1054,1055,
        5,2,0,0,1055,1056,5,4,0,0,1056,105,1,0,0,0,1057,1058,5,156,0,0,1058,
        1059,5,3,0,0,1059,1060,5,1,0,0,1060,1061,3,160,80,0,1061,1062,3,
        234,117,0,1062,1063,3,236,118,0,1063,1064,3,238,119,0,1064,1065,
        5,2,0,0,1065,1066,5,4,0,0,1066,107,1,0,0,0,1067,1068,5,156,0,0,1068,
        1069,5,3,0,0,1069,1070,5,1,0,0,1070,1072,3,162,81,0,1071,1073,3,
        228,114,0,1072,1071,1,0,0,0,1072,1073,1,0,0,0,1073,1075,1,0,0,0,
        1074,1076,3,212,106,0,1075,1074,1,0,0,0,1075,1076,1,0,0,0,1076,1078,
        1,0,0,0,1077,1079,3,214,107,0,1078,1077,1,0,0,0,1078,1079,1,0,0,
        0,1079,1081,1,0,0,0,1080,1082,3,180,90,0,1081,1080,1,0,0,0,1081,
        1082,1,0,0,0,1082,1084,1,0,0,0,1083,1085,3,360,180,0,1084,1083,1,
        0,0,0,1084,1085,1,0,0,0,1085,1087,1,0,0,0,1086,1088,3,362,181,0,
        1087,1086,1,0,0,0,1087,1088,1,0,0,0,1088,1089,1,0,0,0,1089,1090,
        5,2,0,0,1090,1091,5,4,0,0,1091,109,1,0,0,0,1092,1093,5,156,0,0,1093,
        1094,5,3,0,0,1094,1095,5,1,0,0,1095,1096,3,164,82,0,1096,1097,3,
        216,108,0,1097,1099,3,228,114,0,1098,1100,3,230,115,0,1099,1098,
        1,0,0,0,1099,1100,1,0,0,0,1100,1101,1,0,0,0,1101,1102,3,232,116,
        0,1102,1103,5,2,0,0,1103,1104,5,4,0,0,1104,111,1,0,0,0,1105,1106,
        5,156,0,0,1106,1107,5,3,0,0,1107,1108,5,1,0,0,1108,1110,3,166,83,
        0,1109,1111,3,368,184,0,1110,1109,1,0,0,0,1110,1111,1,0,0,0,1111,
        1112,1,0,0,0,1112,1113,3,370,185,0,1113,1114,3,228,114,0,1114,1115,
        5,2,0,0,1115,1116,5,4,0,0,1116,113,1,0,0,0,1117,1118,5,156,0,0,1118,
        1119,5,3,0,0,1119,1120,5,1,0,0,1120,1121,3,168,84,0,1121,1122,3,
        388,194,0,1122,1124,3,390,195,0,1123,1125,3,392,196,0,1124,1123,
        1,0,0,0,1124,1125,1,0,0,0,1125,1126,1,0,0,0,1126,1127,5,2,0,0,1127,
        1128,5,4,0,0,1128,115,1,0,0,0,1129,1130,5,156,0,0,1130,1131,5,3,
        0,0,1131,1132,5,1,0,0,1132,1133,3,170,85,0,1133,1134,3,220,110,0,
        1134,1135,3,222,111,0,1135,1136,5,2,0,0,1136,1137,5,4,0,0,1137,117,
        1,0,0,0,1138,1139,5,156,0,0,1139,1140,5,3,0,0,1140,1141,5,1,0,0,
        1141,1143,3,172,86,0,1142,1144,3,224,112,0,1143,1142,1,0,0,0,1143,
        1144,1,0,0,0,1144,1145,1,0,0,0,1145,1146,3,262,131,0,1146,1147,5,
        2,0,0,1147,1148,5,4,0,0,1148,119,1,0,0,0,1149,1150,5,156,0,0,1150,
        1151,5,3,0,0,1151,1152,5,1,0,0,1152,1153,3,174,87,0,1153,1154,3,
        216,108,0,1154,1156,3,398,199,0,1155,1157,3,228,114,0,1156,1155,
        1,0,0,0,1156,1157,1,0,0,0,1157,1158,1,0,0,0,1158,1159,3,230,115,
        0,1159,1160,3,232,116,0,1160,1161,3,400,200,0,1161,1162,5,2,0,0,
        1162,1163,5,4,0,0,1163,121,1,0,0,0,1164,1165,5,12,0,0,1165,1166,
        5,3,0,0,1166,1167,5,20,0,0,1167,1168,5,4,0,0,1168,123,1,0,0,0,1169,
        1170,5,12,0,0,1170,1171,5,3,0,0,1171,1172,5,21,0,0,1172,1173,5,4,
        0,0,1173,125,1,0,0,0,1174,1175,5,12,0,0,1175,1176,5,3,0,0,1176,1177,
        5,22,0,0,1177,1178,5,4,0,0,1178,127,1,0,0,0,1179,1180,5,12,0,0,1180,
        1181,5,3,0,0,1181,1182,5,23,0,0,1182,1183,5,4,0,0,1183,129,1,0,0,
        0,1184,1185,5,12,0,0,1185,1186,5,3,0,0,1186,1187,5,24,0,0,1187,1188,
        5,4,0,0,1188,131,1,0,0,0,1189,1190,5,12,0,0,1190,1191,5,3,0,0,1191,
        1192,5,25,0,0,1192,1193,5,4,0,0,1193,133,1,0,0,0,1194,1195,5,12,
        0,0,1195,1196,5,3,0,0,1196,1197,5,26,0,0,1197,1198,5,4,0,0,1198,
        135,1,0,0,0,1199,1200,5,12,0,0,1200,1201,5,3,0,0,1201,1202,5,27,
        0,0,1202,1203,5,4,0,0,1203,137,1,0,0,0,1204,1205,5,12,0,0,1205,1206,
        5,3,0,0,1206,1207,5,28,0,0,1207,1208,5,4,0,0,1208,139,1,0,0,0,1209,
        1210,5,12,0,0,1210,1211,5,3,0,0,1211,1212,5,29,0,0,1212,1213,5,4,
        0,0,1213,141,1,0,0,0,1214,1215,5,12,0,0,1215,1216,5,3,0,0,1216,1217,
        5,30,0,0,1217,1218,5,4,0,0,1218,143,1,0,0,0,1219,1220,5,12,0,0,1220,
        1221,5,3,0,0,1221,1222,5,31,0,0,1222,1223,5,4,0,0,1223,145,1,0,0,
        0,1224,1225,5,12,0,0,1225,1226,5,3,0,0,1226,1227,5,32,0,0,1227,1228,
        5,4,0,0,1228,147,1,0,0,0,1229,1230,5,12,0,0,1230,1231,5,3,0,0,1231,
        1232,5,33,0,0,1232,1233,5,4,0,0,1233,149,1,0,0,0,1234,1235,5,12,
        0,0,1235,1236,5,3,0,0,1236,1237,5,34,0,0,1237,1238,5,4,0,0,1238,
        151,1,0,0,0,1239,1240,5,12,0,0,1240,1241,5,3,0,0,1241,1242,5,35,
        0,0,1242,1243,5,4,0,0,1243,153,1,0,0,0,1244,1245,5,12,0,0,1245,1246,
        5,3,0,0,1246,1247,5,36,0,0,1247,1248,5,4,0,0,1248,155,1,0,0,0,1249,
        1250,5,12,0,0,1250,1251,5,3,0,0,1251,1252,5,37,0,0,1252,1253,5,4,
        0,0,1253,157,1,0,0,0,1254,1255,5,12,0,0,1255,1256,5,3,0,0,1256,1257,
        5,38,0,0,1257,1258,5,4,0,0,1258,159,1,0,0,0,1259,1260,5,12,0,0,1260,
        1261,5,3,0,0,1261,1262,5,39,0,0,1262,1263,5,4,0,0,1263,161,1,0,0,
        0,1264,1265,5,12,0,0,1265,1266,5,3,0,0,1266,1267,5,40,0,0,1267,1268,
        5,4,0,0,1268,163,1,0,0,0,1269,1270,5,12,0,0,1270,1271,5,3,0,0,1271,
        1272,5,41,0,0,1272,1273,5,4,0,0,1273,165,1,0,0,0,1274,1275,5,12,
        0,0,1275,1276,5,3,0,0,1276,1277,5,42,0,0,1277,1278,5,4,0,0,1278,
        167,1,0,0,0,1279,1280,5,12,0,0,1280,1281,5,3,0,0,1281,1282,5,43,
        0,0,1282,1283,5,4,0,0,1283,169,1,0,0,0,1284,1285,5,12,0,0,1285,1286,
        5,3,0,0,1286,1287,5,44,0,0,1287,1288,5,4,0,0,1288,171,1,0,0,0,1289,
        1290,5,12,0,0,1290,1291,5,3,0,0,1291,1292,5,45,0,0,1292,1293,5,4,
        0,0,1293,173,1,0,0,0,1294,1295,5,12,0,0,1295,1296,5,3,0,0,1296,1297,
        5,46,0,0,1297,1298,5,4,0,0,1298,175,1,0,0,0,1299,1300,5,47,0,0,1300,
        1301,5,3,0,0,1301,1302,5,13,0,0,1302,1303,5,4,0,0,1303,177,1,0,0,
        0,1304,1305,5,48,0,0,1305,1306,5,3,0,0,1306,1307,5,156,0,0,1307,
        1308,5,4,0,0,1308,179,1,0,0,0,1309,1310,5,49,0,0,1310,1311,5,3,0,
        0,1311,1312,5,156,0,0,1312,1313,5,4,0,0,1313,181,1,0,0,0,1314,1315,
        5,50,0,0,1315,1316,5,3,0,0,1316,1317,5,156,0,0,1317,1318,5,4,0,0,
        1318,183,1,0,0,0,1319,1320,5,51,0,0,1320,1321,5,3,0,0,1321,1322,
        5,13,0,0,1322,1323,5,4,0,0,1323,185,1,0,0,0,1324,1325,5,52,0,0,1325,
        1326,5,3,0,0,1326,1327,5,156,0,0,1327,1328,5,4,0,0,1328,187,1,0,
        0,0,1329,1330,5,53,0,0,1330,1331,5,3,0,0,1331,1332,3,406,203,0,1332,
        1333,5,4,0,0,1333,189,1,0,0,0,1334,1335,5,54,0,0,1335,1336,5,3,0,
        0,1336,1337,5,13,0,0,1337,1338,5,4,0,0,1338,191,1,0,0,0,1339,1340,
        5,55,0,0,1340,1341,5,3,0,0,1341,1342,3,406,203,0,1342,1343,5,4,0,
        0,1343,193,1,0,0,0,1344,1345,5,56,0,0,1345,1346,5,3,0,0,1346,1347,
        3,406,203,0,1347,1348,5,4,0,0,1348,195,1,0,0,0,1349,1350,5,57,0,
        0,1350,1351,5,3,0,0,1351,1355,5,1,0,0,1352,1354,3,386,193,0,1353,
        1352,1,0,0,0,1354,1357,1,0,0,0,1355,1353,1,0,0,0,1355,1356,1,0,0,
        0,1356,1358,1,0,0,0,1357,1355,1,0,0,0,1358,1359,5,2,0,0,1359,1360,
        5,4,0,0,1360,197,1,0,0,0,1361,1362,5,58,0,0,1362,1363,5,3,0,0,1363,
        1364,3,242,121,0,1364,1365,5,4,0,0,1365,199,1,0,0,0,1366,1367,5,
        59,0,0,1367,1368,5,3,0,0,1368,1369,3,406,203,0,1369,1370,5,4,0,0,
        1370,201,1,0,0,0,1371,1372,5,60,0,0,1372,1373,5,3,0,0,1373,1374,
        5,13,0,0,1374,1375,5,4,0,0,1375,203,1,0,0,0,1376,1377,5,61,0,0,1377,
        1378,5,3,0,0,1378,1379,5,13,0,0,1379,1380,5,4,0,0,1380,205,1,0,0,
        0,1381,1382,5,62,0,0,1382,1383,5,3,0,0,1383,1384,5,13,0,0,1384,1385,
        5,4,0,0,1385,207,1,0,0,0,1386,1387,5,63,0,0,1387,1388,5,3,0,0,1388,
        1389,5,13,0,0,1389,1390,5,4,0,0,1390,209,1,0,0,0,1391,1392,5,64,
        0,0,1392,1393,5,3,0,0,1393,1394,5,13,0,0,1394,1395,5,4,0,0,1395,
        211,1,0,0,0,1396,1397,5,65,0,0,1397,1398,5,3,0,0,1398,1399,3,404,
        202,0,1399,1400,5,4,0,0,1400,213,1,0,0,0,1401,1402,5,66,0,0,1402,
        1403,5,3,0,0,1403,1404,3,242,121,0,1404,1405,5,4,0,0,1405,215,1,
        0,0,0,1406,1407,5,67,0,0,1407,1408,5,3,0,0,1408,1409,3,240,120,0,
        1409,1410,5,4,0,0,1410,217,1,0,0,0,1411,1412,5,68,0,0,1412,1413,
        5,3,0,0,1413,1414,3,404,202,0,1414,1415,5,4,0,0,1415,219,1,0,0,0,
        1416,1417,5,69,0,0,1417,1418,5,3,0,0,1418,1419,5,157,0,0,1419,1420,
        5,4,0,0,1420,221,1,0,0,0,1421,1422,5,70,0,0,1422,1423,5,3,0,0,1423,
        1427,5,1,0,0,1424,1426,3,386,193,0,1425,1424,1,0,0,0,1426,1429,1,
        0,0,0,1427,1425,1,0,0,0,1427,1428,1,0,0,0,1428,1430,1,0,0,0,1429,
        1427,1,0,0,0,1430,1431,5,2,0,0,1431,1432,5,4,0,0,1432,223,1,0,0,
        0,1433,1434,5,71,0,0,1434,1435,5,3,0,0,1435,1436,5,156,0,0,1436,
        1437,5,4,0,0,1437,225,1,0,0,0,1438,1439,5,72,0,0,1439,1440,5,3,0,
        0,1440,1441,3,240,120,0,1441,1442,5,4,0,0,1442,227,1,0,0,0,1443,
        1444,5,73,0,0,1444,1445,5,3,0,0,1445,1446,3,404,202,0,1446,1447,
        5,4,0,0,1447,229,1,0,0,0,1448,1449,5,74,0,0,1449,1450,5,3,0,0,1450,
        1451,3,406,203,0,1451,1452,5,4,0,0,1452,231,1,0,0,0,1453,1454,5,
        75,0,0,1454,1455,5,3,0,0,1455,1456,3,404,202,0,1456,1457,5,4,0,0,
        1457,233,1,0,0,0,1458,1459,5,76,0,0,1459,1460,5,3,0,0,1460,1461,
        5,13,0,0,1461,1462,5,4,0,0,1462,235,1,0,0,0,1463,1464,5,77,0,0,1464,
        1465,5,3,0,0,1465,1466,3,240,120,0,1466,1467,5,4,0,0,1467,237,1,
        0,0,0,1468,1469,5,78,0,0,1469,1470,5,3,0,0,1470,1471,5,13,0,0,1471,
        1472,5,4,0,0,1472,239,1,0,0,0,1473,1478,5,5,0,0,1474,1475,5,156,
        0,0,1475,1477,5,6,0,0,1476,1474,1,0,0,0,1477,1480,1,0,0,0,1478,1476,
        1,0,0,0,1478,1479,1,0,0,0,1479,1481,1,0,0,0,1480,1478,1,0,0,0,1481,
        1482,5,7,0,0,1482,241,1,0,0,0,1483,1484,5,5,0,0,1484,1500,5,7,0,
        0,1485,1486,5,5,0,0,1486,1491,3,406,203,0,1487,1488,5,6,0,0,1488,
        1490,3,406,203,0,1489,1487,1,0,0,0,1490,1493,1,0,0,0,1491,1489,1,
        0,0,0,1491,1492,1,0,0,0,1492,1495,1,0,0,0,1493,1491,1,0,0,0,1494,
        1496,5,6,0,0,1495,1494,1,0,0,0,1495,1496,1,0,0,0,1496,1497,1,0,0,
        0,1497,1498,5,7,0,0,1498,1500,1,0,0,0,1499,1483,1,0,0,0,1499,1485,
        1,0,0,0,1500,243,1,0,0,0,1501,1506,5,5,0,0,1502,1503,5,158,0,0,1503,
        1505,5,6,0,0,1504,1502,1,0,0,0,1505,1508,1,0,0,0,1506,1504,1,0,0,
        0,1506,1507,1,0,0,0,1507,1509,1,0,0,0,1508,1506,1,0,0,0,1509,1510,
        5,7,0,0,1510,245,1,0,0,0,1511,1512,5,79,0,0,1512,1513,5,3,0,0,1513,
        1514,5,156,0,0,1514,1515,5,4,0,0,1515,247,1,0,0,0,1516,1517,5,80,
        0,0,1517,1518,5,3,0,0,1518,1519,3,240,120,0,1519,1520,5,4,0,0,1520,
        249,1,0,0,0,1521,1522,5,81,0,0,1522,1523,5,3,0,0,1523,1524,3,240,
        120,0,1524,1525,5,4,0,0,1525,251,1,0,0,0,1526,1527,5,82,0,0,1527,
        1528,5,3,0,0,1528,1529,3,404,202,0,1529,1530,5,4,0,0,1530,253,1,
        0,0,0,1531,1532,5,83,0,0,1532,1533,5,3,0,0,1533,1534,3,404,202,0,
        1534,1535,5,4,0,0,1535,255,1,0,0,0,1536,1537,5,84,0,0,1537,1538,
        5,3,0,0,1538,1539,3,404,202,0,1539,1540,5,4,0,0,1540,257,1,0,0,0,
        1541,1542,5,85,0,0,1542,1543,5,3,0,0,1543,1544,5,13,0,0,1544,1545,
        5,4,0,0,1545,259,1,0,0,0,1546,1547,5,86,0,0,1547,1548,5,3,0,0,1548,
        1549,3,240,120,0,1549,1550,5,4,0,0,1550,261,1,0,0,0,1551,1552,5,
        87,0,0,1552,1553,5,3,0,0,1553,1554,3,406,203,0,1554,1555,5,4,0,0,
        1555,263,1,0,0,0,1556,1557,5,88,0,0,1557,1558,5,3,0,0,1558,1559,
        5,156,0,0,1559,1560,5,4,0,0,1560,265,1,0,0,0,1561,1562,5,89,0,0,
        1562,1563,5,3,0,0,1563,1564,5,157,0,0,1564,1565,5,4,0,0,1565,267,
        1,0,0,0,1566,1567,5,90,0,0,1567,1568,5,3,0,0,1568,1569,5,13,0,0,
        1569,1570,5,4,0,0,1570,269,1,0,0,0,1571,1572,5,91,0,0,1572,1573,
        5,3,0,0,1573,1574,3,406,203,0,1574,1575,5,4,0,0,1575,271,1,0,0,0,
        1576,1577,5,92,0,0,1577,1578,5,3,0,0,1578,1579,3,406,203,0,1579,
        1580,5,4,0,0,1580,273,1,0,0,0,1581,1582,5,93,0,0,1582,1583,5,3,0,
        0,1583,1584,5,13,0,0,1584,1585,5,4,0,0,1585,275,1,0,0,0,1586,1587,
        5,94,0,0,1587,1588,5,3,0,0,1588,1589,3,404,202,0,1589,1590,5,4,0,
        0,1590,277,1,0,0,0,1591,1592,5,95,0,0,1592,1593,5,3,0,0,1593,1594,
        3,404,202,0,1594,1595,5,4,0,0,1595,279,1,0,0,0,1596,1597,5,96,0,
        0,1597,1598,5,3,0,0,1598,1599,3,242,121,0,1599,1600,5,4,0,0,1600,
        281,1,0,0,0,1601,1602,5,97,0,0,1602,1603,5,3,0,0,1603,1604,5,13,
        0,0,1604,1605,5,4,0,0,1605,283,1,0,0,0,1606,1607,5,98,0,0,1607,1608,
        5,3,0,0,1608,1609,3,242,121,0,1609,1610,5,4,0,0,1610,285,1,0,0,0,
        1611,1612,5,99,0,0,1612,1613,5,3,0,0,1613,1614,5,13,0,0,1614,1615,
        5,4,0,0,1615,287,1,0,0,0,1616,1617,5,100,0,0,1617,1618,5,3,0,0,1618,
        1619,3,404,202,0,1619,1620,5,4,0,0,1620,289,1,0,0,0,1621,1622,5,
        101,0,0,1622,1623,5,3,0,0,1623,1625,5,1,0,0,1624,1626,3,298,149,
        0,1625,1624,1,0,0,0,1625,1626,1,0,0,0,1626,1628,1,0,0,0,1627,1629,
        3,402,201,0,1628,1627,1,0,0,0,1628,1629,1,0,0,0,1629,1631,1,0,0,
        0,1630,1632,3,294,147,0,1631,1630,1,0,0,0,1631,1632,1,0,0,0,1632,
        1634,1,0,0,0,1633,1635,3,292,146,0,1634,1633,1,0,0,0,1634,1635,1,
        0,0,0,1635,1637,1,0,0,0,1636,1638,3,296,148,0,1637,1636,1,0,0,0,
        1637,1638,1,0,0,0,1638,1640,1,0,0,0,1639,1641,3,300,150,0,1640,1639,
        1,0,0,0,1640,1641,1,0,0,0,1641,1643,1,0,0,0,1642,1644,3,302,151,
        0,1643,1642,1,0,0,0,1643,1644,1,0,0,0,1644,1646,1,0,0,0,1645,1647,
        3,304,152,0,1646,1645,1,0,0,0,1646,1647,1,0,0,0,1647,1649,1,0,0,
        0,1648,1650,3,306,153,0,1649,1648,1,0,0,0,1649,1650,1,0,0,0,1650,
        1651,1,0,0,0,1651,1652,5,2,0,0,1652,1653,5,4,0,0,1653,291,1,0,0,
        0,1654,1655,5,102,0,0,1655,1656,5,3,0,0,1656,1657,5,13,0,0,1657,
        1658,5,4,0,0,1658,293,1,0,0,0,1659,1660,5,103,0,0,1660,1661,5,3,
        0,0,1661,1662,5,158,0,0,1662,1663,5,4,0,0,1663,295,1,0,0,0,1664,
        1665,5,104,0,0,1665,1666,5,3,0,0,1666,1667,5,13,0,0,1667,1668,5,
        4,0,0,1668,297,1,0,0,0,1669,1670,5,105,0,0,1670,1671,5,3,0,0,1671,
        1672,7,0,0,0,1672,1673,5,4,0,0,1673,299,1,0,0,0,1674,1675,5,106,
        0,0,1675,1676,5,3,0,0,1676,1677,5,13,0,0,1677,1678,5,4,0,0,1678,
        301,1,0,0,0,1679,1680,5,107,0,0,1680,1681,5,3,0,0,1681,1682,5,13,
        0,0,1682,1683,5,4,0,0,1683,303,1,0,0,0,1684,1685,5,108,0,0,1685,
        1686,5,3,0,0,1686,1687,3,406,203,0,1687,1688,5,4,0,0,1688,305,1,
        0,0,0,1689,1690,5,109,0,0,1690,1691,5,3,0,0,1691,1695,5,1,0,0,1692,
        1694,3,308,154,0,1693,1692,1,0,0,0,1694,1697,1,0,0,0,1695,1693,1,
        0,0,0,1695,1696,1,0,0,0,1696,1698,1,0,0,0,1697,1695,1,0,0,0,1698,
        1699,5,2,0,0,1699,1700,5,4,0,0,1700,307,1,0,0,0,1701,1702,5,156,
        0,0,1702,1703,5,3,0,0,1703,1705,5,1,0,0,1704,1706,3,310,155,0,1705,
        1704,1,0,0,0,1705,1706,1,0,0,0,1706,1708,1,0,0,0,1707,1709,3,312,
        156,0,1708,1707,1,0,0,0,1708,1709,1,0,0,0,1709,1711,1,0,0,0,1710,
        1712,3,314,157,0,1711,1710,1,0,0,0,1711,1712,1,0,0,0,1712,1714,1,
        0,0,0,1713,1715,3,316,158,0,1714,1713,1,0,0,0,1714,1715,1,0,0,0,
        1715,1717,1,0,0,0,1716,1718,3,292,146,0,1717,1716,1,0,0,0,1717,1718,
        1,0,0,0,1718,1720,1,0,0,0,1719,1721,3,318,159,0,1720,1719,1,0,0,
        0,1720,1721,1,0,0,0,1721,1723,1,0,0,0,1722,1724,3,396,198,0,1723,
        1722,1,0,0,0,1723,1724,1,0,0,0,1724,1726,1,0,0,0,1725,1727,3,312,
        156,0,1726,1725,1,0,0,0,1726,1727,1,0,0,0,1727,1728,1,0,0,0,1728,
        1729,5,2,0,0,1729,1730,5,4,0,0,1730,309,1,0,0,0,1731,1732,5,110,
        0,0,1732,1733,5,3,0,0,1733,1734,5,158,0,0,1734,1735,5,4,0,0,1735,
        311,1,0,0,0,1736,1737,5,111,0,0,1737,1738,5,3,0,0,1738,1739,5,156,
        0,0,1739,1740,5,4,0,0,1740,313,1,0,0,0,1741,1742,5,112,0,0,1742,
        1743,5,3,0,0,1743,1744,3,404,202,0,1744,1745,5,4,0,0,1745,315,1,
        0,0,0,1746,1747,5,113,0,0,1747,1748,5,3,0,0,1748,1749,3,404,202,
        0,1749,1750,5,4,0,0,1750,317,1,0,0,0,1751,1752,5,114,0,0,1752,1753,
        5,3,0,0,1753,1754,5,158,0,0,1754,1755,5,4,0,0,1755,319,1,0,0,0,1756,
        1757,5,115,0,0,1757,1758,5,3,0,0,1758,1759,5,157,0,0,1759,1760,5,
        4,0,0,1760,321,1,0,0,0,1761,1762,5,116,0,0,1762,1763,5,3,0,0,1763,
        1764,5,158,0,0,1764,1765,5,4,0,0,1765,323,1,0,0,0,1766,1767,5,117,
        0,0,1767,1768,5,3,0,0,1768,1769,5,13,0,0,1769,1770,5,4,0,0,1770,
        325,1,0,0,0,1771,1772,5,118,0,0,1772,1773,5,3,0,0,1773,1774,3,242,
        121,0,1774,1775,5,4,0,0,1775,327,1,0,0,0,1776,1777,5,119,0,0,1777,
        1778,5,3,0,0,1778,1779,5,156,0,0,1779,1780,5,4,0,0,1780,329,1,0,
        0,0,1781,1782,5,120,0,0,1782,1783,5,3,0,0,1783,1784,5,156,0,0,1784,
        1785,5,4,0,0,1785,331,1,0,0,0,1786,1787,5,121,0,0,1787,1788,5,3,
        0,0,1788,1789,3,240,120,0,1789,1790,5,4,0,0,1790,333,1,0,0,0,1791,
        1792,5,122,0,0,1792,1793,5,3,0,0,1793,1794,5,13,0,0,1794,1795,5,
        4,0,0,1795,335,1,0,0,0,1796,1797,5,123,0,0,1797,1798,5,3,0,0,1798,
        1799,3,404,202,0,1799,1800,5,4,0,0,1800,337,1,0,0,0,1801,1802,5,
        124,0,0,1802,1803,5,3,0,0,1803,1804,3,406,203,0,1804,1805,5,4,0,
        0,1805,1814,1,0,0,0,1806,1807,5,124,0,0,1807,1808,5,3,0,0,1808,1809,
        5,5,0,0,1809,1810,3,378,189,0,1810,1811,5,7,0,0,1811,1812,5,4,0,
        0,1812,1814,1,0,0,0,1813,1801,1,0,0,0,1813,1806,1,0,0,0,1814,339,
        1,0,0,0,1815,1816,5,125,0,0,1816,1817,5,3,0,0,1817,1818,3,404,202,
        0,1818,1819,5,4,0,0,1819,341,1,0,0,0,1820,1821,5,126,0,0,1821,1822,
        5,3,0,0,1822,1823,3,240,120,0,1823,1824,5,4,0,0,1824,343,1,0,0,0,
        1825,1826,5,127,0,0,1826,1827,5,3,0,0,1827,1828,3,242,121,0,1828,
        1829,5,4,0,0,1829,345,1,0,0,0,1830,1831,5,128,0,0,1831,1832,5,3,
        0,0,1832,1833,3,242,121,0,1833,1834,5,4,0,0,1834,347,1,0,0,0,1835,
        1836,5,129,0,0,1836,1837,5,3,0,0,1837,1838,3,242,121,0,1838,1839,
        5,4,0,0,1839,349,1,0,0,0,1840,1841,5,130,0,0,1841,1842,5,3,0,0,1842,
        1843,3,242,121,0,1843,1844,5,4,0,0,1844,351,1,0,0,0,1845,1846,5,
        131,0,0,1846,1847,5,3,0,0,1847,1848,3,404,202,0,1848,1849,5,4,0,
        0,1849,353,1,0,0,0,1850,1851,5,132,0,0,1851,1852,5,3,0,0,1852,1853,
        5,157,0,0,1853,1854,5,4,0,0,1854,355,1,0,0,0,1855,1856,5,133,0,0,
        1856,1857,5,3,0,0,1857,1858,3,404,202,0,1858,1859,5,4,0,0,1859,357,
        1,0,0,0,1860,1861,5,134,0,0,1861,1862,5,3,0,0,1862,1863,5,13,0,0,
        1863,1864,5,4,0,0,1864,359,1,0,0,0,1865,1866,5,135,0,0,1866,1867,
        5,3,0,0,1867,1868,5,156,0,0,1868,1869,5,4,0,0,1869,361,1,0,0,0,1870,
        1871,5,136,0,0,1871,1872,5,3,0,0,1872,1873,5,156,0,0,1873,1874,5,
        4,0,0,1874,363,1,0,0,0,1875,1876,5,137,0,0,1876,1877,5,3,0,0,1877,
        1878,3,406,203,0,1878,1879,5,4,0,0,1879,365,1,0,0,0,1880,1881,5,
        138,0,0,1881,1882,5,3,0,0,1882,1883,5,156,0,0,1883,1884,5,4,0,0,
        1884,367,1,0,0,0,1885,1886,5,139,0,0,1886,1887,5,3,0,0,1887,1888,
        5,156,0,0,1888,1889,5,4,0,0,1889,369,1,0,0,0,1890,1891,5,140,0,0,
        1891,1892,5,3,0,0,1892,1896,5,1,0,0,1893,1895,3,386,193,0,1894,1893,
        1,0,0,0,1895,1898,1,0,0,0,1896,1894,1,0,0,0,1896,1897,1,0,0,0,1897,
        1899,1,0,0,0,1898,1896,1,0,0,0,1899,1900,5,2,0,0,1900,1901,5,4,0,
        0,1901,371,1,0,0,0,1902,1903,5,141,0,0,1903,1904,5,3,0,0,1904,1905,
        3,240,120,0,1905,1906,5,4,0,0,1906,373,1,0,0,0,1907,1908,5,142,0,
        0,1908,1909,5,3,0,0,1909,1910,3,404,202,0,1910,1911,5,4,0,0,1911,
        375,1,0,0,0,1912,1913,5,143,0,0,1913,1914,5,3,0,0,1914,1915,5,13,
        0,0,1915,1916,5,4,0,0,1916,377,1,0,0,0,1917,1919,3,380,190,0,1918,
        1917,1,0,0,0,1919,1922,1,0,0,0,1920,1918,1,0,0,0,1920,1921,1,0,0,
        0,1921,379,1,0,0,0,1922,1920,1,0,0,0,1923,1924,5,1,0,0,1924,1925,
        5,144,0,0,1925,1926,5,3,0,0,1926,1927,5,156,0,0,1927,1928,5,4,0,
        0,1928,1929,5,145,0,0,1929,1930,5,3,0,0,1930,1931,5,156,0,0,1931,
        1932,5,4,0,0,1932,1933,5,2,0,0,1933,1934,5,6,0,0,1934,381,1,0,0,
        0,1935,1936,5,153,0,0,1936,1937,5,3,0,0,1937,1938,3,242,121,0,1938,
        1939,5,4,0,0,1939,383,1,0,0,0,1940,1941,5,154,0,0,1941,1942,5,3,
        0,0,1942,1943,3,240,120,0,1943,1944,5,4,0,0,1944,385,1,0,0,0,1945,
        1946,3,406,203,0,1946,1947,5,3,0,0,1947,1948,3,406,203,0,1948,1949,
        5,4,0,0,1949,1987,1,0,0,0,1950,1951,3,406,203,0,1951,1952,5,3,0,
        0,1952,1953,5,13,0,0,1953,1954,5,4,0,0,1954,1987,1,0,0,0,1955,1956,
        3,406,203,0,1956,1957,5,3,0,0,1957,1958,5,160,0,0,1958,1959,5,4,
        0,0,1959,1987,1,0,0,0,1960,1961,3,406,203,0,1961,1962,5,3,0,0,1962,
        1963,5,1,0,0,1963,1964,3,386,193,0,1964,1965,5,2,0,0,1965,1966,5,
        4,0,0,1966,1987,1,0,0,0,1967,1968,3,406,203,0,1968,1969,5,3,0,0,
        1969,1971,5,5,0,0,1970,1972,3,406,203,0,1971,1970,1,0,0,0,1971,1972,
        1,0,0,0,1972,1977,1,0,0,0,1973,1974,5,6,0,0,1974,1976,3,406,203,
        0,1975,1973,1,0,0,0,1976,1979,1,0,0,0,1977,1975,1,0,0,0,1977,1978,
        1,0,0,0,1978,1981,1,0,0,0,1979,1977,1,0,0,0,1980,1982,5,6,0,0,1981,
        1980,1,0,0,0,1981,1982,1,0,0,0,1982,1983,1,0,0,0,1983,1984,5,7,0,
        0,1984,1985,5,4,0,0,1985,1987,1,0,0,0,1986,1945,1,0,0,0,1986,1950,
        1,0,0,0,1986,1955,1,0,0,0,1986,1960,1,0,0,0,1986,1967,1,0,0,0,1987,
        387,1,0,0,0,1988,1989,5,146,0,0,1989,1990,5,3,0,0,1990,1991,3,240,
        120,0,1991,1992,5,4,0,0,1992,389,1,0,0,0,1993,1994,5,147,0,0,1994,
        1995,5,3,0,0,1995,1996,5,13,0,0,1996,1997,5,4,0,0,1997,391,1,0,0,
        0,1998,1999,5,148,0,0,1999,2000,5,3,0,0,2000,2001,3,404,202,0,2001,
        2002,5,4,0,0,2002,393,1,0,0,0,2003,2004,5,149,0,0,2004,2005,5,3,
        0,0,2005,2009,5,1,0,0,2006,2008,3,386,193,0,2007,2006,1,0,0,0,2008,
        2011,1,0,0,0,2009,2007,1,0,0,0,2009,2010,1,0,0,0,2010,2012,1,0,0,
        0,2011,2009,1,0,0,0,2012,2013,5,2,0,0,2013,2014,5,4,0,0,2014,395,
        1,0,0,0,2015,2016,5,150,0,0,2016,2017,5,3,0,0,2017,2021,5,1,0,0,
        2018,2020,3,386,193,0,2019,2018,1,0,0,0,2020,2023,1,0,0,0,2021,2019,
        1,0,0,0,2021,2022,1,0,0,0,2022,2024,1,0,0,0,2023,2021,1,0,0,0,2024,
        2025,5,2,0,0,2025,2026,5,4,0,0,2026,397,1,0,0,0,2027,2028,5,151,
        0,0,2028,2029,5,3,0,0,2029,2030,5,156,0,0,2030,2031,5,4,0,0,2031,
        399,1,0,0,0,2032,2033,5,152,0,0,2033,2034,5,3,0,0,2034,2035,5,158,
        0,0,2035,2036,5,4,0,0,2036,401,1,0,0,0,2037,2038,5,155,0,0,2038,
        2039,5,3,0,0,2039,2040,3,406,203,0,2040,2041,5,4,0,0,2041,403,1,
        0,0,0,2042,2049,5,158,0,0,2043,2049,5,157,0,0,2044,2049,5,18,0,0,
        2045,2049,5,10,0,0,2046,2049,5,11,0,0,2047,2049,3,408,204,0,2048,
        2042,1,0,0,0,2048,2043,1,0,0,0,2048,2044,1,0,0,0,2048,2045,1,0,0,
        0,2048,2046,1,0,0,0,2048,2047,1,0,0,0,2049,405,1,0,0,0,2050,2054,
        3,404,202,0,2051,2054,5,13,0,0,2052,2054,5,159,0,0,2053,2050,1,0,
        0,0,2053,2051,1,0,0,0,2053,2052,1,0,0,0,2054,407,1,0,0,0,2055,2056,
        7,1,0,0,2056,409,1,0,0,0,162,440,443,446,449,452,455,458,461,464,
        467,471,474,477,481,484,487,490,493,496,499,504,507,510,523,528,
        533,538,543,548,553,558,563,568,573,578,583,588,593,598,603,608,
        613,618,623,628,633,638,643,648,653,662,665,670,680,683,686,689,
        692,703,710,713,723,726,748,752,755,766,769,772,775,778,781,784,
        787,790,793,796,799,802,805,808,811,814,856,859,862,865,868,872,
        875,878,901,904,909,912,916,943,947,950,953,956,960,964,967,970,
        974,977,989,1012,1017,1020,1023,1026,1029,1035,1072,1075,1078,1081,
        1084,1087,1099,1110,1124,1143,1156,1355,1427,1478,1491,1495,1499,
        1506,1625,1628,1631,1634,1637,1640,1643,1646,1649,1695,1705,1708,
        1711,1714,1717,1720,1723,1726,1813,1896,1920,1971,1977,1981,1986,
        2009,2021,2048,2053
    ]

class PBXProjParser ( Parser ):

    grammarFileName = "PBXProj.g4"

    atn = ATNDeserializer().deserialize(serializedATN())

    decisionsToDFA = [ DFA(ds, i) for i, ds in enumerate(atn.decisionToState) ]

    sharedContextCache = PredictionContextCache()

    literalNames = [ "<INVALID>", "'{'", "'}'", "'='", "';'", "'('", "','", 
                     "')'", "'archiveVersion'", "'classes'", "'-'", "'.'", 
                     "'isa'", "<INVALID>", "'objectVersion'", "'objects'", 
                     "'rootObject'", "'/'", "'_'", "'$'", "'PBXAggregateTarget'", 
                     "'PBXBuildFile'", "'PBXBuildRule'", "'PBXBuildStyle'", 
                     "'PBXContainerItemProxy'", "'PBXCopyFilesBuildPhase'", 
                     "'PBXFileReference'", "'PBXFileSystemSynchronizedBuildFileExceptionSet'", 
                     "'PBXFileSystemSynchronizedRootGroup'", "'PBXFrameworksBuildPhase'", 
                     "'PBXGroup'", "'PBXHeadersBuildPhase'", "'PBXNativeTarget'", 
                     "'PBXLegacyTarget'", "'PBXProject'", "'PBXReferenceProxy'", 
                     "<INVALID>", "'PBXShellScriptBuildPhase'", "'PBXShellBuildPhase'", 
                     "'PBXSourcesBuildPhase'", "'PBXTargetDependency'", 
                     "'PBXVariantGroup'", "'XCBuildConfiguration'", "'XCConfigurationList'", 
                     "'XCRemoteSwiftPackageReference'", "'XCSwiftPackageProductDependency'", 
                     "'XCVersionGroup'", "'alwaysOutOfDate'", "'fileRef'", 
                     "'productRef'", "'containerPortal'", "'proxyType'", 
                     "'remoteGlobalIDString'", "'remoteInfo'", "'fileEncoding'", 
                     "'comments'", "'explicitFileType'", "'explicitFileTypes'", 
                     "'explicitFolders'", "'lastKnownFileType'", "'includeInIndex'", 
                     "'indentWidth'", "'tabWidth'", "'usesTabs'", "'wrapsLines'", 
                     "'platformFilter'", "'platformFilters'", "'children'", 
                     "'productInstallPath'", "'repositoryURL'", "'requirement'", 
                     "'package'", "'packageProductDependencies'", "'name'", 
                     "'path'", "'sourceTree'", "'buildActionMask'", "'files'", 
                     "'runOnlyForDeploymentPostprocessing'", "'buildConfigurationList'", 
                     "'buildPhases'", "'buildRules'", "'buildArgumentsString'", 
                     "'buildToolPath'", "'buildWorkingDirectory'", "'passBuildSettingsInEnvironment'", 
                     "'dependencies'", "'productName'", "'productReference'", 
                     "'productType'", "'lineEnding'", "'xcLanguageSpecificationIdentifier'", 
                     "'plistStructureDefinitionIdentifier'", "'refType'", 
                     "'compilerSpec'", "'filePatterns'", "'inputFiles'", 
                     "'isEditable'", "'outputFiles'", "'runOncePerArchitecture'", 
                     "'script'", "'attributes'", "'LastSwiftMigration'", 
                     "'DefaultBuildSystemTypeForWorkspace'", "'LastSwiftUpdateCheck'", 
                     "'BuildIndependentTargetsInParallel'", "'LastTestingUpgradeCheck'", 
                     "'LastUpgradeCheck'", "'ORGANIZATIONNAME'", "'TargetAttributes'", 
                     "'CreatedOnToolsVersion'", "'TestTargetID'", "'DevelopmentTeam'", 
                     "'DevelopmentTeamName'", "'ProvisioningStyle'", "'compatibilityVersion'", 
                     "'developmentRegion'", "'hasScannedForEncodings'", 
                     "'knownRegions'", "'mainGroup'", "'productRefGroup'", 
                     "'packageReferences'", "'preferredProjectObjectVersion'", 
                     "'projectDirPath'", "'projectReferences'", "'projectRoot'", 
                     "'targets'", "'inputFileListPaths'", "'inputPaths'", 
                     "'outputFileListPaths'", "'outputPaths'", "'shellPath'", 
                     "'shell'", "'shellScript'", "'showEnvVarsInLog'", "'target'", 
                     "'targetProxy'", "'fileType'", "'remoteRef'", "'baseConfigurationReference'", 
                     "'buildSettings'", "'buildStyles'", "'dstPath'", "'dstSubfolderSpec'", 
                     "'ProductGroup'", "'ProjectRef'", "'buildConfigurations'", 
                     "'defaultConfigurationIsVisible'", "'defaultConfigurationName'", 
                     "'settings'", "'SystemCapabilities'", "'currentVersion'", 
                     "'versionGroupType'", "'membershipExceptions'", "'exceptions'", 
                     "'CLASSPREFIX'" ]

    symbolicNames = [ "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                      "ARCHIVE_VERSION", "CLASSES", "DASH", "DOT", "ISA", 
                      "NUMBER", "OBJECT_VERSION", "OBJECTS", "ROOT_OBJECT", 
                      "SLASH", "UNDERSCORE", "DOLLAR", "PBX_AGGREGATE_TARGET", 
                      "PBX_BUILD_FILE", "PBX_BUILD_RULE", "PBX_BUILD_STYLE", 
                      "PBX_CONTAINER_ITEM_PROXY", "PBX_COPY_FILES_BUILD_PHASE", 
                      "PBX_FILE_REFERENCE", "PBX_FILE_SYSTEM_SYNCHRONIZED_BUILD_FILE_EXCEPTION_SET", 
                      "PBX_FILE_SYSTEM_SYNCHRONIZED_ROOT_GROUP", "PBX_FRAMEWORKS_BUILD_PHASE", 
                      "PBX_GROUP", "PBX_HEADERS_BUILD_PHASE", "PBX_NATIVE_TARGET", 
                      "PBX_LEGACY_TARGET", "PBX_PROJECT", "PBX_REFERENCE_PROXY", 
                      "PBX_RESOURCES_BUILD_PHASE", "PBX_SHELL_SCRIPT_BUILD_PHASE", 
                      "PBX_SHELL_BUILD_PHASE", "PBX_SOURCES_BUILD_PHASE", 
                      "PBX_TARGET_DEPENDENCY", "PBX_VARIANT_GROUP", "XC_BUILD_CONFIGURATION", 
                      "XC_CONFIGURATION_LIST", "XC_REMOTE_SWIFT_PACKAGE_REFERENCE", 
                      "XC_SWIFT_PACKAGE_PRODUCT_DEPENDENCY", "XC_VERSION_GROUP", 
                      "ALWAYS_OUT_OF_DATE", "FILE_REF", "PRODUCT_REF", "CONTAINER_PORTAL", 
                      "PROXY_TYPE", "REMOTE_GLOBAL_ID_STRING", "REMOTE_INFO", 
                      "FILE_ENCODING", "COMMENTS", "EXPLICIT_FILE_TYPE", 
                      "EXPLICIT_FILE_TYPES", "EXPLICIT_FOLDERS", "LAST_KNOWN_FILE_TYPE", 
                      "INCLUDE_IN_INDEX", "INDENT_WIDTH", "TAB_WIDTH", "USES_TABS", 
                      "WRAPS_LINES", "PLATFORM_FILTER", "PLATFORM_FILTERS", 
                      "CHILDREN", "PRODUCT_INSTALL_PATH", "REPOSITORY_URL", 
                      "REQUIREMENT", "PACKAGE", "PACKAGE_PRODUCT_DEPENDENCIES", 
                      "NAME", "PATH", "SOURCE_TREE", "BUILD_ACTION_MASK", 
                      "FILES", "RUN_ONLY_FOR_DEPLOYMENT_POSTPROCESSING", 
                      "BUILD_CONFIGURATION_LIST", "BUILD_PHASES", "BUILD_RULES", 
                      "BUILD_ARGUMENTS_STRING", "BUILD_TOOL_PATH", "BUILD_WORKING_DIRECTORY", 
                      "PASS_BUILD_SETTINGS_IN_ENVIRONMENT", "DEPENDENCIES", 
                      "PRODUCT_NAME", "PRODUCT_REFERENCE", "PRODUCT_TYPE", 
                      "LINE_ENDING", "XC_LANGUAGE_SPECIFICATION_IDENTIFIER", 
                      "PLIST_STRUCTURE_DEFINITION_IDENTIFIER", "REF_TYPE", 
                      "COMPILER_SPEC", "FILE_PATTERNS", "INPUT_FILES", "IS_EDITABLE", 
                      "OUTPUT_FILES", "RUN_ONCE_PER_ARCH", "SCRIPT", "ATTRIBUTES", 
                      "LAST_SWIFT_MIGRATION", "DEFAULT_BUILD_SYSTEM_TYPE_FOR_WORKSPACE", 
                      "LAST_SWIFT_UPDATE_CHECK", "BUILD_INDEPENDENT_TARGETS_IN_PARALLEL", 
                      "LAST_TESTING_UPGRADE_CHECK", "LAST_UPGRADE_CHECK", 
                      "ORGANIZATION_NAME", "TARGET_ATTRIBUTES", "CREATED_ON_TOOLS_VERSION", 
                      "TEST_TARGET_ID", "DEVELOPMENT_TEAM", "DEVELOPMENT_TEAM_NAME", 
                      "PROVISIONING_STYLE", "COMPATIBILITY_VERSION", "DEVELOPMENT_REGION", 
                      "HAS_SCANNED_FOR_ENCODINGS", "KNOWN_REGIONS", "MAIN_GROUP", 
                      "PRODUCT_REF_GROUP", "PACKAGE_REFERENCES", "PREFERRED_PROJECT_OBJECT_VERSION", 
                      "PRODUCT_DIR_PATH", "PROJECT_REFERENCES", "PROJECT_ROOT", 
                      "TARGETS", "INPUT_FILE_LIST_PATHS", "INPUT_PATHS", 
                      "OUTPUT_FILE_LIST_PATHS", "OUTPUT_PATHS", "SHELL_PATH", 
                      "SHELL", "SHELL_SCRIPT", "SHOW_ENV_VARS_IN_LOG", "TARGET", 
                      "TARGET_PROXY", "FILE_TYPE", "REMOTE_REF", "BASE_CONFIGURATION_REFERENCE", 
                      "BUILD_SETTINGS", "BUILD_STYLES", "DST_PATH", "DST_SUBFOLDER_SPEC", 
                      "PRODUCT_GROUP", "PROJECT_REF", "BUILD_CONFIGURATIONS", 
                      "DEFAULT_CONFIGURATION_IS_VISIBLE", "DEFAULT_CONFIGURATION_NAME", 
                      "SETTINGS", "SYSTEM_CAPABILITIES", "CURRENT_VERSION", 
                      "VERSION_GROUP_TYPE", "MEMBERSHIP_EXCEPTIONS", "EXCEPTIONS", 
                      "CLASSPREFIX", "REFERENCE", "QUOTED_STRING", "NON_QUOTED_STRING", 
                      "VARIABLE", "ALPHA_NUMERIC", "ALPHA_NUMERIC_CAP", 
                      "WS", "COMMENT", "LINE_COMMENT" ]

    RULE_start = 0
    RULE_root_element = 1
    RULE_archive_version = 2
    RULE_classes = 3
    RULE_object_version = 4
    RULE_objects = 5
    RULE_root_object = 6
    RULE_pbx_aggregate_target_section = 7
    RULE_pbx_build_file_section = 8
    RULE_pbx_build_rule_section = 9
    RULE_pbx_build_style_section = 10
    RULE_pbx_container_item_proxy_section = 11
    RULE_pbx_copy_files_build_phase_section = 12
    RULE_pbx_file_reference_section = 13
    RULE_pbx_file_system_synchronized_build_file_exception_set_section = 14
    RULE_pbx_file_system_synchronized_root_group_section = 15
    RULE_pbx_frameworks_build_phase_section = 16
    RULE_pbx_group_section = 17
    RULE_pbx_headers_build_phase_section = 18
    RULE_pbx_native_target_section = 19
    RULE_pbx_legacy_target_section = 20
    RULE_pbx_project_section = 21
    RULE_pbx_reference_proxy_section = 22
    RULE_pbx_resources_build_phase_section = 23
    RULE_pbx_shell_script_build_phase_section = 24
    RULE_pbx_shell_build_phase_section = 25
    RULE_pbx_sources_build_phase_section = 26
    RULE_pbx_target_dependency_section = 27
    RULE_pbx_variant_group_section = 28
    RULE_xc_build_configuration_section = 29
    RULE_xc_configuration_list_section = 30
    RULE_xc_remote_swift_package_reference_section = 31
    RULE_xc_swift_package_product_dependency_section = 32
    RULE_xc_version_group_section = 33
    RULE_pbx_aggregate_target = 34
    RULE_pbx_build_file = 35
    RULE_pbx_build_rule = 36
    RULE_pbx_build_style = 37
    RULE_pbx_container_item_proxy = 38
    RULE_pbx_copy_files_build_phase = 39
    RULE_pbx_file_reference = 40
    RULE_pbx_file_system_synchronized_build_file_exception_set = 41
    RULE_pbx_file_system_synchronized_root_group = 42
    RULE_pbx_frameworks_build_phase = 43
    RULE_pbx_group = 44
    RULE_pbx_headers_build_phase = 45
    RULE_pbx_native_target = 46
    RULE_pbx_legacy_target = 47
    RULE_pbx_project = 48
    RULE_pbx_reference_proxy = 49
    RULE_pbx_resources_build_phase = 50
    RULE_pbx_shell_script_build_phase = 51
    RULE_pbx_shell_build_phase = 52
    RULE_pbx_sources_build_phase = 53
    RULE_pbx_target_dependency = 54
    RULE_pbx_variant_group = 55
    RULE_xc_build_configuration = 56
    RULE_xc_configuration_list = 57
    RULE_xc_remote_swift_package_reference = 58
    RULE_xc_swift_package_product_dependency = 59
    RULE_xc_version_group = 60
    RULE_isa_pbx_aggregate_target = 61
    RULE_isa_pbx_build_file = 62
    RULE_isa_pbx_build_rule = 63
    RULE_isa_pbx_build_style = 64
    RULE_isa_pbx_container_item_proxy = 65
    RULE_isa_pbx_copy_files_build_phase = 66
    RULE_isa_pbx_file_reference = 67
    RULE_isa_pbx_file_system_synchronized_build_file_exception_set = 68
    RULE_isa_pbx_file_system_synchronized_root_group = 69
    RULE_isa_pbx_frameworks_build_phase = 70
    RULE_isa_pbx_group = 71
    RULE_isa_pbx_header_build_phase = 72
    RULE_isa_pbx_native_target = 73
    RULE_isa_pbx_legacy_target = 74
    RULE_isa_pbx_project = 75
    RULE_isa_pbx_reference_proxy = 76
    RULE_isa_pbx_resources_build_phase = 77
    RULE_isa_pbx_shell_script_build_phase = 78
    RULE_isa_pbx_shell_build_phase = 79
    RULE_isa_pbx_sources_build_phase = 80
    RULE_isa_pbx_target_dependency = 81
    RULE_isa_pbx_variant_group = 82
    RULE_isa_xc_build_configuration = 83
    RULE_isa_xc_configuration_list = 84
    RULE_isa_xc_remote_swift_package_reference = 85
    RULE_isa_xc_swift_package_product_dependency = 86
    RULE_isa_xc_version_group = 87
    RULE_always_out_of_date = 88
    RULE_file_ref = 89
    RULE_product_ref = 90
    RULE_container_portal = 91
    RULE_proxy_type = 92
    RULE_remote_global_id_string = 93
    RULE_remote_info = 94
    RULE_file_encoding = 95
    RULE_comments = 96
    RULE_explicit_file_type = 97
    RULE_explicit_file_types = 98
    RULE_explicit_folders = 99
    RULE_last_known_file_type = 100
    RULE_include_in_index = 101
    RULE_indent_width = 102
    RULE_tab_width = 103
    RULE_uses_tabs = 104
    RULE_wraps_lines = 105
    RULE_platform_filter = 106
    RULE_platform_filters = 107
    RULE_children = 108
    RULE_product_install_path = 109
    RULE_repository_url = 110
    RULE_requirement = 111
    RULE_xc_package = 112
    RULE_package_product_dependencies = 113
    RULE_name = 114
    RULE_path = 115
    RULE_source_tree = 116
    RULE_build_action_mask = 117
    RULE_files = 118
    RULE_run_only_for_deployment_postprocessing = 119
    RULE_reference_list = 120
    RULE_any_string_list = 121
    RULE_non_quoted_strings_list = 122
    RULE_build_configuration_list = 123
    RULE_build_phases = 124
    RULE_build_rules = 125
    RULE_build_arguments_string = 126
    RULE_build_tool_path = 127
    RULE_build_working_directory = 128
    RULE_pass_build_settings_in_environment = 129
    RULE_dependencies = 130
    RULE_product_name = 131
    RULE_product_reference = 132
    RULE_product_type = 133
    RULE_line_ending = 134
    RULE_xc_language_specification_identifier = 135
    RULE_plist_structure_definition_identifier = 136
    RULE_ref_type = 137
    RULE_compiler_spec = 138
    RULE_file_patterns = 139
    RULE_input_files = 140
    RULE_is_editable = 141
    RULE_output_files = 142
    RULE_run_once_per_arch = 143
    RULE_script = 144
    RULE_attributes = 145
    RULE_last_swift_migration = 146
    RULE_default_build_system_type_for_workspace = 147
    RULE_last_swift_update_check = 148
    RULE_build_targets_in_parallel = 149
    RULE_last_testing_upgrade_check = 150
    RULE_last_upgrade_check = 151
    RULE_organization_name = 152
    RULE_target_attributes = 153
    RULE_target_attribute = 154
    RULE_created_on_tools_version = 155
    RULE_test_target_id = 156
    RULE_development_team = 157
    RULE_development_team_name = 158
    RULE_provisioning_style = 159
    RULE_compatibility_version = 160
    RULE_development_region = 161
    RULE_has_scanned_for_encodings = 162
    RULE_known_regions = 163
    RULE_main_group = 164
    RULE_product_ref_group = 165
    RULE_package_references = 166
    RULE_preferred_project_object_version = 167
    RULE_project_dir_path = 168
    RULE_project_references = 169
    RULE_project_root = 170
    RULE_targets = 171
    RULE_input_file_list_paths = 172
    RULE_input_paths = 173
    RULE_output_file_list_paths = 174
    RULE_output_paths = 175
    RULE_shell_path = 176
    RULE_shell = 177
    RULE_shell_script = 178
    RULE_show_env_vars_in_log = 179
    RULE_target = 180
    RULE_target_proxy = 181
    RULE_file_type = 182
    RULE_remote_ref = 183
    RULE_base_configuration_reference = 184
    RULE_build_settings = 185
    RULE_build_styles = 186
    RULE_dst_path = 187
    RULE_dst_subfolder_spec = 188
    RULE_project_references_list = 189
    RULE_project_references_list_element = 190
    RULE_membership_exceptions = 191
    RULE_exceptions = 192
    RULE_key_value = 193
    RULE_build_configurations = 194
    RULE_default_configuration_is_visible = 195
    RULE_default_configuration_name = 196
    RULE_settings = 197
    RULE_system_capabilities = 198
    RULE_current_version = 199
    RULE_version_group_type = 200
    RULE_class_prefix = 201
    RULE_any_string = 202
    RULE_str_number_variable = 203
    RULE_any_token = 204

    ruleNames =  [ "start", "root_element", "archive_version", "classes", 
                   "object_version", "objects", "root_object", "pbx_aggregate_target_section", 
                   "pbx_build_file_section", "pbx_build_rule_section", "pbx_build_style_section", 
                   "pbx_container_item_proxy_section", "pbx_copy_files_build_phase_section", 
                   "pbx_file_reference_section", "pbx_file_system_synchronized_build_file_exception_set_section", 
                   "pbx_file_system_synchronized_root_group_section", "pbx_frameworks_build_phase_section", 
                   "pbx_group_section", "pbx_headers_build_phase_section", 
                   "pbx_native_target_section", "pbx_legacy_target_section", 
                   "pbx_project_section", "pbx_reference_proxy_section", 
                   "pbx_resources_build_phase_section", "pbx_shell_script_build_phase_section", 
                   "pbx_shell_build_phase_section", "pbx_sources_build_phase_section", 
                   "pbx_target_dependency_section", "pbx_variant_group_section", 
                   "xc_build_configuration_section", "xc_configuration_list_section", 
                   "xc_remote_swift_package_reference_section", "xc_swift_package_product_dependency_section", 
                   "xc_version_group_section", "pbx_aggregate_target", "pbx_build_file", 
                   "pbx_build_rule", "pbx_build_style", "pbx_container_item_proxy", 
                   "pbx_copy_files_build_phase", "pbx_file_reference", "pbx_file_system_synchronized_build_file_exception_set", 
                   "pbx_file_system_synchronized_root_group", "pbx_frameworks_build_phase", 
                   "pbx_group", "pbx_headers_build_phase", "pbx_native_target", 
                   "pbx_legacy_target", "pbx_project", "pbx_reference_proxy", 
                   "pbx_resources_build_phase", "pbx_shell_script_build_phase", 
                   "pbx_shell_build_phase", "pbx_sources_build_phase", "pbx_target_dependency", 
                   "pbx_variant_group", "xc_build_configuration", "xc_configuration_list", 
                   "xc_remote_swift_package_reference", "xc_swift_package_product_dependency", 
                   "xc_version_group", "isa_pbx_aggregate_target", "isa_pbx_build_file", 
                   "isa_pbx_build_rule", "isa_pbx_build_style", "isa_pbx_container_item_proxy", 
                   "isa_pbx_copy_files_build_phase", "isa_pbx_file_reference", 
                   "isa_pbx_file_system_synchronized_build_file_exception_set", 
                   "isa_pbx_file_system_synchronized_root_group", "isa_pbx_frameworks_build_phase", 
                   "isa_pbx_group", "isa_pbx_header_build_phase", "isa_pbx_native_target", 
                   "isa_pbx_legacy_target", "isa_pbx_project", "isa_pbx_reference_proxy", 
                   "isa_pbx_resources_build_phase", "isa_pbx_shell_script_build_phase", 
                   "isa_pbx_shell_build_phase", "isa_pbx_sources_build_phase", 
                   "isa_pbx_target_dependency", "isa_pbx_variant_group", 
                   "isa_xc_build_configuration", "isa_xc_configuration_list", 
                   "isa_xc_remote_swift_package_reference", "isa_xc_swift_package_product_dependency", 
                   "isa_xc_version_group", "always_out_of_date", "file_ref", 
                   "product_ref", "container_portal", "proxy_type", "remote_global_id_string", 
                   "remote_info", "file_encoding", "comments", "explicit_file_type", 
                   "explicit_file_types", "explicit_folders", "last_known_file_type", 
                   "include_in_index", "indent_width", "tab_width", "uses_tabs", 
                   "wraps_lines", "platform_filter", "platform_filters", 
                   "children", "product_install_path", "repository_url", 
                   "requirement", "xc_package", "package_product_dependencies", 
                   "name", "path", "source_tree", "build_action_mask", "files", 
                   "run_only_for_deployment_postprocessing", "reference_list", 
                   "any_string_list", "non_quoted_strings_list", "build_configuration_list", 
                   "build_phases", "build_rules", "build_arguments_string", 
                   "build_tool_path", "build_working_directory", "pass_build_settings_in_environment", 
                   "dependencies", "product_name", "product_reference", 
                   "product_type", "line_ending", "xc_language_specification_identifier", 
                   "plist_structure_definition_identifier", "ref_type", 
                   "compiler_spec", "file_patterns", "input_files", "is_editable", 
                   "output_files", "run_once_per_arch", "script", "attributes", 
                   "last_swift_migration", "default_build_system_type_for_workspace", 
                   "last_swift_update_check", "build_targets_in_parallel", 
                   "last_testing_upgrade_check", "last_upgrade_check", "organization_name", 
                   "target_attributes", "target_attribute", "created_on_tools_version", 
                   "test_target_id", "development_team", "development_team_name", 
                   "provisioning_style", "compatibility_version", "development_region", 
                   "has_scanned_for_encodings", "known_regions", "main_group", 
                   "product_ref_group", "package_references", "preferred_project_object_version", 
                   "project_dir_path", "project_references", "project_root", 
                   "targets", "input_file_list_paths", "input_paths", "output_file_list_paths", 
                   "output_paths", "shell_path", "shell", "shell_script", 
                   "show_env_vars_in_log", "target", "target_proxy", "file_type", 
                   "remote_ref", "base_configuration_reference", "build_settings", 
                   "build_styles", "dst_path", "dst_subfolder_spec", "project_references_list", 
                   "project_references_list_element", "membership_exceptions", 
                   "exceptions", "key_value", "build_configurations", "default_configuration_is_visible", 
                   "default_configuration_name", "settings", "system_capabilities", 
                   "current_version", "version_group_type", "class_prefix", 
                   "any_string", "str_number_variable", "any_token" ]

    EOF = Token.EOF
    T__0=1
    T__1=2
    T__2=3
    T__3=4
    T__4=5
    T__5=6
    T__6=7
    ARCHIVE_VERSION=8
    CLASSES=9
    DASH=10
    DOT=11
    ISA=12
    NUMBER=13
    OBJECT_VERSION=14
    OBJECTS=15
    ROOT_OBJECT=16
    SLASH=17
    UNDERSCORE=18
    DOLLAR=19
    PBX_AGGREGATE_TARGET=20
    PBX_BUILD_FILE=21
    PBX_BUILD_RULE=22
    PBX_BUILD_STYLE=23
    PBX_CONTAINER_ITEM_PROXY=24
    PBX_COPY_FILES_BUILD_PHASE=25
    PBX_FILE_REFERENCE=26
    PBX_FILE_SYSTEM_SYNCHRONIZED_BUILD_FILE_EXCEPTION_SET=27
    PBX_FILE_SYSTEM_SYNCHRONIZED_ROOT_GROUP=28
    PBX_FRAMEWORKS_BUILD_PHASE=29
    PBX_GROUP=30
    PBX_HEADERS_BUILD_PHASE=31
    PBX_NATIVE_TARGET=32
    PBX_LEGACY_TARGET=33
    PBX_PROJECT=34
    PBX_REFERENCE_PROXY=35
    PBX_RESOURCES_BUILD_PHASE=36
    PBX_SHELL_SCRIPT_BUILD_PHASE=37
    PBX_SHELL_BUILD_PHASE=38
    PBX_SOURCES_BUILD_PHASE=39
    PBX_TARGET_DEPENDENCY=40
    PBX_VARIANT_GROUP=41
    XC_BUILD_CONFIGURATION=42
    XC_CONFIGURATION_LIST=43
    XC_REMOTE_SWIFT_PACKAGE_REFERENCE=44
    XC_SWIFT_PACKAGE_PRODUCT_DEPENDENCY=45
    XC_VERSION_GROUP=46
    ALWAYS_OUT_OF_DATE=47
    FILE_REF=48
    PRODUCT_REF=49
    CONTAINER_PORTAL=50
    PROXY_TYPE=51
    REMOTE_GLOBAL_ID_STRING=52
    REMOTE_INFO=53
    FILE_ENCODING=54
    COMMENTS=55
    EXPLICIT_FILE_TYPE=56
    EXPLICIT_FILE_TYPES=57
    EXPLICIT_FOLDERS=58
    LAST_KNOWN_FILE_TYPE=59
    INCLUDE_IN_INDEX=60
    INDENT_WIDTH=61
    TAB_WIDTH=62
    USES_TABS=63
    WRAPS_LINES=64
    PLATFORM_FILTER=65
    PLATFORM_FILTERS=66
    CHILDREN=67
    PRODUCT_INSTALL_PATH=68
    REPOSITORY_URL=69
    REQUIREMENT=70
    PACKAGE=71
    PACKAGE_PRODUCT_DEPENDENCIES=72
    NAME=73
    PATH=74
    SOURCE_TREE=75
    BUILD_ACTION_MASK=76
    FILES=77
    RUN_ONLY_FOR_DEPLOYMENT_POSTPROCESSING=78
    BUILD_CONFIGURATION_LIST=79
    BUILD_PHASES=80
    BUILD_RULES=81
    BUILD_ARGUMENTS_STRING=82
    BUILD_TOOL_PATH=83
    BUILD_WORKING_DIRECTORY=84
    PASS_BUILD_SETTINGS_IN_ENVIRONMENT=85
    DEPENDENCIES=86
    PRODUCT_NAME=87
    PRODUCT_REFERENCE=88
    PRODUCT_TYPE=89
    LINE_ENDING=90
    XC_LANGUAGE_SPECIFICATION_IDENTIFIER=91
    PLIST_STRUCTURE_DEFINITION_IDENTIFIER=92
    REF_TYPE=93
    COMPILER_SPEC=94
    FILE_PATTERNS=95
    INPUT_FILES=96
    IS_EDITABLE=97
    OUTPUT_FILES=98
    RUN_ONCE_PER_ARCH=99
    SCRIPT=100
    ATTRIBUTES=101
    LAST_SWIFT_MIGRATION=102
    DEFAULT_BUILD_SYSTEM_TYPE_FOR_WORKSPACE=103
    LAST_SWIFT_UPDATE_CHECK=104
    BUILD_INDEPENDENT_TARGETS_IN_PARALLEL=105
    LAST_TESTING_UPGRADE_CHECK=106
    LAST_UPGRADE_CHECK=107
    ORGANIZATION_NAME=108
    TARGET_ATTRIBUTES=109
    CREATED_ON_TOOLS_VERSION=110
    TEST_TARGET_ID=111
    DEVELOPMENT_TEAM=112
    DEVELOPMENT_TEAM_NAME=113
    PROVISIONING_STYLE=114
    COMPATIBILITY_VERSION=115
    DEVELOPMENT_REGION=116
    HAS_SCANNED_FOR_ENCODINGS=117
    KNOWN_REGIONS=118
    MAIN_GROUP=119
    PRODUCT_REF_GROUP=120
    PACKAGE_REFERENCES=121
    PREFERRED_PROJECT_OBJECT_VERSION=122
    PRODUCT_DIR_PATH=123
    PROJECT_REFERENCES=124
    PROJECT_ROOT=125
    TARGETS=126
    INPUT_FILE_LIST_PATHS=127
    INPUT_PATHS=128
    OUTPUT_FILE_LIST_PATHS=129
    OUTPUT_PATHS=130
    SHELL_PATH=131
    SHELL=132
    SHELL_SCRIPT=133
    SHOW_ENV_VARS_IN_LOG=134
    TARGET=135
    TARGET_PROXY=136
    FILE_TYPE=137
    REMOTE_REF=138
    BASE_CONFIGURATION_REFERENCE=139
    BUILD_SETTINGS=140
    BUILD_STYLES=141
    DST_PATH=142
    DST_SUBFOLDER_SPEC=143
    PRODUCT_GROUP=144
    PROJECT_REF=145
    BUILD_CONFIGURATIONS=146
    DEFAULT_CONFIGURATION_IS_VISIBLE=147
    DEFAULT_CONFIGURATION_NAME=148
    SETTINGS=149
    SYSTEM_CAPABILITIES=150
    CURRENT_VERSION=151
    VERSION_GROUP_TYPE=152
    MEMBERSHIP_EXCEPTIONS=153
    EXCEPTIONS=154
    CLASSPREFIX=155
    REFERENCE=156
    QUOTED_STRING=157
    NON_QUOTED_STRING=158
    VARIABLE=159
    ALPHA_NUMERIC=160
    ALPHA_NUMERIC_CAP=161
    WS=162
    COMMENT=163
    LINE_COMMENT=164

    def __init__(self, input:TokenStream, output:TextIO = sys.stdout):
        super().__init__(input, output)
        self.checkVersion("4.13.1")
        self._interp = ParserATNSimulator(self, self.atn, self.decisionsToDFA, self.sharedContextCache)
        self._predicates = None




    class StartContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def root_element(self):
            return self.getTypedRuleContext(PBXProjParser.Root_elementContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_start

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterStart" ):
                listener.enterStart(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitStart" ):
                listener.exitStart(self)




    def start(self):

        localctx = PBXProjParser.StartContext(self, self._ctx, self.state)
        self.enterRule(localctx, 0, self.RULE_start)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 410
            self.root_element()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Root_elementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def archive_version(self):
            return self.getTypedRuleContext(PBXProjParser.Archive_versionContext,0)


        def classes(self):
            return self.getTypedRuleContext(PBXProjParser.ClassesContext,0)


        def object_version(self):
            return self.getTypedRuleContext(PBXProjParser.Object_versionContext,0)


        def objects(self):
            return self.getTypedRuleContext(PBXProjParser.ObjectsContext,0)


        def root_object(self):
            return self.getTypedRuleContext(PBXProjParser.Root_objectContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_root_element

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRoot_element" ):
                listener.enterRoot_element(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRoot_element" ):
                listener.exitRoot_element(self)




    def root_element(self):

        localctx = PBXProjParser.Root_elementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 2, self.RULE_root_element)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 412
            self.match(PBXProjParser.T__0)
            self.state = 413
            self.archive_version()
            self.state = 414
            self.classes()
            self.state = 415
            self.object_version()
            self.state = 416
            self.objects()
            self.state = 417
            self.root_object()
            self.state = 418
            self.match(PBXProjParser.T__1)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Archive_versionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ARCHIVE_VERSION(self):
            return self.getToken(PBXProjParser.ARCHIVE_VERSION, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_archive_version

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterArchive_version" ):
                listener.enterArchive_version(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitArchive_version" ):
                listener.exitArchive_version(self)




    def archive_version(self):

        localctx = PBXProjParser.Archive_versionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 4, self.RULE_archive_version)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 420
            self.match(PBXProjParser.ARCHIVE_VERSION)
            self.state = 421
            self.match(PBXProjParser.T__2)
            self.state = 422
            self.match(PBXProjParser.NUMBER)
            self.state = 423
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ClassesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CLASSES(self):
            return self.getToken(PBXProjParser.CLASSES, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_classes

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterClasses" ):
                listener.enterClasses(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitClasses" ):
                listener.exitClasses(self)




    def classes(self):

        localctx = PBXProjParser.ClassesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 6, self.RULE_classes)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 425
            self.match(PBXProjParser.CLASSES)
            self.state = 426
            self.match(PBXProjParser.T__2)
            self.state = 427
            self.match(PBXProjParser.T__0)
            self.state = 428
            self.match(PBXProjParser.T__1)
            self.state = 429
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Object_versionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def OBJECT_VERSION(self):
            return self.getToken(PBXProjParser.OBJECT_VERSION, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_object_version

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterObject_version" ):
                listener.enterObject_version(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitObject_version" ):
                listener.exitObject_version(self)




    def object_version(self):

        localctx = PBXProjParser.Object_versionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 8, self.RULE_object_version)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 431
            self.match(PBXProjParser.OBJECT_VERSION)
            self.state = 432
            self.match(PBXProjParser.T__2)
            self.state = 433
            self.match(PBXProjParser.NUMBER)
            self.state = 434
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ObjectsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def OBJECTS(self):
            return self.getToken(PBXProjParser.OBJECTS, 0)

        def pbx_group_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_group_sectionContext,0)


        def pbx_project_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_project_sectionContext,0)


        def xc_build_configuration_section(self):
            return self.getTypedRuleContext(PBXProjParser.Xc_build_configuration_sectionContext,0)


        def xc_configuration_list_section(self):
            return self.getTypedRuleContext(PBXProjParser.Xc_configuration_list_sectionContext,0)


        def pbx_aggregate_target_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_aggregate_target_sectionContext,0)


        def pbx_build_file_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_build_file_sectionContext,0)


        def pbx_build_rule_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_build_rule_sectionContext,0)


        def pbx_build_style_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_build_style_sectionContext,0)


        def pbx_container_item_proxy_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_container_item_proxy_sectionContext,0)


        def pbx_copy_files_build_phase_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_copy_files_build_phase_sectionContext,0)


        def pbx_file_reference_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_file_reference_sectionContext,0)


        def pbx_file_system_synchronized_build_file_exception_set_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_file_system_synchronized_build_file_exception_set_sectionContext,0)


        def pbx_file_system_synchronized_root_group_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_file_system_synchronized_root_group_sectionContext,0)


        def pbx_frameworks_build_phase_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_frameworks_build_phase_sectionContext,0)


        def pbx_headers_build_phase_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_headers_build_phase_sectionContext,0)


        def pbx_legacy_target_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_legacy_target_sectionContext,0)


        def pbx_native_target_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_native_target_sectionContext,0)


        def pbx_reference_proxy_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_reference_proxy_sectionContext,0)


        def pbx_resources_build_phase_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_resources_build_phase_sectionContext,0)


        def pbx_shell_script_build_phase_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_shell_script_build_phase_sectionContext,0)


        def pbx_shell_build_phase_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_shell_build_phase_sectionContext,0)


        def pbx_sources_build_phase_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_sources_build_phase_sectionContext,0)


        def pbx_target_dependency_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_target_dependency_sectionContext,0)


        def pbx_variant_group_section(self):
            return self.getTypedRuleContext(PBXProjParser.Pbx_variant_group_sectionContext,0)


        def xc_remote_swift_package_reference_section(self):
            return self.getTypedRuleContext(PBXProjParser.Xc_remote_swift_package_reference_sectionContext,0)


        def xc_swift_package_product_dependency_section(self):
            return self.getTypedRuleContext(PBXProjParser.Xc_swift_package_product_dependency_sectionContext,0)


        def xc_version_group_section(self):
            return self.getTypedRuleContext(PBXProjParser.Xc_version_group_sectionContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_objects

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterObjects" ):
                listener.enterObjects(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitObjects" ):
                listener.exitObjects(self)




    def objects(self):

        localctx = PBXProjParser.ObjectsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 10, self.RULE_objects)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 436
            self.match(PBXProjParser.OBJECTS)
            self.state = 437
            self.match(PBXProjParser.T__2)
            self.state = 438
            self.match(PBXProjParser.T__0)
            self.state = 440
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,0,self._ctx)
            if la_ == 1:
                self.state = 439
                self.pbx_aggregate_target_section()


            self.state = 443
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,1,self._ctx)
            if la_ == 1:
                self.state = 442
                self.pbx_build_file_section()


            self.state = 446
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,2,self._ctx)
            if la_ == 1:
                self.state = 445
                self.pbx_build_rule_section()


            self.state = 449
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,3,self._ctx)
            if la_ == 1:
                self.state = 448
                self.pbx_build_style_section()


            self.state = 452
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,4,self._ctx)
            if la_ == 1:
                self.state = 451
                self.pbx_container_item_proxy_section()


            self.state = 455
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,5,self._ctx)
            if la_ == 1:
                self.state = 454
                self.pbx_copy_files_build_phase_section()


            self.state = 458
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,6,self._ctx)
            if la_ == 1:
                self.state = 457
                self.pbx_file_reference_section()


            self.state = 461
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,7,self._ctx)
            if la_ == 1:
                self.state = 460
                self.pbx_file_system_synchronized_build_file_exception_set_section()


            self.state = 464
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,8,self._ctx)
            if la_ == 1:
                self.state = 463
                self.pbx_file_system_synchronized_root_group_section()


            self.state = 467
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,9,self._ctx)
            if la_ == 1:
                self.state = 466
                self.pbx_frameworks_build_phase_section()


            self.state = 469
            self.pbx_group_section()
            self.state = 471
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,10,self._ctx)
            if la_ == 1:
                self.state = 470
                self.pbx_headers_build_phase_section()


            self.state = 474
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,11,self._ctx)
            if la_ == 1:
                self.state = 473
                self.pbx_legacy_target_section()


            self.state = 477
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,12,self._ctx)
            if la_ == 1:
                self.state = 476
                self.pbx_native_target_section()


            self.state = 479
            self.pbx_project_section()
            self.state = 481
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,13,self._ctx)
            if la_ == 1:
                self.state = 480
                self.pbx_reference_proxy_section()


            self.state = 484
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,14,self._ctx)
            if la_ == 1:
                self.state = 483
                self.pbx_resources_build_phase_section()


            self.state = 487
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,15,self._ctx)
            if la_ == 1:
                self.state = 486
                self.pbx_shell_script_build_phase_section()


            self.state = 490
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,16,self._ctx)
            if la_ == 1:
                self.state = 489
                self.pbx_shell_build_phase_section()


            self.state = 493
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,17,self._ctx)
            if la_ == 1:
                self.state = 492
                self.pbx_sources_build_phase_section()


            self.state = 496
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,18,self._ctx)
            if la_ == 1:
                self.state = 495
                self.pbx_target_dependency_section()


            self.state = 499
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,19,self._ctx)
            if la_ == 1:
                self.state = 498
                self.pbx_variant_group_section()


            self.state = 501
            self.xc_build_configuration_section()
            self.state = 502
            self.xc_configuration_list_section()
            self.state = 504
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,20,self._ctx)
            if la_ == 1:
                self.state = 503
                self.xc_remote_swift_package_reference_section()


            self.state = 507
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,21,self._ctx)
            if la_ == 1:
                self.state = 506
                self.xc_swift_package_product_dependency_section()


            self.state = 510
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==156:
                self.state = 509
                self.xc_version_group_section()


            self.state = 512
            self.match(PBXProjParser.T__1)
            self.state = 513
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Root_objectContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ROOT_OBJECT(self):
            return self.getToken(PBXProjParser.ROOT_OBJECT, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_root_object

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRoot_object" ):
                listener.enterRoot_object(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRoot_object" ):
                listener.exitRoot_object(self)




    def root_object(self):

        localctx = PBXProjParser.Root_objectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 12, self.RULE_root_object)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 515
            self.match(PBXProjParser.ROOT_OBJECT)
            self.state = 516
            self.match(PBXProjParser.T__2)
            self.state = 517
            self.match(PBXProjParser.REFERENCE)
            self.state = 518
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_aggregate_target_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_aggregate_target(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_aggregate_targetContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_aggregate_targetContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_aggregate_target_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_aggregate_target_section" ):
                listener.enterPbx_aggregate_target_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_aggregate_target_section" ):
                listener.exitPbx_aggregate_target_section(self)




    def pbx_aggregate_target_section(self):

        localctx = PBXProjParser.Pbx_aggregate_target_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 14, self.RULE_pbx_aggregate_target_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 521 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 520
                    self.pbx_aggregate_target()

                else:
                    raise NoViableAltException(self)
                self.state = 523 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,23,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_build_file_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_build_file(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_build_fileContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_build_fileContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_build_file_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_build_file_section" ):
                listener.enterPbx_build_file_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_build_file_section" ):
                listener.exitPbx_build_file_section(self)




    def pbx_build_file_section(self):

        localctx = PBXProjParser.Pbx_build_file_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 16, self.RULE_pbx_build_file_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 526 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 525
                    self.pbx_build_file()

                else:
                    raise NoViableAltException(self)
                self.state = 528 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,24,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_build_rule_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_build_rule(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_build_ruleContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_build_ruleContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_build_rule_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_build_rule_section" ):
                listener.enterPbx_build_rule_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_build_rule_section" ):
                listener.exitPbx_build_rule_section(self)




    def pbx_build_rule_section(self):

        localctx = PBXProjParser.Pbx_build_rule_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 18, self.RULE_pbx_build_rule_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 531 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 530
                    self.pbx_build_rule()

                else:
                    raise NoViableAltException(self)
                self.state = 533 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,25,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_build_style_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_build_style(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_build_styleContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_build_styleContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_build_style_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_build_style_section" ):
                listener.enterPbx_build_style_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_build_style_section" ):
                listener.exitPbx_build_style_section(self)




    def pbx_build_style_section(self):

        localctx = PBXProjParser.Pbx_build_style_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 20, self.RULE_pbx_build_style_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 536 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 535
                    self.pbx_build_style()

                else:
                    raise NoViableAltException(self)
                self.state = 538 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,26,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_container_item_proxy_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_container_item_proxy(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_container_item_proxyContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_container_item_proxyContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_container_item_proxy_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_container_item_proxy_section" ):
                listener.enterPbx_container_item_proxy_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_container_item_proxy_section" ):
                listener.exitPbx_container_item_proxy_section(self)




    def pbx_container_item_proxy_section(self):

        localctx = PBXProjParser.Pbx_container_item_proxy_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 22, self.RULE_pbx_container_item_proxy_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 541 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 540
                    self.pbx_container_item_proxy()

                else:
                    raise NoViableAltException(self)
                self.state = 543 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,27,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_copy_files_build_phase_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_copy_files_build_phase(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_copy_files_build_phaseContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_copy_files_build_phaseContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_copy_files_build_phase_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_copy_files_build_phase_section" ):
                listener.enterPbx_copy_files_build_phase_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_copy_files_build_phase_section" ):
                listener.exitPbx_copy_files_build_phase_section(self)




    def pbx_copy_files_build_phase_section(self):

        localctx = PBXProjParser.Pbx_copy_files_build_phase_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 24, self.RULE_pbx_copy_files_build_phase_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 546 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 545
                    self.pbx_copy_files_build_phase()

                else:
                    raise NoViableAltException(self)
                self.state = 548 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,28,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_file_reference_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_file_reference(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_file_referenceContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_file_referenceContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_file_reference_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_file_reference_section" ):
                listener.enterPbx_file_reference_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_file_reference_section" ):
                listener.exitPbx_file_reference_section(self)




    def pbx_file_reference_section(self):

        localctx = PBXProjParser.Pbx_file_reference_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 26, self.RULE_pbx_file_reference_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 551 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 550
                    self.pbx_file_reference()

                else:
                    raise NoViableAltException(self)
                self.state = 553 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,29,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_file_system_synchronized_build_file_exception_set_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_file_system_synchronized_build_file_exception_set(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_file_system_synchronized_build_file_exception_setContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_file_system_synchronized_build_file_exception_setContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_file_system_synchronized_build_file_exception_set_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_file_system_synchronized_build_file_exception_set_section" ):
                listener.enterPbx_file_system_synchronized_build_file_exception_set_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_file_system_synchronized_build_file_exception_set_section" ):
                listener.exitPbx_file_system_synchronized_build_file_exception_set_section(self)




    def pbx_file_system_synchronized_build_file_exception_set_section(self):

        localctx = PBXProjParser.Pbx_file_system_synchronized_build_file_exception_set_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 28, self.RULE_pbx_file_system_synchronized_build_file_exception_set_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 556 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 555
                    self.pbx_file_system_synchronized_build_file_exception_set()

                else:
                    raise NoViableAltException(self)
                self.state = 558 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,30,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_file_system_synchronized_root_group_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_file_system_synchronized_root_group(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_file_system_synchronized_root_groupContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_file_system_synchronized_root_groupContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_file_system_synchronized_root_group_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_file_system_synchronized_root_group_section" ):
                listener.enterPbx_file_system_synchronized_root_group_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_file_system_synchronized_root_group_section" ):
                listener.exitPbx_file_system_synchronized_root_group_section(self)




    def pbx_file_system_synchronized_root_group_section(self):

        localctx = PBXProjParser.Pbx_file_system_synchronized_root_group_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 30, self.RULE_pbx_file_system_synchronized_root_group_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 561 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 560
                    self.pbx_file_system_synchronized_root_group()

                else:
                    raise NoViableAltException(self)
                self.state = 563 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,31,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_frameworks_build_phase_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_frameworks_build_phase(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_frameworks_build_phaseContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_frameworks_build_phaseContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_frameworks_build_phase_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_frameworks_build_phase_section" ):
                listener.enterPbx_frameworks_build_phase_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_frameworks_build_phase_section" ):
                listener.exitPbx_frameworks_build_phase_section(self)




    def pbx_frameworks_build_phase_section(self):

        localctx = PBXProjParser.Pbx_frameworks_build_phase_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 32, self.RULE_pbx_frameworks_build_phase_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 566 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 565
                    self.pbx_frameworks_build_phase()

                else:
                    raise NoViableAltException(self)
                self.state = 568 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,32,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_group_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_group(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_groupContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_groupContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_group_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_group_section" ):
                listener.enterPbx_group_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_group_section" ):
                listener.exitPbx_group_section(self)




    def pbx_group_section(self):

        localctx = PBXProjParser.Pbx_group_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 34, self.RULE_pbx_group_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 571 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 570
                    self.pbx_group()

                else:
                    raise NoViableAltException(self)
                self.state = 573 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,33,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_headers_build_phase_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_headers_build_phase(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_headers_build_phaseContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_headers_build_phaseContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_headers_build_phase_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_headers_build_phase_section" ):
                listener.enterPbx_headers_build_phase_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_headers_build_phase_section" ):
                listener.exitPbx_headers_build_phase_section(self)




    def pbx_headers_build_phase_section(self):

        localctx = PBXProjParser.Pbx_headers_build_phase_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 36, self.RULE_pbx_headers_build_phase_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 576 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 575
                    self.pbx_headers_build_phase()

                else:
                    raise NoViableAltException(self)
                self.state = 578 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,34,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_native_target_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_native_target(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_native_targetContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_native_targetContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_native_target_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_native_target_section" ):
                listener.enterPbx_native_target_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_native_target_section" ):
                listener.exitPbx_native_target_section(self)




    def pbx_native_target_section(self):

        localctx = PBXProjParser.Pbx_native_target_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 38, self.RULE_pbx_native_target_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 581 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 580
                    self.pbx_native_target()

                else:
                    raise NoViableAltException(self)
                self.state = 583 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,35,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_legacy_target_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_legacy_target(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_legacy_targetContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_legacy_targetContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_legacy_target_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_legacy_target_section" ):
                listener.enterPbx_legacy_target_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_legacy_target_section" ):
                listener.exitPbx_legacy_target_section(self)




    def pbx_legacy_target_section(self):

        localctx = PBXProjParser.Pbx_legacy_target_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 40, self.RULE_pbx_legacy_target_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 586 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 585
                    self.pbx_legacy_target()

                else:
                    raise NoViableAltException(self)
                self.state = 588 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,36,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_project_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_project(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_projectContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_projectContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_project_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_project_section" ):
                listener.enterPbx_project_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_project_section" ):
                listener.exitPbx_project_section(self)




    def pbx_project_section(self):

        localctx = PBXProjParser.Pbx_project_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 42, self.RULE_pbx_project_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 591 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 590
                    self.pbx_project()

                else:
                    raise NoViableAltException(self)
                self.state = 593 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,37,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_reference_proxy_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_reference_proxy(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_reference_proxyContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_reference_proxyContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_reference_proxy_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_reference_proxy_section" ):
                listener.enterPbx_reference_proxy_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_reference_proxy_section" ):
                listener.exitPbx_reference_proxy_section(self)




    def pbx_reference_proxy_section(self):

        localctx = PBXProjParser.Pbx_reference_proxy_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 44, self.RULE_pbx_reference_proxy_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 596 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 595
                    self.pbx_reference_proxy()

                else:
                    raise NoViableAltException(self)
                self.state = 598 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,38,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_resources_build_phase_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_resources_build_phase(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_resources_build_phaseContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_resources_build_phaseContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_resources_build_phase_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_resources_build_phase_section" ):
                listener.enterPbx_resources_build_phase_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_resources_build_phase_section" ):
                listener.exitPbx_resources_build_phase_section(self)




    def pbx_resources_build_phase_section(self):

        localctx = PBXProjParser.Pbx_resources_build_phase_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 46, self.RULE_pbx_resources_build_phase_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 601 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 600
                    self.pbx_resources_build_phase()

                else:
                    raise NoViableAltException(self)
                self.state = 603 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,39,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_shell_script_build_phase_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_shell_script_build_phase(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_shell_script_build_phaseContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_shell_script_build_phaseContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_shell_script_build_phase_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_shell_script_build_phase_section" ):
                listener.enterPbx_shell_script_build_phase_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_shell_script_build_phase_section" ):
                listener.exitPbx_shell_script_build_phase_section(self)




    def pbx_shell_script_build_phase_section(self):

        localctx = PBXProjParser.Pbx_shell_script_build_phase_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 48, self.RULE_pbx_shell_script_build_phase_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 606 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 605
                    self.pbx_shell_script_build_phase()

                else:
                    raise NoViableAltException(self)
                self.state = 608 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,40,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_shell_build_phase_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_shell_build_phase(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_shell_build_phaseContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_shell_build_phaseContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_shell_build_phase_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_shell_build_phase_section" ):
                listener.enterPbx_shell_build_phase_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_shell_build_phase_section" ):
                listener.exitPbx_shell_build_phase_section(self)




    def pbx_shell_build_phase_section(self):

        localctx = PBXProjParser.Pbx_shell_build_phase_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 50, self.RULE_pbx_shell_build_phase_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 611 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 610
                    self.pbx_shell_build_phase()

                else:
                    raise NoViableAltException(self)
                self.state = 613 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,41,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_sources_build_phase_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_sources_build_phase(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_sources_build_phaseContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_sources_build_phaseContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_sources_build_phase_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_sources_build_phase_section" ):
                listener.enterPbx_sources_build_phase_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_sources_build_phase_section" ):
                listener.exitPbx_sources_build_phase_section(self)




    def pbx_sources_build_phase_section(self):

        localctx = PBXProjParser.Pbx_sources_build_phase_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 52, self.RULE_pbx_sources_build_phase_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 616 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 615
                    self.pbx_sources_build_phase()

                else:
                    raise NoViableAltException(self)
                self.state = 618 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,42,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_target_dependency_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_target_dependency(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_target_dependencyContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_target_dependencyContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_target_dependency_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_target_dependency_section" ):
                listener.enterPbx_target_dependency_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_target_dependency_section" ):
                listener.exitPbx_target_dependency_section(self)




    def pbx_target_dependency_section(self):

        localctx = PBXProjParser.Pbx_target_dependency_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 54, self.RULE_pbx_target_dependency_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 621 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 620
                    self.pbx_target_dependency()

                else:
                    raise NoViableAltException(self)
                self.state = 623 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,43,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_variant_group_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def pbx_variant_group(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Pbx_variant_groupContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Pbx_variant_groupContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_variant_group_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_variant_group_section" ):
                listener.enterPbx_variant_group_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_variant_group_section" ):
                listener.exitPbx_variant_group_section(self)




    def pbx_variant_group_section(self):

        localctx = PBXProjParser.Pbx_variant_group_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 56, self.RULE_pbx_variant_group_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 626 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 625
                    self.pbx_variant_group()

                else:
                    raise NoViableAltException(self)
                self.state = 628 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,44,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Xc_build_configuration_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def xc_build_configuration(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Xc_build_configurationContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Xc_build_configurationContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_xc_build_configuration_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXc_build_configuration_section" ):
                listener.enterXc_build_configuration_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXc_build_configuration_section" ):
                listener.exitXc_build_configuration_section(self)




    def xc_build_configuration_section(self):

        localctx = PBXProjParser.Xc_build_configuration_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 58, self.RULE_xc_build_configuration_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 631 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 630
                    self.xc_build_configuration()

                else:
                    raise NoViableAltException(self)
                self.state = 633 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,45,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Xc_configuration_list_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def xc_configuration_list(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Xc_configuration_listContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Xc_configuration_listContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_xc_configuration_list_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXc_configuration_list_section" ):
                listener.enterXc_configuration_list_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXc_configuration_list_section" ):
                listener.exitXc_configuration_list_section(self)




    def xc_configuration_list_section(self):

        localctx = PBXProjParser.Xc_configuration_list_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 60, self.RULE_xc_configuration_list_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 636 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 635
                    self.xc_configuration_list()

                else:
                    raise NoViableAltException(self)
                self.state = 638 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,46,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Xc_remote_swift_package_reference_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def xc_remote_swift_package_reference(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Xc_remote_swift_package_referenceContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Xc_remote_swift_package_referenceContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_xc_remote_swift_package_reference_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXc_remote_swift_package_reference_section" ):
                listener.enterXc_remote_swift_package_reference_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXc_remote_swift_package_reference_section" ):
                listener.exitXc_remote_swift_package_reference_section(self)




    def xc_remote_swift_package_reference_section(self):

        localctx = PBXProjParser.Xc_remote_swift_package_reference_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 62, self.RULE_xc_remote_swift_package_reference_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 641 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 640
                    self.xc_remote_swift_package_reference()

                else:
                    raise NoViableAltException(self)
                self.state = 643 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,47,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Xc_swift_package_product_dependency_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def xc_swift_package_product_dependency(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Xc_swift_package_product_dependencyContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Xc_swift_package_product_dependencyContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_xc_swift_package_product_dependency_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXc_swift_package_product_dependency_section" ):
                listener.enterXc_swift_package_product_dependency_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXc_swift_package_product_dependency_section" ):
                listener.exitXc_swift_package_product_dependency_section(self)




    def xc_swift_package_product_dependency_section(self):

        localctx = PBXProjParser.Xc_swift_package_product_dependency_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 64, self.RULE_xc_swift_package_product_dependency_section)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 646 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 645
                    self.xc_swift_package_product_dependency()

                else:
                    raise NoViableAltException(self)
                self.state = 648 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,48,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Xc_version_group_sectionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def xc_version_group(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Xc_version_groupContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Xc_version_groupContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_xc_version_group_section

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXc_version_group_section" ):
                listener.enterXc_version_group_section(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXc_version_group_section" ):
                listener.exitXc_version_group_section(self)




    def xc_version_group_section(self):

        localctx = PBXProjParser.Xc_version_group_sectionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 66, self.RULE_xc_version_group_section)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 651 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 650
                self.xc_version_group()
                self.state = 653 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==156):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_aggregate_targetContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_aggregate_target(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_aggregate_targetContext,0)


        def build_configuration_list(self):
            return self.getTypedRuleContext(PBXProjParser.Build_configuration_listContext,0)


        def build_phases(self):
            return self.getTypedRuleContext(PBXProjParser.Build_phasesContext,0)


        def dependencies(self):
            return self.getTypedRuleContext(PBXProjParser.DependenciesContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def build_settings(self):
            return self.getTypedRuleContext(PBXProjParser.Build_settingsContext,0)


        def comments(self):
            return self.getTypedRuleContext(PBXProjParser.CommentsContext,0)


        def product_name(self):
            return self.getTypedRuleContext(PBXProjParser.Product_nameContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_aggregate_target

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_aggregate_target" ):
                listener.enterPbx_aggregate_target(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_aggregate_target" ):
                listener.exitPbx_aggregate_target(self)




    def pbx_aggregate_target(self):

        localctx = PBXProjParser.Pbx_aggregate_targetContext(self, self._ctx, self.state)
        self.enterRule(localctx, 68, self.RULE_pbx_aggregate_target)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 655
            self.match(PBXProjParser.REFERENCE)
            self.state = 656
            self.match(PBXProjParser.T__2)
            self.state = 657
            self.match(PBXProjParser.T__0)
            self.state = 658
            self.isa_pbx_aggregate_target()
            self.state = 659
            self.build_configuration_list()
            self.state = 660
            self.build_phases()
            self.state = 662
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==140:
                self.state = 661
                self.build_settings()


            self.state = 665
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==55:
                self.state = 664
                self.comments()


            self.state = 667
            self.dependencies()
            self.state = 668
            self.name()
            self.state = 670
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==87:
                self.state = 669
                self.product_name()


            self.state = 672
            self.match(PBXProjParser.T__1)
            self.state = 673
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_build_fileContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_build_file(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_build_fileContext,0)


        def file_ref(self):
            return self.getTypedRuleContext(PBXProjParser.File_refContext,0)


        def platform_filter(self):
            return self.getTypedRuleContext(PBXProjParser.Platform_filterContext,0)


        def platform_filters(self):
            return self.getTypedRuleContext(PBXProjParser.Platform_filtersContext,0)


        def product_ref(self):
            return self.getTypedRuleContext(PBXProjParser.Product_refContext,0)


        def settings(self):
            return self.getTypedRuleContext(PBXProjParser.SettingsContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_build_file

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_build_file" ):
                listener.enterPbx_build_file(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_build_file" ):
                listener.exitPbx_build_file(self)




    def pbx_build_file(self):

        localctx = PBXProjParser.Pbx_build_fileContext(self, self._ctx, self.state)
        self.enterRule(localctx, 70, self.RULE_pbx_build_file)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 675
            self.match(PBXProjParser.REFERENCE)
            self.state = 676
            self.match(PBXProjParser.T__2)
            self.state = 677
            self.match(PBXProjParser.T__0)
            self.state = 678
            self.isa_pbx_build_file()
            self.state = 680
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==48:
                self.state = 679
                self.file_ref()


            self.state = 683
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==65:
                self.state = 682
                self.platform_filter()


            self.state = 686
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==66:
                self.state = 685
                self.platform_filters()


            self.state = 689
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==49:
                self.state = 688
                self.product_ref()


            self.state = 692
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==149:
                self.state = 691
                self.settings()


            self.state = 694
            self.match(PBXProjParser.T__1)
            self.state = 695
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_build_ruleContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_build_rule(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_build_ruleContext,0)


        def compiler_spec(self):
            return self.getTypedRuleContext(PBXProjParser.Compiler_specContext,0)


        def file_type(self):
            return self.getTypedRuleContext(PBXProjParser.File_typeContext,0)


        def input_files(self):
            return self.getTypedRuleContext(PBXProjParser.Input_filesContext,0)


        def is_editable(self):
            return self.getTypedRuleContext(PBXProjParser.Is_editableContext,0)


        def output_files(self):
            return self.getTypedRuleContext(PBXProjParser.Output_filesContext,0)


        def file_patterns(self):
            return self.getTypedRuleContext(PBXProjParser.File_patternsContext,0)


        def run_once_per_arch(self):
            return self.getTypedRuleContext(PBXProjParser.Run_once_per_archContext,0)


        def script(self):
            return self.getTypedRuleContext(PBXProjParser.ScriptContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_build_rule

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_build_rule" ):
                listener.enterPbx_build_rule(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_build_rule" ):
                listener.exitPbx_build_rule(self)




    def pbx_build_rule(self):

        localctx = PBXProjParser.Pbx_build_ruleContext(self, self._ctx, self.state)
        self.enterRule(localctx, 72, self.RULE_pbx_build_rule)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 697
            self.match(PBXProjParser.REFERENCE)
            self.state = 698
            self.match(PBXProjParser.T__2)
            self.state = 699
            self.match(PBXProjParser.T__0)
            self.state = 700
            self.isa_pbx_build_rule()
            self.state = 701
            self.compiler_spec()
            self.state = 703
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==95:
                self.state = 702
                self.file_patterns()


            self.state = 705
            self.file_type()
            self.state = 706
            self.input_files()
            self.state = 707
            self.is_editable()
            self.state = 708
            self.output_files()
            self.state = 710
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==99:
                self.state = 709
                self.run_once_per_arch()


            self.state = 713
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==100:
                self.state = 712
                self.script()


            self.state = 715
            self.match(PBXProjParser.T__1)
            self.state = 716
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_build_styleContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_build_style(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_build_styleContext,0)


        def build_settings(self):
            return self.getTypedRuleContext(PBXProjParser.Build_settingsContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_build_style

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_build_style" ):
                listener.enterPbx_build_style(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_build_style" ):
                listener.exitPbx_build_style(self)




    def pbx_build_style(self):

        localctx = PBXProjParser.Pbx_build_styleContext(self, self._ctx, self.state)
        self.enterRule(localctx, 74, self.RULE_pbx_build_style)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 718
            self.match(PBXProjParser.REFERENCE)
            self.state = 719
            self.match(PBXProjParser.T__2)
            self.state = 720
            self.match(PBXProjParser.T__0)
            self.state = 721
            self.isa_pbx_build_style()
            self.state = 723
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==140:
                self.state = 722
                self.build_settings()


            self.state = 726
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==73:
                self.state = 725
                self.name()


            self.state = 728
            self.match(PBXProjParser.T__1)
            self.state = 729
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_container_item_proxyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_container_item_proxy(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_container_item_proxyContext,0)


        def container_portal(self):
            return self.getTypedRuleContext(PBXProjParser.Container_portalContext,0)


        def proxy_type(self):
            return self.getTypedRuleContext(PBXProjParser.Proxy_typeContext,0)


        def remote_global_id_string(self):
            return self.getTypedRuleContext(PBXProjParser.Remote_global_id_stringContext,0)


        def remote_info(self):
            return self.getTypedRuleContext(PBXProjParser.Remote_infoContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_container_item_proxy

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_container_item_proxy" ):
                listener.enterPbx_container_item_proxy(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_container_item_proxy" ):
                listener.exitPbx_container_item_proxy(self)




    def pbx_container_item_proxy(self):

        localctx = PBXProjParser.Pbx_container_item_proxyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 76, self.RULE_pbx_container_item_proxy)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 731
            self.match(PBXProjParser.REFERENCE)
            self.state = 732
            self.match(PBXProjParser.T__2)
            self.state = 733
            self.match(PBXProjParser.T__0)
            self.state = 734
            self.isa_pbx_container_item_proxy()
            self.state = 735
            self.container_portal()
            self.state = 736
            self.proxy_type()
            self.state = 737
            self.remote_global_id_string()
            self.state = 738
            self.remote_info()
            self.state = 739
            self.match(PBXProjParser.T__1)
            self.state = 740
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_copy_files_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_copy_files_build_phase(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_copy_files_build_phaseContext,0)


        def build_action_mask(self):
            return self.getTypedRuleContext(PBXProjParser.Build_action_maskContext,0)


        def dst_subfolder_spec(self):
            return self.getTypedRuleContext(PBXProjParser.Dst_subfolder_specContext,0)


        def run_only_for_deployment_postprocessing(self):
            return self.getTypedRuleContext(PBXProjParser.Run_only_for_deployment_postprocessingContext,0)


        def dst_path(self):
            return self.getTypedRuleContext(PBXProjParser.Dst_pathContext,0)


        def files(self):
            return self.getTypedRuleContext(PBXProjParser.FilesContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_copy_files_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_copy_files_build_phase" ):
                listener.enterPbx_copy_files_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_copy_files_build_phase" ):
                listener.exitPbx_copy_files_build_phase(self)




    def pbx_copy_files_build_phase(self):

        localctx = PBXProjParser.Pbx_copy_files_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 78, self.RULE_pbx_copy_files_build_phase)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 742
            self.match(PBXProjParser.REFERENCE)
            self.state = 743
            self.match(PBXProjParser.T__2)
            self.state = 744
            self.match(PBXProjParser.T__0)
            self.state = 745
            self.isa_pbx_copy_files_build_phase()
            self.state = 746
            self.build_action_mask()
            self.state = 748
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==142:
                self.state = 747
                self.dst_path()


            self.state = 750
            self.dst_subfolder_spec()
            self.state = 752
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==77:
                self.state = 751
                self.files()


            self.state = 755
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==73:
                self.state = 754
                self.name()


            self.state = 757
            self.run_only_for_deployment_postprocessing()
            self.state = 758
            self.match(PBXProjParser.T__1)
            self.state = 759
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_file_referenceContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_file_reference(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_file_referenceContext,0)


        def comments(self):
            return self.getTypedRuleContext(PBXProjParser.CommentsContext,0)


        def file_encoding(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.File_encodingContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.File_encodingContext,i)


        def explicit_file_type(self):
            return self.getTypedRuleContext(PBXProjParser.Explicit_file_typeContext,0)


        def include_in_index(self):
            return self.getTypedRuleContext(PBXProjParser.Include_in_indexContext,0)


        def indent_width(self):
            return self.getTypedRuleContext(PBXProjParser.Indent_widthContext,0)


        def last_known_file_type(self):
            return self.getTypedRuleContext(PBXProjParser.Last_known_file_typeContext,0)


        def line_ending(self):
            return self.getTypedRuleContext(PBXProjParser.Line_endingContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def path(self):
            return self.getTypedRuleContext(PBXProjParser.PathContext,0)


        def ref_type(self):
            return self.getTypedRuleContext(PBXProjParser.Ref_typeContext,0)


        def plist_structure_definition_identifier(self):
            return self.getTypedRuleContext(PBXProjParser.Plist_structure_definition_identifierContext,0)


        def source_tree(self):
            return self.getTypedRuleContext(PBXProjParser.Source_treeContext,0)


        def tab_width(self):
            return self.getTypedRuleContext(PBXProjParser.Tab_widthContext,0)


        def xc_language_specification_identifier(self):
            return self.getTypedRuleContext(PBXProjParser.Xc_language_specification_identifierContext,0)


        def uses_tabs(self):
            return self.getTypedRuleContext(PBXProjParser.Uses_tabsContext,0)


        def wraps_lines(self):
            return self.getTypedRuleContext(PBXProjParser.Wraps_linesContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_file_reference

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_file_reference" ):
                listener.enterPbx_file_reference(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_file_reference" ):
                listener.exitPbx_file_reference(self)




    def pbx_file_reference(self):

        localctx = PBXProjParser.Pbx_file_referenceContext(self, self._ctx, self.state)
        self.enterRule(localctx, 80, self.RULE_pbx_file_reference)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 761
            self.match(PBXProjParser.REFERENCE)
            self.state = 762
            self.match(PBXProjParser.T__2)
            self.state = 763
            self.match(PBXProjParser.T__0)
            self.state = 764
            self.isa_pbx_file_reference()
            self.state = 766
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==55:
                self.state = 765
                self.comments()


            self.state = 769
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,67,self._ctx)
            if la_ == 1:
                self.state = 768
                self.file_encoding()


            self.state = 772
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==56:
                self.state = 771
                self.explicit_file_type()


            self.state = 775
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==54:
                self.state = 774
                self.file_encoding()


            self.state = 778
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==60:
                self.state = 777
                self.include_in_index()


            self.state = 781
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==61:
                self.state = 780
                self.indent_width()


            self.state = 784
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==59:
                self.state = 783
                self.last_known_file_type()


            self.state = 787
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==90:
                self.state = 786
                self.line_ending()


            self.state = 790
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==73:
                self.state = 789
                self.name()


            self.state = 793
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==74:
                self.state = 792
                self.path()


            self.state = 796
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==93:
                self.state = 795
                self.ref_type()


            self.state = 799
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==92:
                self.state = 798
                self.plist_structure_definition_identifier()


            self.state = 802
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==75:
                self.state = 801
                self.source_tree()


            self.state = 805
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==62:
                self.state = 804
                self.tab_width()


            self.state = 808
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==91:
                self.state = 807
                self.xc_language_specification_identifier()


            self.state = 811
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==63:
                self.state = 810
                self.uses_tabs()


            self.state = 814
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==64:
                self.state = 813
                self.wraps_lines()


            self.state = 816
            self.match(PBXProjParser.T__1)
            self.state = 817
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_file_system_synchronized_build_file_exception_setContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_file_system_synchronized_build_file_exception_set(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_file_system_synchronized_build_file_exception_setContext,0)


        def membership_exceptions(self):
            return self.getTypedRuleContext(PBXProjParser.Membership_exceptionsContext,0)


        def target(self):
            return self.getTypedRuleContext(PBXProjParser.TargetContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_file_system_synchronized_build_file_exception_set

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_file_system_synchronized_build_file_exception_set" ):
                listener.enterPbx_file_system_synchronized_build_file_exception_set(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_file_system_synchronized_build_file_exception_set" ):
                listener.exitPbx_file_system_synchronized_build_file_exception_set(self)




    def pbx_file_system_synchronized_build_file_exception_set(self):

        localctx = PBXProjParser.Pbx_file_system_synchronized_build_file_exception_setContext(self, self._ctx, self.state)
        self.enterRule(localctx, 82, self.RULE_pbx_file_system_synchronized_build_file_exception_set)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 819
            self.match(PBXProjParser.REFERENCE)
            self.state = 820
            self.match(PBXProjParser.T__2)
            self.state = 821
            self.match(PBXProjParser.T__0)
            self.state = 822
            self.isa_pbx_file_system_synchronized_build_file_exception_set()
            self.state = 823
            self.membership_exceptions()
            self.state = 824
            self.target()
            self.state = 825
            self.match(PBXProjParser.T__1)
            self.state = 826
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_file_system_synchronized_root_groupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_file_system_synchronized_root_group(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_file_system_synchronized_root_groupContext,0)


        def exceptions(self):
            return self.getTypedRuleContext(PBXProjParser.ExceptionsContext,0)


        def explicit_file_types(self):
            return self.getTypedRuleContext(PBXProjParser.Explicit_file_typesContext,0)


        def explicit_folders(self):
            return self.getTypedRuleContext(PBXProjParser.Explicit_foldersContext,0)


        def path(self):
            return self.getTypedRuleContext(PBXProjParser.PathContext,0)


        def source_tree(self):
            return self.getTypedRuleContext(PBXProjParser.Source_treeContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_file_system_synchronized_root_group

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_file_system_synchronized_root_group" ):
                listener.enterPbx_file_system_synchronized_root_group(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_file_system_synchronized_root_group" ):
                listener.exitPbx_file_system_synchronized_root_group(self)




    def pbx_file_system_synchronized_root_group(self):

        localctx = PBXProjParser.Pbx_file_system_synchronized_root_groupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 84, self.RULE_pbx_file_system_synchronized_root_group)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 828
            self.match(PBXProjParser.REFERENCE)
            self.state = 829
            self.match(PBXProjParser.T__2)
            self.state = 830
            self.match(PBXProjParser.T__0)
            self.state = 831
            self.isa_pbx_file_system_synchronized_root_group()
            self.state = 832
            self.exceptions()
            self.state = 833
            self.explicit_file_types()
            self.state = 834
            self.explicit_folders()
            self.state = 835
            self.path()
            self.state = 836
            self.source_tree()
            self.state = 837
            self.match(PBXProjParser.T__1)
            self.state = 838
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_frameworks_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_frameworks_build_phase(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_frameworks_build_phaseContext,0)


        def build_action_mask(self):
            return self.getTypedRuleContext(PBXProjParser.Build_action_maskContext,0)


        def files(self):
            return self.getTypedRuleContext(PBXProjParser.FilesContext,0)


        def run_only_for_deployment_postprocessing(self):
            return self.getTypedRuleContext(PBXProjParser.Run_only_for_deployment_postprocessingContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_frameworks_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_frameworks_build_phase" ):
                listener.enterPbx_frameworks_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_frameworks_build_phase" ):
                listener.exitPbx_frameworks_build_phase(self)




    def pbx_frameworks_build_phase(self):

        localctx = PBXProjParser.Pbx_frameworks_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 86, self.RULE_pbx_frameworks_build_phase)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 840
            self.match(PBXProjParser.REFERENCE)
            self.state = 841
            self.match(PBXProjParser.T__2)
            self.state = 842
            self.match(PBXProjParser.T__0)
            self.state = 843
            self.isa_pbx_frameworks_build_phase()
            self.state = 844
            self.build_action_mask()
            self.state = 845
            self.files()
            self.state = 846
            self.run_only_for_deployment_postprocessing()
            self.state = 847
            self.match(PBXProjParser.T__1)
            self.state = 848
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_groupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_group(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_groupContext,0)


        def children(self):
            return self.getTypedRuleContext(PBXProjParser.ChildrenContext,0)


        def source_tree(self):
            return self.getTypedRuleContext(PBXProjParser.Source_treeContext,0)


        def comments(self):
            return self.getTypedRuleContext(PBXProjParser.CommentsContext,0)


        def indent_width(self):
            return self.getTypedRuleContext(PBXProjParser.Indent_widthContext,0)


        def include_in_index(self):
            return self.getTypedRuleContext(PBXProjParser.Include_in_indexContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def path(self):
            return self.getTypedRuleContext(PBXProjParser.PathContext,0)


        def tab_width(self):
            return self.getTypedRuleContext(PBXProjParser.Tab_widthContext,0)


        def uses_tabs(self):
            return self.getTypedRuleContext(PBXProjParser.Uses_tabsContext,0)


        def wraps_lines(self):
            return self.getTypedRuleContext(PBXProjParser.Wraps_linesContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_group

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_group" ):
                listener.enterPbx_group(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_group" ):
                listener.exitPbx_group(self)




    def pbx_group(self):

        localctx = PBXProjParser.Pbx_groupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 88, self.RULE_pbx_group)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 850
            self.match(PBXProjParser.REFERENCE)
            self.state = 851
            self.match(PBXProjParser.T__2)
            self.state = 852
            self.match(PBXProjParser.T__0)
            self.state = 853
            self.isa_pbx_group()
            self.state = 854
            self.children()
            self.state = 856
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==55:
                self.state = 855
                self.comments()


            self.state = 859
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==61:
                self.state = 858
                self.indent_width()


            self.state = 862
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==60:
                self.state = 861
                self.include_in_index()


            self.state = 865
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==73:
                self.state = 864
                self.name()


            self.state = 868
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==74:
                self.state = 867
                self.path()


            self.state = 870
            self.source_tree()
            self.state = 872
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==62:
                self.state = 871
                self.tab_width()


            self.state = 875
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==63:
                self.state = 874
                self.uses_tabs()


            self.state = 878
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==64:
                self.state = 877
                self.wraps_lines()


            self.state = 880
            self.match(PBXProjParser.T__1)
            self.state = 881
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_headers_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_header_build_phase(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_header_build_phaseContext,0)


        def build_action_mask(self):
            return self.getTypedRuleContext(PBXProjParser.Build_action_maskContext,0)


        def files(self):
            return self.getTypedRuleContext(PBXProjParser.FilesContext,0)


        def run_only_for_deployment_postprocessing(self):
            return self.getTypedRuleContext(PBXProjParser.Run_only_for_deployment_postprocessingContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_headers_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_headers_build_phase" ):
                listener.enterPbx_headers_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_headers_build_phase" ):
                listener.exitPbx_headers_build_phase(self)




    def pbx_headers_build_phase(self):

        localctx = PBXProjParser.Pbx_headers_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 90, self.RULE_pbx_headers_build_phase)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 883
            self.match(PBXProjParser.REFERENCE)
            self.state = 884
            self.match(PBXProjParser.T__2)
            self.state = 885
            self.match(PBXProjParser.T__0)
            self.state = 886
            self.isa_pbx_header_build_phase()
            self.state = 887
            self.build_action_mask()
            self.state = 888
            self.files()
            self.state = 889
            self.run_only_for_deployment_postprocessing()
            self.state = 890
            self.match(PBXProjParser.T__1)
            self.state = 891
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_native_targetContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_native_target(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_native_targetContext,0)


        def build_configuration_list(self):
            return self.getTypedRuleContext(PBXProjParser.Build_configuration_listContext,0)


        def build_phases(self):
            return self.getTypedRuleContext(PBXProjParser.Build_phasesContext,0)


        def build_rules(self):
            return self.getTypedRuleContext(PBXProjParser.Build_rulesContext,0)


        def dependencies(self):
            return self.getTypedRuleContext(PBXProjParser.DependenciesContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def product_name(self):
            return self.getTypedRuleContext(PBXProjParser.Product_nameContext,0)


        def product_type(self):
            return self.getTypedRuleContext(PBXProjParser.Product_typeContext,0)


        def comments(self):
            return self.getTypedRuleContext(PBXProjParser.CommentsContext,0)


        def build_settings(self):
            return self.getTypedRuleContext(PBXProjParser.Build_settingsContext,0)


        def product_install_path(self):
            return self.getTypedRuleContext(PBXProjParser.Product_install_pathContext,0)


        def package_product_dependencies(self):
            return self.getTypedRuleContext(PBXProjParser.Package_product_dependenciesContext,0)


        def product_reference(self):
            return self.getTypedRuleContext(PBXProjParser.Product_referenceContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_native_target

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_native_target" ):
                listener.enterPbx_native_target(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_native_target" ):
                listener.exitPbx_native_target(self)




    def pbx_native_target(self):

        localctx = PBXProjParser.Pbx_native_targetContext(self, self._ctx, self.state)
        self.enterRule(localctx, 92, self.RULE_pbx_native_target)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 893
            self.match(PBXProjParser.REFERENCE)
            self.state = 894
            self.match(PBXProjParser.T__2)
            self.state = 895
            self.match(PBXProjParser.T__0)
            self.state = 896
            self.isa_pbx_native_target()
            self.state = 897
            self.build_configuration_list()
            self.state = 898
            self.build_phases()
            self.state = 899
            self.build_rules()
            self.state = 901
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==55:
                self.state = 900
                self.comments()


            self.state = 904
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==140:
                self.state = 903
                self.build_settings()


            self.state = 906
            self.dependencies()
            self.state = 907
            self.name()
            self.state = 909
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==68:
                self.state = 908
                self.product_install_path()


            self.state = 912
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==72:
                self.state = 911
                self.package_product_dependencies()


            self.state = 914
            self.product_name()
            self.state = 916
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==88:
                self.state = 915
                self.product_reference()


            self.state = 918
            self.product_type()
            self.state = 919
            self.match(PBXProjParser.T__1)
            self.state = 920
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_legacy_targetContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_legacy_target(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_legacy_targetContext,0)


        def build_arguments_string(self):
            return self.getTypedRuleContext(PBXProjParser.Build_arguments_stringContext,0)


        def build_configuration_list(self):
            return self.getTypedRuleContext(PBXProjParser.Build_configuration_listContext,0)


        def build_phases(self):
            return self.getTypedRuleContext(PBXProjParser.Build_phasesContext,0)


        def build_tool_path(self):
            return self.getTypedRuleContext(PBXProjParser.Build_tool_pathContext,0)


        def build_working_directory(self):
            return self.getTypedRuleContext(PBXProjParser.Build_working_directoryContext,0)


        def dependencies(self):
            return self.getTypedRuleContext(PBXProjParser.DependenciesContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def pass_build_settings_in_environment(self):
            return self.getTypedRuleContext(PBXProjParser.Pass_build_settings_in_environmentContext,0)


        def product_name(self):
            return self.getTypedRuleContext(PBXProjParser.Product_nameContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_legacy_target

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_legacy_target" ):
                listener.enterPbx_legacy_target(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_legacy_target" ):
                listener.exitPbx_legacy_target(self)




    def pbx_legacy_target(self):

        localctx = PBXProjParser.Pbx_legacy_targetContext(self, self._ctx, self.state)
        self.enterRule(localctx, 94, self.RULE_pbx_legacy_target)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 922
            self.match(PBXProjParser.REFERENCE)
            self.state = 923
            self.match(PBXProjParser.T__2)
            self.state = 924
            self.match(PBXProjParser.T__0)
            self.state = 925
            self.isa_pbx_legacy_target()
            self.state = 926
            self.build_arguments_string()
            self.state = 927
            self.build_configuration_list()
            self.state = 928
            self.build_phases()
            self.state = 929
            self.build_tool_path()
            self.state = 930
            self.build_working_directory()
            self.state = 931
            self.dependencies()
            self.state = 932
            self.name()
            self.state = 933
            self.pass_build_settings_in_environment()
            self.state = 934
            self.product_name()
            self.state = 935
            self.match(PBXProjParser.T__1)
            self.state = 936
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_projectContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_project(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_projectContext,0)


        def build_configuration_list(self):
            return self.getTypedRuleContext(PBXProjParser.Build_configuration_listContext,0)


        def has_scanned_for_encodings(self):
            return self.getTypedRuleContext(PBXProjParser.Has_scanned_for_encodingsContext,0)


        def main_group(self):
            return self.getTypedRuleContext(PBXProjParser.Main_groupContext,0)


        def project_dir_path(self):
            return self.getTypedRuleContext(PBXProjParser.Project_dir_pathContext,0)


        def targets(self):
            return self.getTypedRuleContext(PBXProjParser.TargetsContext,0)


        def attributes(self):
            return self.getTypedRuleContext(PBXProjParser.AttributesContext,0)


        def build_settings(self):
            return self.getTypedRuleContext(PBXProjParser.Build_settingsContext,0)


        def build_styles(self):
            return self.getTypedRuleContext(PBXProjParser.Build_stylesContext,0)


        def compatibility_version(self):
            return self.getTypedRuleContext(PBXProjParser.Compatibility_versionContext,0)


        def development_region(self):
            return self.getTypedRuleContext(PBXProjParser.Development_regionContext,0)


        def known_regions(self):
            return self.getTypedRuleContext(PBXProjParser.Known_regionsContext,0)


        def package_references(self):
            return self.getTypedRuleContext(PBXProjParser.Package_referencesContext,0)


        def preferred_project_object_version(self):
            return self.getTypedRuleContext(PBXProjParser.Preferred_project_object_versionContext,0)


        def product_ref_group(self):
            return self.getTypedRuleContext(PBXProjParser.Product_ref_groupContext,0)


        def project_references(self):
            return self.getTypedRuleContext(PBXProjParser.Project_referencesContext,0)


        def project_root(self):
            return self.getTypedRuleContext(PBXProjParser.Project_rootContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_project

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_project" ):
                listener.enterPbx_project(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_project" ):
                listener.exitPbx_project(self)




    def pbx_project(self):

        localctx = PBXProjParser.Pbx_projectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 96, self.RULE_pbx_project)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 938
            self.match(PBXProjParser.REFERENCE)
            self.state = 939
            self.match(PBXProjParser.T__2)
            self.state = 940
            self.match(PBXProjParser.T__0)
            self.state = 941
            self.isa_pbx_project()
            self.state = 943
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==101:
                self.state = 942
                self.attributes()


            self.state = 945
            self.build_configuration_list()
            self.state = 947
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==140:
                self.state = 946
                self.build_settings()


            self.state = 950
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==141:
                self.state = 949
                self.build_styles()


            self.state = 953
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==115:
                self.state = 952
                self.compatibility_version()


            self.state = 956
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==116:
                self.state = 955
                self.development_region()


            self.state = 958
            self.has_scanned_for_encodings()
            self.state = 960
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==118:
                self.state = 959
                self.known_regions()


            self.state = 962
            self.main_group()
            self.state = 964
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==121:
                self.state = 963
                self.package_references()


            self.state = 967
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==122:
                self.state = 966
                self.preferred_project_object_version()


            self.state = 970
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==120:
                self.state = 969
                self.product_ref_group()


            self.state = 972
            self.project_dir_path()
            self.state = 974
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==124:
                self.state = 973
                self.project_references()


            self.state = 977
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==125:
                self.state = 976
                self.project_root()


            self.state = 979
            self.targets()
            self.state = 980
            self.match(PBXProjParser.T__1)
            self.state = 981
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_reference_proxyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_reference_proxy(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_reference_proxyContext,0)


        def file_type(self):
            return self.getTypedRuleContext(PBXProjParser.File_typeContext,0)


        def path(self):
            return self.getTypedRuleContext(PBXProjParser.PathContext,0)


        def remote_ref(self):
            return self.getTypedRuleContext(PBXProjParser.Remote_refContext,0)


        def source_tree(self):
            return self.getTypedRuleContext(PBXProjParser.Source_treeContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_reference_proxy

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_reference_proxy" ):
                listener.enterPbx_reference_proxy(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_reference_proxy" ):
                listener.exitPbx_reference_proxy(self)




    def pbx_reference_proxy(self):

        localctx = PBXProjParser.Pbx_reference_proxyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 98, self.RULE_pbx_reference_proxy)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 983
            self.match(PBXProjParser.REFERENCE)
            self.state = 984
            self.match(PBXProjParser.T__2)
            self.state = 985
            self.match(PBXProjParser.T__0)
            self.state = 986
            self.isa_pbx_reference_proxy()
            self.state = 987
            self.file_type()
            self.state = 989
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==73:
                self.state = 988
                self.name()


            self.state = 991
            self.path()
            self.state = 992
            self.remote_ref()
            self.state = 993
            self.source_tree()
            self.state = 994
            self.match(PBXProjParser.T__1)
            self.state = 995
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_resources_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_resources_build_phase(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_resources_build_phaseContext,0)


        def build_action_mask(self):
            return self.getTypedRuleContext(PBXProjParser.Build_action_maskContext,0)


        def files(self):
            return self.getTypedRuleContext(PBXProjParser.FilesContext,0)


        def run_only_for_deployment_postprocessing(self):
            return self.getTypedRuleContext(PBXProjParser.Run_only_for_deployment_postprocessingContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_resources_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_resources_build_phase" ):
                listener.enterPbx_resources_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_resources_build_phase" ):
                listener.exitPbx_resources_build_phase(self)




    def pbx_resources_build_phase(self):

        localctx = PBXProjParser.Pbx_resources_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 100, self.RULE_pbx_resources_build_phase)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 997
            self.match(PBXProjParser.REFERENCE)
            self.state = 998
            self.match(PBXProjParser.T__2)
            self.state = 999
            self.match(PBXProjParser.T__0)
            self.state = 1000
            self.isa_pbx_resources_build_phase()
            self.state = 1001
            self.build_action_mask()
            self.state = 1002
            self.files()
            self.state = 1003
            self.run_only_for_deployment_postprocessing()
            self.state = 1004
            self.match(PBXProjParser.T__1)
            self.state = 1005
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_shell_script_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_shell_script_build_phase(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_shell_script_build_phaseContext,0)


        def build_action_mask(self):
            return self.getTypedRuleContext(PBXProjParser.Build_action_maskContext,0)


        def files(self):
            return self.getTypedRuleContext(PBXProjParser.FilesContext,0)


        def run_only_for_deployment_postprocessing(self):
            return self.getTypedRuleContext(PBXProjParser.Run_only_for_deployment_postprocessingContext,0)


        def shell_path(self):
            return self.getTypedRuleContext(PBXProjParser.Shell_pathContext,0)


        def shell_script(self):
            return self.getTypedRuleContext(PBXProjParser.Shell_scriptContext,0)


        def always_out_of_date(self):
            return self.getTypedRuleContext(PBXProjParser.Always_out_of_dateContext,0)


        def input_file_list_paths(self):
            return self.getTypedRuleContext(PBXProjParser.Input_file_list_pathsContext,0)


        def input_paths(self):
            return self.getTypedRuleContext(PBXProjParser.Input_pathsContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def output_file_list_paths(self):
            return self.getTypedRuleContext(PBXProjParser.Output_file_list_pathsContext,0)


        def output_paths(self):
            return self.getTypedRuleContext(PBXProjParser.Output_pathsContext,0)


        def show_env_vars_in_log(self):
            return self.getTypedRuleContext(PBXProjParser.Show_env_vars_in_logContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_shell_script_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_shell_script_build_phase" ):
                listener.enterPbx_shell_script_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_shell_script_build_phase" ):
                listener.exitPbx_shell_script_build_phase(self)




    def pbx_shell_script_build_phase(self):

        localctx = PBXProjParser.Pbx_shell_script_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 102, self.RULE_pbx_shell_script_build_phase)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1007
            self.match(PBXProjParser.REFERENCE)
            self.state = 1008
            self.match(PBXProjParser.T__2)
            self.state = 1009
            self.match(PBXProjParser.T__0)
            self.state = 1010
            self.isa_pbx_shell_script_build_phase()
            self.state = 1012
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==47:
                self.state = 1011
                self.always_out_of_date()


            self.state = 1014
            self.build_action_mask()
            self.state = 1015
            self.files()
            self.state = 1017
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==127:
                self.state = 1016
                self.input_file_list_paths()


            self.state = 1020
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==128:
                self.state = 1019
                self.input_paths()


            self.state = 1023
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==73:
                self.state = 1022
                self.name()


            self.state = 1026
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==129:
                self.state = 1025
                self.output_file_list_paths()


            self.state = 1029
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==130:
                self.state = 1028
                self.output_paths()


            self.state = 1031
            self.run_only_for_deployment_postprocessing()
            self.state = 1032
            self.shell_path()
            self.state = 1033
            self.shell_script()
            self.state = 1035
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==134:
                self.state = 1034
                self.show_env_vars_in_log()


            self.state = 1037
            self.match(PBXProjParser.T__1)
            self.state = 1038
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_shell_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_shell_build_phase(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_shell_build_phaseContext,0)


        def build_action_mask(self):
            return self.getTypedRuleContext(PBXProjParser.Build_action_maskContext,0)


        def files(self):
            return self.getTypedRuleContext(PBXProjParser.FilesContext,0)


        def input_file_list_paths(self):
            return self.getTypedRuleContext(PBXProjParser.Input_file_list_pathsContext,0)


        def input_paths(self):
            return self.getTypedRuleContext(PBXProjParser.Input_pathsContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def output_file_list_paths(self):
            return self.getTypedRuleContext(PBXProjParser.Output_file_list_pathsContext,0)


        def output_paths(self):
            return self.getTypedRuleContext(PBXProjParser.Output_pathsContext,0)


        def run_only_for_deployment_postprocessing(self):
            return self.getTypedRuleContext(PBXProjParser.Run_only_for_deployment_postprocessingContext,0)


        def shell_path(self):
            return self.getTypedRuleContext(PBXProjParser.Shell_pathContext,0)


        def shell(self):
            return self.getTypedRuleContext(PBXProjParser.ShellContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_shell_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_shell_build_phase" ):
                listener.enterPbx_shell_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_shell_build_phase" ):
                listener.exitPbx_shell_build_phase(self)




    def pbx_shell_build_phase(self):

        localctx = PBXProjParser.Pbx_shell_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 104, self.RULE_pbx_shell_build_phase)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1040
            self.match(PBXProjParser.REFERENCE)
            self.state = 1041
            self.match(PBXProjParser.T__2)
            self.state = 1042
            self.match(PBXProjParser.T__0)
            self.state = 1043
            self.isa_pbx_shell_build_phase()
            self.state = 1044
            self.build_action_mask()
            self.state = 1045
            self.files()
            self.state = 1046
            self.input_file_list_paths()
            self.state = 1047
            self.input_paths()
            self.state = 1048
            self.name()
            self.state = 1049
            self.output_file_list_paths()
            self.state = 1050
            self.output_paths()
            self.state = 1051
            self.run_only_for_deployment_postprocessing()
            self.state = 1052
            self.shell_path()
            self.state = 1053
            self.shell()
            self.state = 1054
            self.match(PBXProjParser.T__1)
            self.state = 1055
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_sources_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_sources_build_phase(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_sources_build_phaseContext,0)


        def build_action_mask(self):
            return self.getTypedRuleContext(PBXProjParser.Build_action_maskContext,0)


        def files(self):
            return self.getTypedRuleContext(PBXProjParser.FilesContext,0)


        def run_only_for_deployment_postprocessing(self):
            return self.getTypedRuleContext(PBXProjParser.Run_only_for_deployment_postprocessingContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_sources_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_sources_build_phase" ):
                listener.enterPbx_sources_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_sources_build_phase" ):
                listener.exitPbx_sources_build_phase(self)




    def pbx_sources_build_phase(self):

        localctx = PBXProjParser.Pbx_sources_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 106, self.RULE_pbx_sources_build_phase)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1057
            self.match(PBXProjParser.REFERENCE)
            self.state = 1058
            self.match(PBXProjParser.T__2)
            self.state = 1059
            self.match(PBXProjParser.T__0)
            self.state = 1060
            self.isa_pbx_sources_build_phase()
            self.state = 1061
            self.build_action_mask()
            self.state = 1062
            self.files()
            self.state = 1063
            self.run_only_for_deployment_postprocessing()
            self.state = 1064
            self.match(PBXProjParser.T__1)
            self.state = 1065
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_target_dependencyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_target_dependency(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_target_dependencyContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def platform_filter(self):
            return self.getTypedRuleContext(PBXProjParser.Platform_filterContext,0)


        def platform_filters(self):
            return self.getTypedRuleContext(PBXProjParser.Platform_filtersContext,0)


        def product_ref(self):
            return self.getTypedRuleContext(PBXProjParser.Product_refContext,0)


        def target(self):
            return self.getTypedRuleContext(PBXProjParser.TargetContext,0)


        def target_proxy(self):
            return self.getTypedRuleContext(PBXProjParser.Target_proxyContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_target_dependency

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_target_dependency" ):
                listener.enterPbx_target_dependency(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_target_dependency" ):
                listener.exitPbx_target_dependency(self)




    def pbx_target_dependency(self):

        localctx = PBXProjParser.Pbx_target_dependencyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 108, self.RULE_pbx_target_dependency)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1067
            self.match(PBXProjParser.REFERENCE)
            self.state = 1068
            self.match(PBXProjParser.T__2)
            self.state = 1069
            self.match(PBXProjParser.T__0)
            self.state = 1070
            self.isa_pbx_target_dependency()
            self.state = 1072
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==73:
                self.state = 1071
                self.name()


            self.state = 1075
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==65:
                self.state = 1074
                self.platform_filter()


            self.state = 1078
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==66:
                self.state = 1077
                self.platform_filters()


            self.state = 1081
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==49:
                self.state = 1080
                self.product_ref()


            self.state = 1084
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==135:
                self.state = 1083
                self.target()


            self.state = 1087
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==136:
                self.state = 1086
                self.target_proxy()


            self.state = 1089
            self.match(PBXProjParser.T__1)
            self.state = 1090
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pbx_variant_groupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_pbx_variant_group(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_pbx_variant_groupContext,0)


        def children(self):
            return self.getTypedRuleContext(PBXProjParser.ChildrenContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def source_tree(self):
            return self.getTypedRuleContext(PBXProjParser.Source_treeContext,0)


        def path(self):
            return self.getTypedRuleContext(PBXProjParser.PathContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_pbx_variant_group

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPbx_variant_group" ):
                listener.enterPbx_variant_group(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPbx_variant_group" ):
                listener.exitPbx_variant_group(self)




    def pbx_variant_group(self):

        localctx = PBXProjParser.Pbx_variant_groupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 110, self.RULE_pbx_variant_group)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1092
            self.match(PBXProjParser.REFERENCE)
            self.state = 1093
            self.match(PBXProjParser.T__2)
            self.state = 1094
            self.match(PBXProjParser.T__0)
            self.state = 1095
            self.isa_pbx_variant_group()
            self.state = 1096
            self.children()
            self.state = 1097
            self.name()
            self.state = 1099
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==74:
                self.state = 1098
                self.path()


            self.state = 1101
            self.source_tree()
            self.state = 1102
            self.match(PBXProjParser.T__1)
            self.state = 1103
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Xc_build_configurationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_xc_build_configuration(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_xc_build_configurationContext,0)


        def build_settings(self):
            return self.getTypedRuleContext(PBXProjParser.Build_settingsContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def base_configuration_reference(self):
            return self.getTypedRuleContext(PBXProjParser.Base_configuration_referenceContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_xc_build_configuration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXc_build_configuration" ):
                listener.enterXc_build_configuration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXc_build_configuration" ):
                listener.exitXc_build_configuration(self)




    def xc_build_configuration(self):

        localctx = PBXProjParser.Xc_build_configurationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 112, self.RULE_xc_build_configuration)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1105
            self.match(PBXProjParser.REFERENCE)
            self.state = 1106
            self.match(PBXProjParser.T__2)
            self.state = 1107
            self.match(PBXProjParser.T__0)
            self.state = 1108
            self.isa_xc_build_configuration()
            self.state = 1110
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==139:
                self.state = 1109
                self.base_configuration_reference()


            self.state = 1112
            self.build_settings()
            self.state = 1113
            self.name()
            self.state = 1114
            self.match(PBXProjParser.T__1)
            self.state = 1115
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Xc_configuration_listContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_xc_configuration_list(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_xc_configuration_listContext,0)


        def build_configurations(self):
            return self.getTypedRuleContext(PBXProjParser.Build_configurationsContext,0)


        def default_configuration_is_visible(self):
            return self.getTypedRuleContext(PBXProjParser.Default_configuration_is_visibleContext,0)


        def default_configuration_name(self):
            return self.getTypedRuleContext(PBXProjParser.Default_configuration_nameContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_xc_configuration_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXc_configuration_list" ):
                listener.enterXc_configuration_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXc_configuration_list" ):
                listener.exitXc_configuration_list(self)




    def xc_configuration_list(self):

        localctx = PBXProjParser.Xc_configuration_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 114, self.RULE_xc_configuration_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1117
            self.match(PBXProjParser.REFERENCE)
            self.state = 1118
            self.match(PBXProjParser.T__2)
            self.state = 1119
            self.match(PBXProjParser.T__0)
            self.state = 1120
            self.isa_xc_configuration_list()
            self.state = 1121
            self.build_configurations()
            self.state = 1122
            self.default_configuration_is_visible()
            self.state = 1124
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==148:
                self.state = 1123
                self.default_configuration_name()


            self.state = 1126
            self.match(PBXProjParser.T__1)
            self.state = 1127
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Xc_remote_swift_package_referenceContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_xc_remote_swift_package_reference(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_xc_remote_swift_package_referenceContext,0)


        def repository_url(self):
            return self.getTypedRuleContext(PBXProjParser.Repository_urlContext,0)


        def requirement(self):
            return self.getTypedRuleContext(PBXProjParser.RequirementContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_xc_remote_swift_package_reference

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXc_remote_swift_package_reference" ):
                listener.enterXc_remote_swift_package_reference(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXc_remote_swift_package_reference" ):
                listener.exitXc_remote_swift_package_reference(self)




    def xc_remote_swift_package_reference(self):

        localctx = PBXProjParser.Xc_remote_swift_package_referenceContext(self, self._ctx, self.state)
        self.enterRule(localctx, 116, self.RULE_xc_remote_swift_package_reference)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1129
            self.match(PBXProjParser.REFERENCE)
            self.state = 1130
            self.match(PBXProjParser.T__2)
            self.state = 1131
            self.match(PBXProjParser.T__0)
            self.state = 1132
            self.isa_xc_remote_swift_package_reference()
            self.state = 1133
            self.repository_url()
            self.state = 1134
            self.requirement()
            self.state = 1135
            self.match(PBXProjParser.T__1)
            self.state = 1136
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Xc_swift_package_product_dependencyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_xc_swift_package_product_dependency(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_xc_swift_package_product_dependencyContext,0)


        def product_name(self):
            return self.getTypedRuleContext(PBXProjParser.Product_nameContext,0)


        def xc_package(self):
            return self.getTypedRuleContext(PBXProjParser.Xc_packageContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_xc_swift_package_product_dependency

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXc_swift_package_product_dependency" ):
                listener.enterXc_swift_package_product_dependency(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXc_swift_package_product_dependency" ):
                listener.exitXc_swift_package_product_dependency(self)




    def xc_swift_package_product_dependency(self):

        localctx = PBXProjParser.Xc_swift_package_product_dependencyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 118, self.RULE_xc_swift_package_product_dependency)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1138
            self.match(PBXProjParser.REFERENCE)
            self.state = 1139
            self.match(PBXProjParser.T__2)
            self.state = 1140
            self.match(PBXProjParser.T__0)
            self.state = 1141
            self.isa_xc_swift_package_product_dependency()
            self.state = 1143
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==71:
                self.state = 1142
                self.xc_package()


            self.state = 1145
            self.product_name()
            self.state = 1146
            self.match(PBXProjParser.T__1)
            self.state = 1147
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Xc_version_groupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def isa_xc_version_group(self):
            return self.getTypedRuleContext(PBXProjParser.Isa_xc_version_groupContext,0)


        def children(self):
            return self.getTypedRuleContext(PBXProjParser.ChildrenContext,0)


        def current_version(self):
            return self.getTypedRuleContext(PBXProjParser.Current_versionContext,0)


        def path(self):
            return self.getTypedRuleContext(PBXProjParser.PathContext,0)


        def source_tree(self):
            return self.getTypedRuleContext(PBXProjParser.Source_treeContext,0)


        def version_group_type(self):
            return self.getTypedRuleContext(PBXProjParser.Version_group_typeContext,0)


        def name(self):
            return self.getTypedRuleContext(PBXProjParser.NameContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_xc_version_group

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXc_version_group" ):
                listener.enterXc_version_group(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXc_version_group" ):
                listener.exitXc_version_group(self)




    def xc_version_group(self):

        localctx = PBXProjParser.Xc_version_groupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 120, self.RULE_xc_version_group)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1149
            self.match(PBXProjParser.REFERENCE)
            self.state = 1150
            self.match(PBXProjParser.T__2)
            self.state = 1151
            self.match(PBXProjParser.T__0)
            self.state = 1152
            self.isa_xc_version_group()
            self.state = 1153
            self.children()
            self.state = 1154
            self.current_version()
            self.state = 1156
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==73:
                self.state = 1155
                self.name()


            self.state = 1158
            self.path()
            self.state = 1159
            self.source_tree()
            self.state = 1160
            self.version_group_type()
            self.state = 1161
            self.match(PBXProjParser.T__1)
            self.state = 1162
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_aggregate_targetContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_AGGREGATE_TARGET(self):
            return self.getToken(PBXProjParser.PBX_AGGREGATE_TARGET, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_aggregate_target

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_aggregate_target" ):
                listener.enterIsa_pbx_aggregate_target(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_aggregate_target" ):
                listener.exitIsa_pbx_aggregate_target(self)




    def isa_pbx_aggregate_target(self):

        localctx = PBXProjParser.Isa_pbx_aggregate_targetContext(self, self._ctx, self.state)
        self.enterRule(localctx, 122, self.RULE_isa_pbx_aggregate_target)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1164
            self.match(PBXProjParser.ISA)
            self.state = 1165
            self.match(PBXProjParser.T__2)
            self.state = 1166
            self.match(PBXProjParser.PBX_AGGREGATE_TARGET)
            self.state = 1167
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_build_fileContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_BUILD_FILE(self):
            return self.getToken(PBXProjParser.PBX_BUILD_FILE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_build_file

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_build_file" ):
                listener.enterIsa_pbx_build_file(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_build_file" ):
                listener.exitIsa_pbx_build_file(self)




    def isa_pbx_build_file(self):

        localctx = PBXProjParser.Isa_pbx_build_fileContext(self, self._ctx, self.state)
        self.enterRule(localctx, 124, self.RULE_isa_pbx_build_file)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1169
            self.match(PBXProjParser.ISA)
            self.state = 1170
            self.match(PBXProjParser.T__2)
            self.state = 1171
            self.match(PBXProjParser.PBX_BUILD_FILE)
            self.state = 1172
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_build_ruleContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_BUILD_RULE(self):
            return self.getToken(PBXProjParser.PBX_BUILD_RULE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_build_rule

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_build_rule" ):
                listener.enterIsa_pbx_build_rule(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_build_rule" ):
                listener.exitIsa_pbx_build_rule(self)




    def isa_pbx_build_rule(self):

        localctx = PBXProjParser.Isa_pbx_build_ruleContext(self, self._ctx, self.state)
        self.enterRule(localctx, 126, self.RULE_isa_pbx_build_rule)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1174
            self.match(PBXProjParser.ISA)
            self.state = 1175
            self.match(PBXProjParser.T__2)
            self.state = 1176
            self.match(PBXProjParser.PBX_BUILD_RULE)
            self.state = 1177
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_build_styleContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_BUILD_STYLE(self):
            return self.getToken(PBXProjParser.PBX_BUILD_STYLE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_build_style

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_build_style" ):
                listener.enterIsa_pbx_build_style(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_build_style" ):
                listener.exitIsa_pbx_build_style(self)




    def isa_pbx_build_style(self):

        localctx = PBXProjParser.Isa_pbx_build_styleContext(self, self._ctx, self.state)
        self.enterRule(localctx, 128, self.RULE_isa_pbx_build_style)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1179
            self.match(PBXProjParser.ISA)
            self.state = 1180
            self.match(PBXProjParser.T__2)
            self.state = 1181
            self.match(PBXProjParser.PBX_BUILD_STYLE)
            self.state = 1182
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_container_item_proxyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_CONTAINER_ITEM_PROXY(self):
            return self.getToken(PBXProjParser.PBX_CONTAINER_ITEM_PROXY, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_container_item_proxy

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_container_item_proxy" ):
                listener.enterIsa_pbx_container_item_proxy(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_container_item_proxy" ):
                listener.exitIsa_pbx_container_item_proxy(self)




    def isa_pbx_container_item_proxy(self):

        localctx = PBXProjParser.Isa_pbx_container_item_proxyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 130, self.RULE_isa_pbx_container_item_proxy)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1184
            self.match(PBXProjParser.ISA)
            self.state = 1185
            self.match(PBXProjParser.T__2)
            self.state = 1186
            self.match(PBXProjParser.PBX_CONTAINER_ITEM_PROXY)
            self.state = 1187
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_copy_files_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_COPY_FILES_BUILD_PHASE(self):
            return self.getToken(PBXProjParser.PBX_COPY_FILES_BUILD_PHASE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_copy_files_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_copy_files_build_phase" ):
                listener.enterIsa_pbx_copy_files_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_copy_files_build_phase" ):
                listener.exitIsa_pbx_copy_files_build_phase(self)




    def isa_pbx_copy_files_build_phase(self):

        localctx = PBXProjParser.Isa_pbx_copy_files_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 132, self.RULE_isa_pbx_copy_files_build_phase)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1189
            self.match(PBXProjParser.ISA)
            self.state = 1190
            self.match(PBXProjParser.T__2)
            self.state = 1191
            self.match(PBXProjParser.PBX_COPY_FILES_BUILD_PHASE)
            self.state = 1192
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_file_referenceContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_FILE_REFERENCE(self):
            return self.getToken(PBXProjParser.PBX_FILE_REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_file_reference

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_file_reference" ):
                listener.enterIsa_pbx_file_reference(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_file_reference" ):
                listener.exitIsa_pbx_file_reference(self)




    def isa_pbx_file_reference(self):

        localctx = PBXProjParser.Isa_pbx_file_referenceContext(self, self._ctx, self.state)
        self.enterRule(localctx, 134, self.RULE_isa_pbx_file_reference)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1194
            self.match(PBXProjParser.ISA)
            self.state = 1195
            self.match(PBXProjParser.T__2)
            self.state = 1196
            self.match(PBXProjParser.PBX_FILE_REFERENCE)
            self.state = 1197
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_file_system_synchronized_build_file_exception_setContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_FILE_SYSTEM_SYNCHRONIZED_BUILD_FILE_EXCEPTION_SET(self):
            return self.getToken(PBXProjParser.PBX_FILE_SYSTEM_SYNCHRONIZED_BUILD_FILE_EXCEPTION_SET, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_file_system_synchronized_build_file_exception_set

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_file_system_synchronized_build_file_exception_set" ):
                listener.enterIsa_pbx_file_system_synchronized_build_file_exception_set(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_file_system_synchronized_build_file_exception_set" ):
                listener.exitIsa_pbx_file_system_synchronized_build_file_exception_set(self)




    def isa_pbx_file_system_synchronized_build_file_exception_set(self):

        localctx = PBXProjParser.Isa_pbx_file_system_synchronized_build_file_exception_setContext(self, self._ctx, self.state)
        self.enterRule(localctx, 136, self.RULE_isa_pbx_file_system_synchronized_build_file_exception_set)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1199
            self.match(PBXProjParser.ISA)
            self.state = 1200
            self.match(PBXProjParser.T__2)
            self.state = 1201
            self.match(PBXProjParser.PBX_FILE_SYSTEM_SYNCHRONIZED_BUILD_FILE_EXCEPTION_SET)
            self.state = 1202
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_file_system_synchronized_root_groupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_FILE_SYSTEM_SYNCHRONIZED_ROOT_GROUP(self):
            return self.getToken(PBXProjParser.PBX_FILE_SYSTEM_SYNCHRONIZED_ROOT_GROUP, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_file_system_synchronized_root_group

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_file_system_synchronized_root_group" ):
                listener.enterIsa_pbx_file_system_synchronized_root_group(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_file_system_synchronized_root_group" ):
                listener.exitIsa_pbx_file_system_synchronized_root_group(self)




    def isa_pbx_file_system_synchronized_root_group(self):

        localctx = PBXProjParser.Isa_pbx_file_system_synchronized_root_groupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 138, self.RULE_isa_pbx_file_system_synchronized_root_group)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1204
            self.match(PBXProjParser.ISA)
            self.state = 1205
            self.match(PBXProjParser.T__2)
            self.state = 1206
            self.match(PBXProjParser.PBX_FILE_SYSTEM_SYNCHRONIZED_ROOT_GROUP)
            self.state = 1207
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_frameworks_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_FRAMEWORKS_BUILD_PHASE(self):
            return self.getToken(PBXProjParser.PBX_FRAMEWORKS_BUILD_PHASE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_frameworks_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_frameworks_build_phase" ):
                listener.enterIsa_pbx_frameworks_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_frameworks_build_phase" ):
                listener.exitIsa_pbx_frameworks_build_phase(self)




    def isa_pbx_frameworks_build_phase(self):

        localctx = PBXProjParser.Isa_pbx_frameworks_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 140, self.RULE_isa_pbx_frameworks_build_phase)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1209
            self.match(PBXProjParser.ISA)
            self.state = 1210
            self.match(PBXProjParser.T__2)
            self.state = 1211
            self.match(PBXProjParser.PBX_FRAMEWORKS_BUILD_PHASE)
            self.state = 1212
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_groupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_GROUP(self):
            return self.getToken(PBXProjParser.PBX_GROUP, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_group

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_group" ):
                listener.enterIsa_pbx_group(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_group" ):
                listener.exitIsa_pbx_group(self)




    def isa_pbx_group(self):

        localctx = PBXProjParser.Isa_pbx_groupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 142, self.RULE_isa_pbx_group)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1214
            self.match(PBXProjParser.ISA)
            self.state = 1215
            self.match(PBXProjParser.T__2)
            self.state = 1216
            self.match(PBXProjParser.PBX_GROUP)
            self.state = 1217
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_header_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_HEADERS_BUILD_PHASE(self):
            return self.getToken(PBXProjParser.PBX_HEADERS_BUILD_PHASE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_header_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_header_build_phase" ):
                listener.enterIsa_pbx_header_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_header_build_phase" ):
                listener.exitIsa_pbx_header_build_phase(self)




    def isa_pbx_header_build_phase(self):

        localctx = PBXProjParser.Isa_pbx_header_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 144, self.RULE_isa_pbx_header_build_phase)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1219
            self.match(PBXProjParser.ISA)
            self.state = 1220
            self.match(PBXProjParser.T__2)
            self.state = 1221
            self.match(PBXProjParser.PBX_HEADERS_BUILD_PHASE)
            self.state = 1222
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_native_targetContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_NATIVE_TARGET(self):
            return self.getToken(PBXProjParser.PBX_NATIVE_TARGET, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_native_target

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_native_target" ):
                listener.enterIsa_pbx_native_target(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_native_target" ):
                listener.exitIsa_pbx_native_target(self)




    def isa_pbx_native_target(self):

        localctx = PBXProjParser.Isa_pbx_native_targetContext(self, self._ctx, self.state)
        self.enterRule(localctx, 146, self.RULE_isa_pbx_native_target)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1224
            self.match(PBXProjParser.ISA)
            self.state = 1225
            self.match(PBXProjParser.T__2)
            self.state = 1226
            self.match(PBXProjParser.PBX_NATIVE_TARGET)
            self.state = 1227
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_legacy_targetContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_LEGACY_TARGET(self):
            return self.getToken(PBXProjParser.PBX_LEGACY_TARGET, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_legacy_target

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_legacy_target" ):
                listener.enterIsa_pbx_legacy_target(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_legacy_target" ):
                listener.exitIsa_pbx_legacy_target(self)




    def isa_pbx_legacy_target(self):

        localctx = PBXProjParser.Isa_pbx_legacy_targetContext(self, self._ctx, self.state)
        self.enterRule(localctx, 148, self.RULE_isa_pbx_legacy_target)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1229
            self.match(PBXProjParser.ISA)
            self.state = 1230
            self.match(PBXProjParser.T__2)
            self.state = 1231
            self.match(PBXProjParser.PBX_LEGACY_TARGET)
            self.state = 1232
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_projectContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_PROJECT(self):
            return self.getToken(PBXProjParser.PBX_PROJECT, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_project

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_project" ):
                listener.enterIsa_pbx_project(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_project" ):
                listener.exitIsa_pbx_project(self)




    def isa_pbx_project(self):

        localctx = PBXProjParser.Isa_pbx_projectContext(self, self._ctx, self.state)
        self.enterRule(localctx, 150, self.RULE_isa_pbx_project)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1234
            self.match(PBXProjParser.ISA)
            self.state = 1235
            self.match(PBXProjParser.T__2)
            self.state = 1236
            self.match(PBXProjParser.PBX_PROJECT)
            self.state = 1237
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_reference_proxyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_REFERENCE_PROXY(self):
            return self.getToken(PBXProjParser.PBX_REFERENCE_PROXY, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_reference_proxy

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_reference_proxy" ):
                listener.enterIsa_pbx_reference_proxy(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_reference_proxy" ):
                listener.exitIsa_pbx_reference_proxy(self)




    def isa_pbx_reference_proxy(self):

        localctx = PBXProjParser.Isa_pbx_reference_proxyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 152, self.RULE_isa_pbx_reference_proxy)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1239
            self.match(PBXProjParser.ISA)
            self.state = 1240
            self.match(PBXProjParser.T__2)
            self.state = 1241
            self.match(PBXProjParser.PBX_REFERENCE_PROXY)
            self.state = 1242
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_resources_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_RESOURCES_BUILD_PHASE(self):
            return self.getToken(PBXProjParser.PBX_RESOURCES_BUILD_PHASE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_resources_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_resources_build_phase" ):
                listener.enterIsa_pbx_resources_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_resources_build_phase" ):
                listener.exitIsa_pbx_resources_build_phase(self)




    def isa_pbx_resources_build_phase(self):

        localctx = PBXProjParser.Isa_pbx_resources_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 154, self.RULE_isa_pbx_resources_build_phase)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1244
            self.match(PBXProjParser.ISA)
            self.state = 1245
            self.match(PBXProjParser.T__2)
            self.state = 1246
            self.match(PBXProjParser.PBX_RESOURCES_BUILD_PHASE)
            self.state = 1247
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_shell_script_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_SHELL_SCRIPT_BUILD_PHASE(self):
            return self.getToken(PBXProjParser.PBX_SHELL_SCRIPT_BUILD_PHASE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_shell_script_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_shell_script_build_phase" ):
                listener.enterIsa_pbx_shell_script_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_shell_script_build_phase" ):
                listener.exitIsa_pbx_shell_script_build_phase(self)




    def isa_pbx_shell_script_build_phase(self):

        localctx = PBXProjParser.Isa_pbx_shell_script_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 156, self.RULE_isa_pbx_shell_script_build_phase)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1249
            self.match(PBXProjParser.ISA)
            self.state = 1250
            self.match(PBXProjParser.T__2)
            self.state = 1251
            self.match(PBXProjParser.PBX_SHELL_SCRIPT_BUILD_PHASE)
            self.state = 1252
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_shell_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_SHELL_BUILD_PHASE(self):
            return self.getToken(PBXProjParser.PBX_SHELL_BUILD_PHASE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_shell_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_shell_build_phase" ):
                listener.enterIsa_pbx_shell_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_shell_build_phase" ):
                listener.exitIsa_pbx_shell_build_phase(self)




    def isa_pbx_shell_build_phase(self):

        localctx = PBXProjParser.Isa_pbx_shell_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 158, self.RULE_isa_pbx_shell_build_phase)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1254
            self.match(PBXProjParser.ISA)
            self.state = 1255
            self.match(PBXProjParser.T__2)
            self.state = 1256
            self.match(PBXProjParser.PBX_SHELL_BUILD_PHASE)
            self.state = 1257
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_sources_build_phaseContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_SOURCES_BUILD_PHASE(self):
            return self.getToken(PBXProjParser.PBX_SOURCES_BUILD_PHASE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_sources_build_phase

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_sources_build_phase" ):
                listener.enterIsa_pbx_sources_build_phase(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_sources_build_phase" ):
                listener.exitIsa_pbx_sources_build_phase(self)




    def isa_pbx_sources_build_phase(self):

        localctx = PBXProjParser.Isa_pbx_sources_build_phaseContext(self, self._ctx, self.state)
        self.enterRule(localctx, 160, self.RULE_isa_pbx_sources_build_phase)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1259
            self.match(PBXProjParser.ISA)
            self.state = 1260
            self.match(PBXProjParser.T__2)
            self.state = 1261
            self.match(PBXProjParser.PBX_SOURCES_BUILD_PHASE)
            self.state = 1262
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_target_dependencyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_TARGET_DEPENDENCY(self):
            return self.getToken(PBXProjParser.PBX_TARGET_DEPENDENCY, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_target_dependency

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_target_dependency" ):
                listener.enterIsa_pbx_target_dependency(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_target_dependency" ):
                listener.exitIsa_pbx_target_dependency(self)




    def isa_pbx_target_dependency(self):

        localctx = PBXProjParser.Isa_pbx_target_dependencyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 162, self.RULE_isa_pbx_target_dependency)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1264
            self.match(PBXProjParser.ISA)
            self.state = 1265
            self.match(PBXProjParser.T__2)
            self.state = 1266
            self.match(PBXProjParser.PBX_TARGET_DEPENDENCY)
            self.state = 1267
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_pbx_variant_groupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def PBX_VARIANT_GROUP(self):
            return self.getToken(PBXProjParser.PBX_VARIANT_GROUP, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_pbx_variant_group

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_pbx_variant_group" ):
                listener.enterIsa_pbx_variant_group(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_pbx_variant_group" ):
                listener.exitIsa_pbx_variant_group(self)




    def isa_pbx_variant_group(self):

        localctx = PBXProjParser.Isa_pbx_variant_groupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 164, self.RULE_isa_pbx_variant_group)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1269
            self.match(PBXProjParser.ISA)
            self.state = 1270
            self.match(PBXProjParser.T__2)
            self.state = 1271
            self.match(PBXProjParser.PBX_VARIANT_GROUP)
            self.state = 1272
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_xc_build_configurationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def XC_BUILD_CONFIGURATION(self):
            return self.getToken(PBXProjParser.XC_BUILD_CONFIGURATION, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_xc_build_configuration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_xc_build_configuration" ):
                listener.enterIsa_xc_build_configuration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_xc_build_configuration" ):
                listener.exitIsa_xc_build_configuration(self)




    def isa_xc_build_configuration(self):

        localctx = PBXProjParser.Isa_xc_build_configurationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 166, self.RULE_isa_xc_build_configuration)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1274
            self.match(PBXProjParser.ISA)
            self.state = 1275
            self.match(PBXProjParser.T__2)
            self.state = 1276
            self.match(PBXProjParser.XC_BUILD_CONFIGURATION)
            self.state = 1277
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_xc_configuration_listContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def XC_CONFIGURATION_LIST(self):
            return self.getToken(PBXProjParser.XC_CONFIGURATION_LIST, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_xc_configuration_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_xc_configuration_list" ):
                listener.enterIsa_xc_configuration_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_xc_configuration_list" ):
                listener.exitIsa_xc_configuration_list(self)




    def isa_xc_configuration_list(self):

        localctx = PBXProjParser.Isa_xc_configuration_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 168, self.RULE_isa_xc_configuration_list)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1279
            self.match(PBXProjParser.ISA)
            self.state = 1280
            self.match(PBXProjParser.T__2)
            self.state = 1281
            self.match(PBXProjParser.XC_CONFIGURATION_LIST)
            self.state = 1282
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_xc_remote_swift_package_referenceContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def XC_REMOTE_SWIFT_PACKAGE_REFERENCE(self):
            return self.getToken(PBXProjParser.XC_REMOTE_SWIFT_PACKAGE_REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_xc_remote_swift_package_reference

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_xc_remote_swift_package_reference" ):
                listener.enterIsa_xc_remote_swift_package_reference(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_xc_remote_swift_package_reference" ):
                listener.exitIsa_xc_remote_swift_package_reference(self)




    def isa_xc_remote_swift_package_reference(self):

        localctx = PBXProjParser.Isa_xc_remote_swift_package_referenceContext(self, self._ctx, self.state)
        self.enterRule(localctx, 170, self.RULE_isa_xc_remote_swift_package_reference)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1284
            self.match(PBXProjParser.ISA)
            self.state = 1285
            self.match(PBXProjParser.T__2)
            self.state = 1286
            self.match(PBXProjParser.XC_REMOTE_SWIFT_PACKAGE_REFERENCE)
            self.state = 1287
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_xc_swift_package_product_dependencyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def XC_SWIFT_PACKAGE_PRODUCT_DEPENDENCY(self):
            return self.getToken(PBXProjParser.XC_SWIFT_PACKAGE_PRODUCT_DEPENDENCY, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_xc_swift_package_product_dependency

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_xc_swift_package_product_dependency" ):
                listener.enterIsa_xc_swift_package_product_dependency(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_xc_swift_package_product_dependency" ):
                listener.exitIsa_xc_swift_package_product_dependency(self)




    def isa_xc_swift_package_product_dependency(self):

        localctx = PBXProjParser.Isa_xc_swift_package_product_dependencyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 172, self.RULE_isa_xc_swift_package_product_dependency)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1289
            self.match(PBXProjParser.ISA)
            self.state = 1290
            self.match(PBXProjParser.T__2)
            self.state = 1291
            self.match(PBXProjParser.XC_SWIFT_PACKAGE_PRODUCT_DEPENDENCY)
            self.state = 1292
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Isa_xc_version_groupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def XC_VERSION_GROUP(self):
            return self.getToken(PBXProjParser.XC_VERSION_GROUP, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_isa_xc_version_group

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIsa_xc_version_group" ):
                listener.enterIsa_xc_version_group(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIsa_xc_version_group" ):
                listener.exitIsa_xc_version_group(self)




    def isa_xc_version_group(self):

        localctx = PBXProjParser.Isa_xc_version_groupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 174, self.RULE_isa_xc_version_group)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1294
            self.match(PBXProjParser.ISA)
            self.state = 1295
            self.match(PBXProjParser.T__2)
            self.state = 1296
            self.match(PBXProjParser.XC_VERSION_GROUP)
            self.state = 1297
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Always_out_of_dateContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ALWAYS_OUT_OF_DATE(self):
            return self.getToken(PBXProjParser.ALWAYS_OUT_OF_DATE, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_always_out_of_date

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAlways_out_of_date" ):
                listener.enterAlways_out_of_date(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAlways_out_of_date" ):
                listener.exitAlways_out_of_date(self)




    def always_out_of_date(self):

        localctx = PBXProjParser.Always_out_of_dateContext(self, self._ctx, self.state)
        self.enterRule(localctx, 176, self.RULE_always_out_of_date)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1299
            self.match(PBXProjParser.ALWAYS_OUT_OF_DATE)
            self.state = 1300
            self.match(PBXProjParser.T__2)
            self.state = 1301
            self.match(PBXProjParser.NUMBER)
            self.state = 1302
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class File_refContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FILE_REF(self):
            return self.getToken(PBXProjParser.FILE_REF, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_file_ref

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFile_ref" ):
                listener.enterFile_ref(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFile_ref" ):
                listener.exitFile_ref(self)




    def file_ref(self):

        localctx = PBXProjParser.File_refContext(self, self._ctx, self.state)
        self.enterRule(localctx, 178, self.RULE_file_ref)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1304
            self.match(PBXProjParser.FILE_REF)
            self.state = 1305
            self.match(PBXProjParser.T__2)
            self.state = 1306
            self.match(PBXProjParser.REFERENCE)
            self.state = 1307
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Product_refContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PRODUCT_REF(self):
            return self.getToken(PBXProjParser.PRODUCT_REF, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_product_ref

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProduct_ref" ):
                listener.enterProduct_ref(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProduct_ref" ):
                listener.exitProduct_ref(self)




    def product_ref(self):

        localctx = PBXProjParser.Product_refContext(self, self._ctx, self.state)
        self.enterRule(localctx, 180, self.RULE_product_ref)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1309
            self.match(PBXProjParser.PRODUCT_REF)
            self.state = 1310
            self.match(PBXProjParser.T__2)
            self.state = 1311
            self.match(PBXProjParser.REFERENCE)
            self.state = 1312
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Container_portalContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CONTAINER_PORTAL(self):
            return self.getToken(PBXProjParser.CONTAINER_PORTAL, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_container_portal

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterContainer_portal" ):
                listener.enterContainer_portal(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitContainer_portal" ):
                listener.exitContainer_portal(self)




    def container_portal(self):

        localctx = PBXProjParser.Container_portalContext(self, self._ctx, self.state)
        self.enterRule(localctx, 182, self.RULE_container_portal)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1314
            self.match(PBXProjParser.CONTAINER_PORTAL)
            self.state = 1315
            self.match(PBXProjParser.T__2)
            self.state = 1316
            self.match(PBXProjParser.REFERENCE)
            self.state = 1317
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Proxy_typeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PROXY_TYPE(self):
            return self.getToken(PBXProjParser.PROXY_TYPE, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_proxy_type

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProxy_type" ):
                listener.enterProxy_type(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProxy_type" ):
                listener.exitProxy_type(self)




    def proxy_type(self):

        localctx = PBXProjParser.Proxy_typeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 184, self.RULE_proxy_type)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1319
            self.match(PBXProjParser.PROXY_TYPE)
            self.state = 1320
            self.match(PBXProjParser.T__2)
            self.state = 1321
            self.match(PBXProjParser.NUMBER)
            self.state = 1322
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Remote_global_id_stringContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REMOTE_GLOBAL_ID_STRING(self):
            return self.getToken(PBXProjParser.REMOTE_GLOBAL_ID_STRING, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_remote_global_id_string

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRemote_global_id_string" ):
                listener.enterRemote_global_id_string(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRemote_global_id_string" ):
                listener.exitRemote_global_id_string(self)




    def remote_global_id_string(self):

        localctx = PBXProjParser.Remote_global_id_stringContext(self, self._ctx, self.state)
        self.enterRule(localctx, 186, self.RULE_remote_global_id_string)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1324
            self.match(PBXProjParser.REMOTE_GLOBAL_ID_STRING)
            self.state = 1325
            self.match(PBXProjParser.T__2)
            self.state = 1326
            self.match(PBXProjParser.REFERENCE)
            self.state = 1327
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Remote_infoContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REMOTE_INFO(self):
            return self.getToken(PBXProjParser.REMOTE_INFO, 0)

        def str_number_variable(self):
            return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_remote_info

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRemote_info" ):
                listener.enterRemote_info(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRemote_info" ):
                listener.exitRemote_info(self)




    def remote_info(self):

        localctx = PBXProjParser.Remote_infoContext(self, self._ctx, self.state)
        self.enterRule(localctx, 188, self.RULE_remote_info)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1329
            self.match(PBXProjParser.REMOTE_INFO)
            self.state = 1330
            self.match(PBXProjParser.T__2)
            self.state = 1331
            self.str_number_variable()
            self.state = 1332
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class File_encodingContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FILE_ENCODING(self):
            return self.getToken(PBXProjParser.FILE_ENCODING, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_file_encoding

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFile_encoding" ):
                listener.enterFile_encoding(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFile_encoding" ):
                listener.exitFile_encoding(self)




    def file_encoding(self):

        localctx = PBXProjParser.File_encodingContext(self, self._ctx, self.state)
        self.enterRule(localctx, 190, self.RULE_file_encoding)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1334
            self.match(PBXProjParser.FILE_ENCODING)
            self.state = 1335
            self.match(PBXProjParser.T__2)
            self.state = 1336
            self.match(PBXProjParser.NUMBER)
            self.state = 1337
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class CommentsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def COMMENTS(self):
            return self.getToken(PBXProjParser.COMMENTS, 0)

        def str_number_variable(self):
            return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_comments

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterComments" ):
                listener.enterComments(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitComments" ):
                listener.exitComments(self)




    def comments(self):

        localctx = PBXProjParser.CommentsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 192, self.RULE_comments)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1339
            self.match(PBXProjParser.COMMENTS)
            self.state = 1340
            self.match(PBXProjParser.T__2)
            self.state = 1341
            self.str_number_variable()
            self.state = 1342
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Explicit_file_typeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EXPLICIT_FILE_TYPE(self):
            return self.getToken(PBXProjParser.EXPLICIT_FILE_TYPE, 0)

        def str_number_variable(self):
            return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_explicit_file_type

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExplicit_file_type" ):
                listener.enterExplicit_file_type(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExplicit_file_type" ):
                listener.exitExplicit_file_type(self)




    def explicit_file_type(self):

        localctx = PBXProjParser.Explicit_file_typeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 194, self.RULE_explicit_file_type)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1344
            self.match(PBXProjParser.EXPLICIT_FILE_TYPE)
            self.state = 1345
            self.match(PBXProjParser.T__2)
            self.state = 1346
            self.str_number_variable()
            self.state = 1347
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Explicit_file_typesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EXPLICIT_FILE_TYPES(self):
            return self.getToken(PBXProjParser.EXPLICIT_FILE_TYPES, 0)

        def key_value(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Key_valueContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Key_valueContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_explicit_file_types

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExplicit_file_types" ):
                listener.enterExplicit_file_types(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExplicit_file_types" ):
                listener.exitExplicit_file_types(self)




    def explicit_file_types(self):

        localctx = PBXProjParser.Explicit_file_typesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 196, self.RULE_explicit_file_types)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1349
            self.match(PBXProjParser.EXPLICIT_FILE_TYPES)
            self.state = 1350
            self.match(PBXProjParser.T__2)
            self.state = 1351
            self.match(PBXProjParser.T__0)
            self.state = 1355
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & -141015588143360) != 0) or ((((_la - 64)) & ~0x3f) == 0 and ((1 << (_la - 64)) & -1) != 0) or ((((_la - 128)) & ~0x3f) == 0 and ((1 << (_la - 128)) & 4026523647) != 0):
                self.state = 1352
                self.key_value()
                self.state = 1357
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 1358
            self.match(PBXProjParser.T__1)
            self.state = 1359
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Explicit_foldersContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EXPLICIT_FOLDERS(self):
            return self.getToken(PBXProjParser.EXPLICIT_FOLDERS, 0)

        def any_string_list(self):
            return self.getTypedRuleContext(PBXProjParser.Any_string_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_explicit_folders

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExplicit_folders" ):
                listener.enterExplicit_folders(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExplicit_folders" ):
                listener.exitExplicit_folders(self)




    def explicit_folders(self):

        localctx = PBXProjParser.Explicit_foldersContext(self, self._ctx, self.state)
        self.enterRule(localctx, 198, self.RULE_explicit_folders)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1361
            self.match(PBXProjParser.EXPLICIT_FOLDERS)
            self.state = 1362
            self.match(PBXProjParser.T__2)
            self.state = 1363
            self.any_string_list()
            self.state = 1364
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Last_known_file_typeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LAST_KNOWN_FILE_TYPE(self):
            return self.getToken(PBXProjParser.LAST_KNOWN_FILE_TYPE, 0)

        def str_number_variable(self):
            return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_last_known_file_type

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLast_known_file_type" ):
                listener.enterLast_known_file_type(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLast_known_file_type" ):
                listener.exitLast_known_file_type(self)




    def last_known_file_type(self):

        localctx = PBXProjParser.Last_known_file_typeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 200, self.RULE_last_known_file_type)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1366
            self.match(PBXProjParser.LAST_KNOWN_FILE_TYPE)
            self.state = 1367
            self.match(PBXProjParser.T__2)
            self.state = 1368
            self.str_number_variable()
            self.state = 1369
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Include_in_indexContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def INCLUDE_IN_INDEX(self):
            return self.getToken(PBXProjParser.INCLUDE_IN_INDEX, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_include_in_index

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInclude_in_index" ):
                listener.enterInclude_in_index(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInclude_in_index" ):
                listener.exitInclude_in_index(self)




    def include_in_index(self):

        localctx = PBXProjParser.Include_in_indexContext(self, self._ctx, self.state)
        self.enterRule(localctx, 202, self.RULE_include_in_index)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1371
            self.match(PBXProjParser.INCLUDE_IN_INDEX)
            self.state = 1372
            self.match(PBXProjParser.T__2)
            self.state = 1373
            self.match(PBXProjParser.NUMBER)
            self.state = 1374
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Indent_widthContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def INDENT_WIDTH(self):
            return self.getToken(PBXProjParser.INDENT_WIDTH, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_indent_width

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIndent_width" ):
                listener.enterIndent_width(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIndent_width" ):
                listener.exitIndent_width(self)




    def indent_width(self):

        localctx = PBXProjParser.Indent_widthContext(self, self._ctx, self.state)
        self.enterRule(localctx, 204, self.RULE_indent_width)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1376
            self.match(PBXProjParser.INDENT_WIDTH)
            self.state = 1377
            self.match(PBXProjParser.T__2)
            self.state = 1378
            self.match(PBXProjParser.NUMBER)
            self.state = 1379
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Tab_widthContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def TAB_WIDTH(self):
            return self.getToken(PBXProjParser.TAB_WIDTH, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_tab_width

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTab_width" ):
                listener.enterTab_width(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTab_width" ):
                listener.exitTab_width(self)




    def tab_width(self):

        localctx = PBXProjParser.Tab_widthContext(self, self._ctx, self.state)
        self.enterRule(localctx, 206, self.RULE_tab_width)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1381
            self.match(PBXProjParser.TAB_WIDTH)
            self.state = 1382
            self.match(PBXProjParser.T__2)
            self.state = 1383
            self.match(PBXProjParser.NUMBER)
            self.state = 1384
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Uses_tabsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def USES_TABS(self):
            return self.getToken(PBXProjParser.USES_TABS, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_uses_tabs

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterUses_tabs" ):
                listener.enterUses_tabs(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitUses_tabs" ):
                listener.exitUses_tabs(self)




    def uses_tabs(self):

        localctx = PBXProjParser.Uses_tabsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 208, self.RULE_uses_tabs)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1386
            self.match(PBXProjParser.USES_TABS)
            self.state = 1387
            self.match(PBXProjParser.T__2)
            self.state = 1388
            self.match(PBXProjParser.NUMBER)
            self.state = 1389
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Wraps_linesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def WRAPS_LINES(self):
            return self.getToken(PBXProjParser.WRAPS_LINES, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_wraps_lines

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterWraps_lines" ):
                listener.enterWraps_lines(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitWraps_lines" ):
                listener.exitWraps_lines(self)




    def wraps_lines(self):

        localctx = PBXProjParser.Wraps_linesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 210, self.RULE_wraps_lines)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1391
            self.match(PBXProjParser.WRAPS_LINES)
            self.state = 1392
            self.match(PBXProjParser.T__2)
            self.state = 1393
            self.match(PBXProjParser.NUMBER)
            self.state = 1394
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Platform_filterContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PLATFORM_FILTER(self):
            return self.getToken(PBXProjParser.PLATFORM_FILTER, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_platform_filter

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPlatform_filter" ):
                listener.enterPlatform_filter(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPlatform_filter" ):
                listener.exitPlatform_filter(self)




    def platform_filter(self):

        localctx = PBXProjParser.Platform_filterContext(self, self._ctx, self.state)
        self.enterRule(localctx, 212, self.RULE_platform_filter)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1396
            self.match(PBXProjParser.PLATFORM_FILTER)
            self.state = 1397
            self.match(PBXProjParser.T__2)
            self.state = 1398
            self.any_string()
            self.state = 1399
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Platform_filtersContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PLATFORM_FILTERS(self):
            return self.getToken(PBXProjParser.PLATFORM_FILTERS, 0)

        def any_string_list(self):
            return self.getTypedRuleContext(PBXProjParser.Any_string_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_platform_filters

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPlatform_filters" ):
                listener.enterPlatform_filters(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPlatform_filters" ):
                listener.exitPlatform_filters(self)




    def platform_filters(self):

        localctx = PBXProjParser.Platform_filtersContext(self, self._ctx, self.state)
        self.enterRule(localctx, 214, self.RULE_platform_filters)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1401
            self.match(PBXProjParser.PLATFORM_FILTERS)
            self.state = 1402
            self.match(PBXProjParser.T__2)
            self.state = 1403
            self.any_string_list()
            self.state = 1404
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ChildrenContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CHILDREN(self):
            return self.getToken(PBXProjParser.CHILDREN, 0)

        def reference_list(self):
            return self.getTypedRuleContext(PBXProjParser.Reference_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_children

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterChildren" ):
                listener.enterChildren(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitChildren" ):
                listener.exitChildren(self)




    def children(self):

        localctx = PBXProjParser.ChildrenContext(self, self._ctx, self.state)
        self.enterRule(localctx, 216, self.RULE_children)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1406
            self.match(PBXProjParser.CHILDREN)
            self.state = 1407
            self.match(PBXProjParser.T__2)
            self.state = 1408
            self.reference_list()
            self.state = 1409
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Product_install_pathContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PRODUCT_INSTALL_PATH(self):
            return self.getToken(PBXProjParser.PRODUCT_INSTALL_PATH, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_product_install_path

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProduct_install_path" ):
                listener.enterProduct_install_path(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProduct_install_path" ):
                listener.exitProduct_install_path(self)




    def product_install_path(self):

        localctx = PBXProjParser.Product_install_pathContext(self, self._ctx, self.state)
        self.enterRule(localctx, 218, self.RULE_product_install_path)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1411
            self.match(PBXProjParser.PRODUCT_INSTALL_PATH)
            self.state = 1412
            self.match(PBXProjParser.T__2)
            self.state = 1413
            self.any_string()
            self.state = 1414
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Repository_urlContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REPOSITORY_URL(self):
            return self.getToken(PBXProjParser.REPOSITORY_URL, 0)

        def QUOTED_STRING(self):
            return self.getToken(PBXProjParser.QUOTED_STRING, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_repository_url

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRepository_url" ):
                listener.enterRepository_url(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRepository_url" ):
                listener.exitRepository_url(self)




    def repository_url(self):

        localctx = PBXProjParser.Repository_urlContext(self, self._ctx, self.state)
        self.enterRule(localctx, 220, self.RULE_repository_url)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1416
            self.match(PBXProjParser.REPOSITORY_URL)
            self.state = 1417
            self.match(PBXProjParser.T__2)
            self.state = 1418
            self.match(PBXProjParser.QUOTED_STRING)
            self.state = 1419
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class RequirementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REQUIREMENT(self):
            return self.getToken(PBXProjParser.REQUIREMENT, 0)

        def key_value(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Key_valueContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Key_valueContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_requirement

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRequirement" ):
                listener.enterRequirement(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRequirement" ):
                listener.exitRequirement(self)




    def requirement(self):

        localctx = PBXProjParser.RequirementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 222, self.RULE_requirement)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1421
            self.match(PBXProjParser.REQUIREMENT)
            self.state = 1422
            self.match(PBXProjParser.T__2)
            self.state = 1423
            self.match(PBXProjParser.T__0)
            self.state = 1427
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & -141015588143360) != 0) or ((((_la - 64)) & ~0x3f) == 0 and ((1 << (_la - 64)) & -1) != 0) or ((((_la - 128)) & ~0x3f) == 0 and ((1 << (_la - 128)) & 4026523647) != 0):
                self.state = 1424
                self.key_value()
                self.state = 1429
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 1430
            self.match(PBXProjParser.T__1)
            self.state = 1431
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Xc_packageContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PACKAGE(self):
            return self.getToken(PBXProjParser.PACKAGE, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_xc_package

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXc_package" ):
                listener.enterXc_package(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXc_package" ):
                listener.exitXc_package(self)




    def xc_package(self):

        localctx = PBXProjParser.Xc_packageContext(self, self._ctx, self.state)
        self.enterRule(localctx, 224, self.RULE_xc_package)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1433
            self.match(PBXProjParser.PACKAGE)
            self.state = 1434
            self.match(PBXProjParser.T__2)
            self.state = 1435
            self.match(PBXProjParser.REFERENCE)
            self.state = 1436
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Package_product_dependenciesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PACKAGE_PRODUCT_DEPENDENCIES(self):
            return self.getToken(PBXProjParser.PACKAGE_PRODUCT_DEPENDENCIES, 0)

        def reference_list(self):
            return self.getTypedRuleContext(PBXProjParser.Reference_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_package_product_dependencies

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPackage_product_dependencies" ):
                listener.enterPackage_product_dependencies(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPackage_product_dependencies" ):
                listener.exitPackage_product_dependencies(self)




    def package_product_dependencies(self):

        localctx = PBXProjParser.Package_product_dependenciesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 226, self.RULE_package_product_dependencies)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1438
            self.match(PBXProjParser.PACKAGE_PRODUCT_DEPENDENCIES)
            self.state = 1439
            self.match(PBXProjParser.T__2)
            self.state = 1440
            self.reference_list()
            self.state = 1441
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class NameContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NAME(self):
            return self.getToken(PBXProjParser.NAME, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterName" ):
                listener.enterName(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitName" ):
                listener.exitName(self)




    def name(self):

        localctx = PBXProjParser.NameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 228, self.RULE_name)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1443
            self.match(PBXProjParser.NAME)
            self.state = 1444
            self.match(PBXProjParser.T__2)
            self.state = 1445
            self.any_string()
            self.state = 1446
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class PathContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PATH(self):
            return self.getToken(PBXProjParser.PATH, 0)

        def str_number_variable(self):
            return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_path

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPath" ):
                listener.enterPath(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPath" ):
                listener.exitPath(self)




    def path(self):

        localctx = PBXProjParser.PathContext(self, self._ctx, self.state)
        self.enterRule(localctx, 230, self.RULE_path)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1448
            self.match(PBXProjParser.PATH)
            self.state = 1449
            self.match(PBXProjParser.T__2)
            self.state = 1450
            self.str_number_variable()
            self.state = 1451
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Source_treeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SOURCE_TREE(self):
            return self.getToken(PBXProjParser.SOURCE_TREE, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_source_tree

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSource_tree" ):
                listener.enterSource_tree(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSource_tree" ):
                listener.exitSource_tree(self)




    def source_tree(self):

        localctx = PBXProjParser.Source_treeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 232, self.RULE_source_tree)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1453
            self.match(PBXProjParser.SOURCE_TREE)
            self.state = 1454
            self.match(PBXProjParser.T__2)
            self.state = 1455
            self.any_string()
            self.state = 1456
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Build_action_maskContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BUILD_ACTION_MASK(self):
            return self.getToken(PBXProjParser.BUILD_ACTION_MASK, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_build_action_mask

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBuild_action_mask" ):
                listener.enterBuild_action_mask(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBuild_action_mask" ):
                listener.exitBuild_action_mask(self)




    def build_action_mask(self):

        localctx = PBXProjParser.Build_action_maskContext(self, self._ctx, self.state)
        self.enterRule(localctx, 234, self.RULE_build_action_mask)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1458
            self.match(PBXProjParser.BUILD_ACTION_MASK)
            self.state = 1459
            self.match(PBXProjParser.T__2)
            self.state = 1460
            self.match(PBXProjParser.NUMBER)
            self.state = 1461
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class FilesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FILES(self):
            return self.getToken(PBXProjParser.FILES, 0)

        def reference_list(self):
            return self.getTypedRuleContext(PBXProjParser.Reference_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_files

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFiles" ):
                listener.enterFiles(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFiles" ):
                listener.exitFiles(self)




    def files(self):

        localctx = PBXProjParser.FilesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 236, self.RULE_files)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1463
            self.match(PBXProjParser.FILES)
            self.state = 1464
            self.match(PBXProjParser.T__2)
            self.state = 1465
            self.reference_list()
            self.state = 1466
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Run_only_for_deployment_postprocessingContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def RUN_ONLY_FOR_DEPLOYMENT_POSTPROCESSING(self):
            return self.getToken(PBXProjParser.RUN_ONLY_FOR_DEPLOYMENT_POSTPROCESSING, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_run_only_for_deployment_postprocessing

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRun_only_for_deployment_postprocessing" ):
                listener.enterRun_only_for_deployment_postprocessing(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRun_only_for_deployment_postprocessing" ):
                listener.exitRun_only_for_deployment_postprocessing(self)




    def run_only_for_deployment_postprocessing(self):

        localctx = PBXProjParser.Run_only_for_deployment_postprocessingContext(self, self._ctx, self.state)
        self.enterRule(localctx, 238, self.RULE_run_only_for_deployment_postprocessing)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1468
            self.match(PBXProjParser.RUN_ONLY_FOR_DEPLOYMENT_POSTPROCESSING)
            self.state = 1469
            self.match(PBXProjParser.T__2)
            self.state = 1470
            self.match(PBXProjParser.NUMBER)
            self.state = 1471
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Reference_listContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self, i:int=None):
            if i is None:
                return self.getTokens(PBXProjParser.REFERENCE)
            else:
                return self.getToken(PBXProjParser.REFERENCE, i)

        def getRuleIndex(self):
            return PBXProjParser.RULE_reference_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterReference_list" ):
                listener.enterReference_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitReference_list" ):
                listener.exitReference_list(self)




    def reference_list(self):

        localctx = PBXProjParser.Reference_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 240, self.RULE_reference_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1473
            self.match(PBXProjParser.T__4)
            self.state = 1478
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==156:
                self.state = 1474
                self.match(PBXProjParser.REFERENCE)
                self.state = 1475
                self.match(PBXProjParser.T__5)
                self.state = 1480
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 1481
            self.match(PBXProjParser.T__6)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Any_string_listContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def str_number_variable(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Str_number_variableContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_any_string_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAny_string_list" ):
                listener.enterAny_string_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAny_string_list" ):
                listener.exitAny_string_list(self)




    def any_string_list(self):

        localctx = PBXProjParser.Any_string_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 242, self.RULE_any_string_list)
        self._la = 0 # Token type
        try:
            self.state = 1499
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,131,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1483
                self.match(PBXProjParser.T__4)
                self.state = 1484
                self.match(PBXProjParser.T__6)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1485
                self.match(PBXProjParser.T__4)
                self.state = 1486
                self.str_number_variable()
                self.state = 1491
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,129,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 1487
                        self.match(PBXProjParser.T__5)
                        self.state = 1488
                        self.str_number_variable() 
                    self.state = 1493
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,129,self._ctx)

                self.state = 1495
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==6:
                    self.state = 1494
                    self.match(PBXProjParser.T__5)


                self.state = 1497
                self.match(PBXProjParser.T__6)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Non_quoted_strings_listContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NON_QUOTED_STRING(self, i:int=None):
            if i is None:
                return self.getTokens(PBXProjParser.NON_QUOTED_STRING)
            else:
                return self.getToken(PBXProjParser.NON_QUOTED_STRING, i)

        def getRuleIndex(self):
            return PBXProjParser.RULE_non_quoted_strings_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNon_quoted_strings_list" ):
                listener.enterNon_quoted_strings_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNon_quoted_strings_list" ):
                listener.exitNon_quoted_strings_list(self)




    def non_quoted_strings_list(self):

        localctx = PBXProjParser.Non_quoted_strings_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 244, self.RULE_non_quoted_strings_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1501
            self.match(PBXProjParser.T__4)
            self.state = 1506
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==158:
                self.state = 1502
                self.match(PBXProjParser.NON_QUOTED_STRING)
                self.state = 1503
                self.match(PBXProjParser.T__5)
                self.state = 1508
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 1509
            self.match(PBXProjParser.T__6)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Build_configuration_listContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BUILD_CONFIGURATION_LIST(self):
            return self.getToken(PBXProjParser.BUILD_CONFIGURATION_LIST, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_build_configuration_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBuild_configuration_list" ):
                listener.enterBuild_configuration_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBuild_configuration_list" ):
                listener.exitBuild_configuration_list(self)




    def build_configuration_list(self):

        localctx = PBXProjParser.Build_configuration_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 246, self.RULE_build_configuration_list)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1511
            self.match(PBXProjParser.BUILD_CONFIGURATION_LIST)
            self.state = 1512
            self.match(PBXProjParser.T__2)
            self.state = 1513
            self.match(PBXProjParser.REFERENCE)
            self.state = 1514
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Build_phasesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BUILD_PHASES(self):
            return self.getToken(PBXProjParser.BUILD_PHASES, 0)

        def reference_list(self):
            return self.getTypedRuleContext(PBXProjParser.Reference_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_build_phases

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBuild_phases" ):
                listener.enterBuild_phases(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBuild_phases" ):
                listener.exitBuild_phases(self)




    def build_phases(self):

        localctx = PBXProjParser.Build_phasesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 248, self.RULE_build_phases)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1516
            self.match(PBXProjParser.BUILD_PHASES)
            self.state = 1517
            self.match(PBXProjParser.T__2)
            self.state = 1518
            self.reference_list()
            self.state = 1519
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Build_rulesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BUILD_RULES(self):
            return self.getToken(PBXProjParser.BUILD_RULES, 0)

        def reference_list(self):
            return self.getTypedRuleContext(PBXProjParser.Reference_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_build_rules

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBuild_rules" ):
                listener.enterBuild_rules(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBuild_rules" ):
                listener.exitBuild_rules(self)




    def build_rules(self):

        localctx = PBXProjParser.Build_rulesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 250, self.RULE_build_rules)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1521
            self.match(PBXProjParser.BUILD_RULES)
            self.state = 1522
            self.match(PBXProjParser.T__2)
            self.state = 1523
            self.reference_list()
            self.state = 1524
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Build_arguments_stringContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BUILD_ARGUMENTS_STRING(self):
            return self.getToken(PBXProjParser.BUILD_ARGUMENTS_STRING, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_build_arguments_string

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBuild_arguments_string" ):
                listener.enterBuild_arguments_string(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBuild_arguments_string" ):
                listener.exitBuild_arguments_string(self)




    def build_arguments_string(self):

        localctx = PBXProjParser.Build_arguments_stringContext(self, self._ctx, self.state)
        self.enterRule(localctx, 252, self.RULE_build_arguments_string)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1526
            self.match(PBXProjParser.BUILD_ARGUMENTS_STRING)
            self.state = 1527
            self.match(PBXProjParser.T__2)
            self.state = 1528
            self.any_string()
            self.state = 1529
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Build_tool_pathContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BUILD_TOOL_PATH(self):
            return self.getToken(PBXProjParser.BUILD_TOOL_PATH, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_build_tool_path

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBuild_tool_path" ):
                listener.enterBuild_tool_path(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBuild_tool_path" ):
                listener.exitBuild_tool_path(self)




    def build_tool_path(self):

        localctx = PBXProjParser.Build_tool_pathContext(self, self._ctx, self.state)
        self.enterRule(localctx, 254, self.RULE_build_tool_path)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1531
            self.match(PBXProjParser.BUILD_TOOL_PATH)
            self.state = 1532
            self.match(PBXProjParser.T__2)
            self.state = 1533
            self.any_string()
            self.state = 1534
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Build_working_directoryContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BUILD_WORKING_DIRECTORY(self):
            return self.getToken(PBXProjParser.BUILD_WORKING_DIRECTORY, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_build_working_directory

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBuild_working_directory" ):
                listener.enterBuild_working_directory(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBuild_working_directory" ):
                listener.exitBuild_working_directory(self)




    def build_working_directory(self):

        localctx = PBXProjParser.Build_working_directoryContext(self, self._ctx, self.state)
        self.enterRule(localctx, 256, self.RULE_build_working_directory)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1536
            self.match(PBXProjParser.BUILD_WORKING_DIRECTORY)
            self.state = 1537
            self.match(PBXProjParser.T__2)
            self.state = 1538
            self.any_string()
            self.state = 1539
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Pass_build_settings_in_environmentContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PASS_BUILD_SETTINGS_IN_ENVIRONMENT(self):
            return self.getToken(PBXProjParser.PASS_BUILD_SETTINGS_IN_ENVIRONMENT, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_pass_build_settings_in_environment

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPass_build_settings_in_environment" ):
                listener.enterPass_build_settings_in_environment(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPass_build_settings_in_environment" ):
                listener.exitPass_build_settings_in_environment(self)




    def pass_build_settings_in_environment(self):

        localctx = PBXProjParser.Pass_build_settings_in_environmentContext(self, self._ctx, self.state)
        self.enterRule(localctx, 258, self.RULE_pass_build_settings_in_environment)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1541
            self.match(PBXProjParser.PASS_BUILD_SETTINGS_IN_ENVIRONMENT)
            self.state = 1542
            self.match(PBXProjParser.T__2)
            self.state = 1543
            self.match(PBXProjParser.NUMBER)
            self.state = 1544
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class DependenciesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DEPENDENCIES(self):
            return self.getToken(PBXProjParser.DEPENDENCIES, 0)

        def reference_list(self):
            return self.getTypedRuleContext(PBXProjParser.Reference_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_dependencies

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDependencies" ):
                listener.enterDependencies(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDependencies" ):
                listener.exitDependencies(self)




    def dependencies(self):

        localctx = PBXProjParser.DependenciesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 260, self.RULE_dependencies)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1546
            self.match(PBXProjParser.DEPENDENCIES)
            self.state = 1547
            self.match(PBXProjParser.T__2)
            self.state = 1548
            self.reference_list()
            self.state = 1549
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Product_nameContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PRODUCT_NAME(self):
            return self.getToken(PBXProjParser.PRODUCT_NAME, 0)

        def str_number_variable(self):
            return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_product_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProduct_name" ):
                listener.enterProduct_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProduct_name" ):
                listener.exitProduct_name(self)




    def product_name(self):

        localctx = PBXProjParser.Product_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 262, self.RULE_product_name)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1551
            self.match(PBXProjParser.PRODUCT_NAME)
            self.state = 1552
            self.match(PBXProjParser.T__2)
            self.state = 1553
            self.str_number_variable()
            self.state = 1554
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Product_referenceContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PRODUCT_REFERENCE(self):
            return self.getToken(PBXProjParser.PRODUCT_REFERENCE, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_product_reference

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProduct_reference" ):
                listener.enterProduct_reference(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProduct_reference" ):
                listener.exitProduct_reference(self)




    def product_reference(self):

        localctx = PBXProjParser.Product_referenceContext(self, self._ctx, self.state)
        self.enterRule(localctx, 264, self.RULE_product_reference)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1556
            self.match(PBXProjParser.PRODUCT_REFERENCE)
            self.state = 1557
            self.match(PBXProjParser.T__2)
            self.state = 1558
            self.match(PBXProjParser.REFERENCE)
            self.state = 1559
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Product_typeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PRODUCT_TYPE(self):
            return self.getToken(PBXProjParser.PRODUCT_TYPE, 0)

        def QUOTED_STRING(self):
            return self.getToken(PBXProjParser.QUOTED_STRING, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_product_type

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProduct_type" ):
                listener.enterProduct_type(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProduct_type" ):
                listener.exitProduct_type(self)




    def product_type(self):

        localctx = PBXProjParser.Product_typeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 266, self.RULE_product_type)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1561
            self.match(PBXProjParser.PRODUCT_TYPE)
            self.state = 1562
            self.match(PBXProjParser.T__2)
            self.state = 1563
            self.match(PBXProjParser.QUOTED_STRING)
            self.state = 1564
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Line_endingContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LINE_ENDING(self):
            return self.getToken(PBXProjParser.LINE_ENDING, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_line_ending

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLine_ending" ):
                listener.enterLine_ending(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLine_ending" ):
                listener.exitLine_ending(self)




    def line_ending(self):

        localctx = PBXProjParser.Line_endingContext(self, self._ctx, self.state)
        self.enterRule(localctx, 268, self.RULE_line_ending)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1566
            self.match(PBXProjParser.LINE_ENDING)
            self.state = 1567
            self.match(PBXProjParser.T__2)
            self.state = 1568
            self.match(PBXProjParser.NUMBER)
            self.state = 1569
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Xc_language_specification_identifierContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def XC_LANGUAGE_SPECIFICATION_IDENTIFIER(self):
            return self.getToken(PBXProjParser.XC_LANGUAGE_SPECIFICATION_IDENTIFIER, 0)

        def str_number_variable(self):
            return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_xc_language_specification_identifier

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterXc_language_specification_identifier" ):
                listener.enterXc_language_specification_identifier(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitXc_language_specification_identifier" ):
                listener.exitXc_language_specification_identifier(self)




    def xc_language_specification_identifier(self):

        localctx = PBXProjParser.Xc_language_specification_identifierContext(self, self._ctx, self.state)
        self.enterRule(localctx, 270, self.RULE_xc_language_specification_identifier)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1571
            self.match(PBXProjParser.XC_LANGUAGE_SPECIFICATION_IDENTIFIER)
            self.state = 1572
            self.match(PBXProjParser.T__2)
            self.state = 1573
            self.str_number_variable()
            self.state = 1574
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Plist_structure_definition_identifierContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PLIST_STRUCTURE_DEFINITION_IDENTIFIER(self):
            return self.getToken(PBXProjParser.PLIST_STRUCTURE_DEFINITION_IDENTIFIER, 0)

        def str_number_variable(self):
            return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_plist_structure_definition_identifier

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPlist_structure_definition_identifier" ):
                listener.enterPlist_structure_definition_identifier(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPlist_structure_definition_identifier" ):
                listener.exitPlist_structure_definition_identifier(self)




    def plist_structure_definition_identifier(self):

        localctx = PBXProjParser.Plist_structure_definition_identifierContext(self, self._ctx, self.state)
        self.enterRule(localctx, 272, self.RULE_plist_structure_definition_identifier)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1576
            self.match(PBXProjParser.PLIST_STRUCTURE_DEFINITION_IDENTIFIER)
            self.state = 1577
            self.match(PBXProjParser.T__2)
            self.state = 1578
            self.str_number_variable()
            self.state = 1579
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Ref_typeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REF_TYPE(self):
            return self.getToken(PBXProjParser.REF_TYPE, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_ref_type

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRef_type" ):
                listener.enterRef_type(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRef_type" ):
                listener.exitRef_type(self)




    def ref_type(self):

        localctx = PBXProjParser.Ref_typeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 274, self.RULE_ref_type)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1581
            self.match(PBXProjParser.REF_TYPE)
            self.state = 1582
            self.match(PBXProjParser.T__2)
            self.state = 1583
            self.match(PBXProjParser.NUMBER)
            self.state = 1584
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Compiler_specContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def COMPILER_SPEC(self):
            return self.getToken(PBXProjParser.COMPILER_SPEC, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_compiler_spec

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCompiler_spec" ):
                listener.enterCompiler_spec(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCompiler_spec" ):
                listener.exitCompiler_spec(self)




    def compiler_spec(self):

        localctx = PBXProjParser.Compiler_specContext(self, self._ctx, self.state)
        self.enterRule(localctx, 276, self.RULE_compiler_spec)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1586
            self.match(PBXProjParser.COMPILER_SPEC)
            self.state = 1587
            self.match(PBXProjParser.T__2)
            self.state = 1588
            self.any_string()
            self.state = 1589
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class File_patternsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FILE_PATTERNS(self):
            return self.getToken(PBXProjParser.FILE_PATTERNS, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_file_patterns

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFile_patterns" ):
                listener.enterFile_patterns(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFile_patterns" ):
                listener.exitFile_patterns(self)




    def file_patterns(self):

        localctx = PBXProjParser.File_patternsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 278, self.RULE_file_patterns)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1591
            self.match(PBXProjParser.FILE_PATTERNS)
            self.state = 1592
            self.match(PBXProjParser.T__2)
            self.state = 1593
            self.any_string()
            self.state = 1594
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Input_filesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def INPUT_FILES(self):
            return self.getToken(PBXProjParser.INPUT_FILES, 0)

        def any_string_list(self):
            return self.getTypedRuleContext(PBXProjParser.Any_string_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_input_files

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInput_files" ):
                listener.enterInput_files(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInput_files" ):
                listener.exitInput_files(self)




    def input_files(self):

        localctx = PBXProjParser.Input_filesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 280, self.RULE_input_files)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1596
            self.match(PBXProjParser.INPUT_FILES)
            self.state = 1597
            self.match(PBXProjParser.T__2)
            self.state = 1598
            self.any_string_list()
            self.state = 1599
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Is_editableContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def IS_EDITABLE(self):
            return self.getToken(PBXProjParser.IS_EDITABLE, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_is_editable

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterIs_editable" ):
                listener.enterIs_editable(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitIs_editable" ):
                listener.exitIs_editable(self)




    def is_editable(self):

        localctx = PBXProjParser.Is_editableContext(self, self._ctx, self.state)
        self.enterRule(localctx, 282, self.RULE_is_editable)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1601
            self.match(PBXProjParser.IS_EDITABLE)
            self.state = 1602
            self.match(PBXProjParser.T__2)
            self.state = 1603
            self.match(PBXProjParser.NUMBER)
            self.state = 1604
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Output_filesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def OUTPUT_FILES(self):
            return self.getToken(PBXProjParser.OUTPUT_FILES, 0)

        def any_string_list(self):
            return self.getTypedRuleContext(PBXProjParser.Any_string_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_output_files

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOutput_files" ):
                listener.enterOutput_files(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOutput_files" ):
                listener.exitOutput_files(self)




    def output_files(self):

        localctx = PBXProjParser.Output_filesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 284, self.RULE_output_files)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1606
            self.match(PBXProjParser.OUTPUT_FILES)
            self.state = 1607
            self.match(PBXProjParser.T__2)
            self.state = 1608
            self.any_string_list()
            self.state = 1609
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Run_once_per_archContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def RUN_ONCE_PER_ARCH(self):
            return self.getToken(PBXProjParser.RUN_ONCE_PER_ARCH, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_run_once_per_arch

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRun_once_per_arch" ):
                listener.enterRun_once_per_arch(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRun_once_per_arch" ):
                listener.exitRun_once_per_arch(self)




    def run_once_per_arch(self):

        localctx = PBXProjParser.Run_once_per_archContext(self, self._ctx, self.state)
        self.enterRule(localctx, 286, self.RULE_run_once_per_arch)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1611
            self.match(PBXProjParser.RUN_ONCE_PER_ARCH)
            self.state = 1612
            self.match(PBXProjParser.T__2)
            self.state = 1613
            self.match(PBXProjParser.NUMBER)
            self.state = 1614
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ScriptContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SCRIPT(self):
            return self.getToken(PBXProjParser.SCRIPT, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_script

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterScript" ):
                listener.enterScript(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitScript" ):
                listener.exitScript(self)




    def script(self):

        localctx = PBXProjParser.ScriptContext(self, self._ctx, self.state)
        self.enterRule(localctx, 288, self.RULE_script)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1616
            self.match(PBXProjParser.SCRIPT)
            self.state = 1617
            self.match(PBXProjParser.T__2)
            self.state = 1618
            self.any_string()
            self.state = 1619
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AttributesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ATTRIBUTES(self):
            return self.getToken(PBXProjParser.ATTRIBUTES, 0)

        def build_targets_in_parallel(self):
            return self.getTypedRuleContext(PBXProjParser.Build_targets_in_parallelContext,0)


        def class_prefix(self):
            return self.getTypedRuleContext(PBXProjParser.Class_prefixContext,0)


        def default_build_system_type_for_workspace(self):
            return self.getTypedRuleContext(PBXProjParser.Default_build_system_type_for_workspaceContext,0)


        def last_swift_migration(self):
            return self.getTypedRuleContext(PBXProjParser.Last_swift_migrationContext,0)


        def last_swift_update_check(self):
            return self.getTypedRuleContext(PBXProjParser.Last_swift_update_checkContext,0)


        def last_testing_upgrade_check(self):
            return self.getTypedRuleContext(PBXProjParser.Last_testing_upgrade_checkContext,0)


        def last_upgrade_check(self):
            return self.getTypedRuleContext(PBXProjParser.Last_upgrade_checkContext,0)


        def organization_name(self):
            return self.getTypedRuleContext(PBXProjParser.Organization_nameContext,0)


        def target_attributes(self):
            return self.getTypedRuleContext(PBXProjParser.Target_attributesContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_attributes

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAttributes" ):
                listener.enterAttributes(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAttributes" ):
                listener.exitAttributes(self)




    def attributes(self):

        localctx = PBXProjParser.AttributesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 290, self.RULE_attributes)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1621
            self.match(PBXProjParser.ATTRIBUTES)
            self.state = 1622
            self.match(PBXProjParser.T__2)
            self.state = 1623
            self.match(PBXProjParser.T__0)
            self.state = 1625
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==105:
                self.state = 1624
                self.build_targets_in_parallel()


            self.state = 1628
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==155:
                self.state = 1627
                self.class_prefix()


            self.state = 1631
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==103:
                self.state = 1630
                self.default_build_system_type_for_workspace()


            self.state = 1634
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==102:
                self.state = 1633
                self.last_swift_migration()


            self.state = 1637
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==104:
                self.state = 1636
                self.last_swift_update_check()


            self.state = 1640
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==106:
                self.state = 1639
                self.last_testing_upgrade_check()


            self.state = 1643
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==107:
                self.state = 1642
                self.last_upgrade_check()


            self.state = 1646
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==108:
                self.state = 1645
                self.organization_name()


            self.state = 1649
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==109:
                self.state = 1648
                self.target_attributes()


            self.state = 1651
            self.match(PBXProjParser.T__1)
            self.state = 1652
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Last_swift_migrationContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LAST_SWIFT_MIGRATION(self):
            return self.getToken(PBXProjParser.LAST_SWIFT_MIGRATION, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_last_swift_migration

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLast_swift_migration" ):
                listener.enterLast_swift_migration(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLast_swift_migration" ):
                listener.exitLast_swift_migration(self)




    def last_swift_migration(self):

        localctx = PBXProjParser.Last_swift_migrationContext(self, self._ctx, self.state)
        self.enterRule(localctx, 292, self.RULE_last_swift_migration)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1654
            self.match(PBXProjParser.LAST_SWIFT_MIGRATION)
            self.state = 1655
            self.match(PBXProjParser.T__2)
            self.state = 1656
            self.match(PBXProjParser.NUMBER)
            self.state = 1657
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Default_build_system_type_for_workspaceContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DEFAULT_BUILD_SYSTEM_TYPE_FOR_WORKSPACE(self):
            return self.getToken(PBXProjParser.DEFAULT_BUILD_SYSTEM_TYPE_FOR_WORKSPACE, 0)

        def NON_QUOTED_STRING(self):
            return self.getToken(PBXProjParser.NON_QUOTED_STRING, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_default_build_system_type_for_workspace

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDefault_build_system_type_for_workspace" ):
                listener.enterDefault_build_system_type_for_workspace(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDefault_build_system_type_for_workspace" ):
                listener.exitDefault_build_system_type_for_workspace(self)




    def default_build_system_type_for_workspace(self):

        localctx = PBXProjParser.Default_build_system_type_for_workspaceContext(self, self._ctx, self.state)
        self.enterRule(localctx, 294, self.RULE_default_build_system_type_for_workspace)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1659
            self.match(PBXProjParser.DEFAULT_BUILD_SYSTEM_TYPE_FOR_WORKSPACE)
            self.state = 1660
            self.match(PBXProjParser.T__2)
            self.state = 1661
            self.match(PBXProjParser.NON_QUOTED_STRING)
            self.state = 1662
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Last_swift_update_checkContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LAST_SWIFT_UPDATE_CHECK(self):
            return self.getToken(PBXProjParser.LAST_SWIFT_UPDATE_CHECK, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_last_swift_update_check

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLast_swift_update_check" ):
                listener.enterLast_swift_update_check(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLast_swift_update_check" ):
                listener.exitLast_swift_update_check(self)




    def last_swift_update_check(self):

        localctx = PBXProjParser.Last_swift_update_checkContext(self, self._ctx, self.state)
        self.enterRule(localctx, 296, self.RULE_last_swift_update_check)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1664
            self.match(PBXProjParser.LAST_SWIFT_UPDATE_CHECK)
            self.state = 1665
            self.match(PBXProjParser.T__2)
            self.state = 1666
            self.match(PBXProjParser.NUMBER)
            self.state = 1667
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Build_targets_in_parallelContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BUILD_INDEPENDENT_TARGETS_IN_PARALLEL(self):
            return self.getToken(PBXProjParser.BUILD_INDEPENDENT_TARGETS_IN_PARALLEL, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def NON_QUOTED_STRING(self):
            return self.getToken(PBXProjParser.NON_QUOTED_STRING, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_build_targets_in_parallel

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBuild_targets_in_parallel" ):
                listener.enterBuild_targets_in_parallel(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBuild_targets_in_parallel" ):
                listener.exitBuild_targets_in_parallel(self)




    def build_targets_in_parallel(self):

        localctx = PBXProjParser.Build_targets_in_parallelContext(self, self._ctx, self.state)
        self.enterRule(localctx, 298, self.RULE_build_targets_in_parallel)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1669
            self.match(PBXProjParser.BUILD_INDEPENDENT_TARGETS_IN_PARALLEL)
            self.state = 1670
            self.match(PBXProjParser.T__2)
            self.state = 1671
            _la = self._input.LA(1)
            if not(_la==13 or _la==158):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
            self.state = 1672
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Last_testing_upgrade_checkContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LAST_TESTING_UPGRADE_CHECK(self):
            return self.getToken(PBXProjParser.LAST_TESTING_UPGRADE_CHECK, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_last_testing_upgrade_check

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLast_testing_upgrade_check" ):
                listener.enterLast_testing_upgrade_check(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLast_testing_upgrade_check" ):
                listener.exitLast_testing_upgrade_check(self)




    def last_testing_upgrade_check(self):

        localctx = PBXProjParser.Last_testing_upgrade_checkContext(self, self._ctx, self.state)
        self.enterRule(localctx, 300, self.RULE_last_testing_upgrade_check)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1674
            self.match(PBXProjParser.LAST_TESTING_UPGRADE_CHECK)
            self.state = 1675
            self.match(PBXProjParser.T__2)
            self.state = 1676
            self.match(PBXProjParser.NUMBER)
            self.state = 1677
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Last_upgrade_checkContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def LAST_UPGRADE_CHECK(self):
            return self.getToken(PBXProjParser.LAST_UPGRADE_CHECK, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_last_upgrade_check

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterLast_upgrade_check" ):
                listener.enterLast_upgrade_check(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitLast_upgrade_check" ):
                listener.exitLast_upgrade_check(self)




    def last_upgrade_check(self):

        localctx = PBXProjParser.Last_upgrade_checkContext(self, self._ctx, self.state)
        self.enterRule(localctx, 302, self.RULE_last_upgrade_check)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1679
            self.match(PBXProjParser.LAST_UPGRADE_CHECK)
            self.state = 1680
            self.match(PBXProjParser.T__2)
            self.state = 1681
            self.match(PBXProjParser.NUMBER)
            self.state = 1682
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Organization_nameContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ORGANIZATION_NAME(self):
            return self.getToken(PBXProjParser.ORGANIZATION_NAME, 0)

        def str_number_variable(self):
            return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_organization_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOrganization_name" ):
                listener.enterOrganization_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOrganization_name" ):
                listener.exitOrganization_name(self)




    def organization_name(self):

        localctx = PBXProjParser.Organization_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 304, self.RULE_organization_name)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1684
            self.match(PBXProjParser.ORGANIZATION_NAME)
            self.state = 1685
            self.match(PBXProjParser.T__2)
            self.state = 1686
            self.str_number_variable()
            self.state = 1687
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Target_attributesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def TARGET_ATTRIBUTES(self):
            return self.getToken(PBXProjParser.TARGET_ATTRIBUTES, 0)

        def target_attribute(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Target_attributeContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Target_attributeContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_target_attributes

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTarget_attributes" ):
                listener.enterTarget_attributes(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTarget_attributes" ):
                listener.exitTarget_attributes(self)




    def target_attributes(self):

        localctx = PBXProjParser.Target_attributesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 306, self.RULE_target_attributes)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1689
            self.match(PBXProjParser.TARGET_ATTRIBUTES)
            self.state = 1690
            self.match(PBXProjParser.T__2)
            self.state = 1691
            self.match(PBXProjParser.T__0)
            self.state = 1695
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==156:
                self.state = 1692
                self.target_attribute()
                self.state = 1697
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 1698
            self.match(PBXProjParser.T__1)
            self.state = 1699
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Target_attributeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def created_on_tools_version(self):
            return self.getTypedRuleContext(PBXProjParser.Created_on_tools_versionContext,0)


        def test_target_id(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Test_target_idContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Test_target_idContext,i)


        def development_team(self):
            return self.getTypedRuleContext(PBXProjParser.Development_teamContext,0)


        def development_team_name(self):
            return self.getTypedRuleContext(PBXProjParser.Development_team_nameContext,0)


        def last_swift_migration(self):
            return self.getTypedRuleContext(PBXProjParser.Last_swift_migrationContext,0)


        def provisioning_style(self):
            return self.getTypedRuleContext(PBXProjParser.Provisioning_styleContext,0)


        def system_capabilities(self):
            return self.getTypedRuleContext(PBXProjParser.System_capabilitiesContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_target_attribute

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTarget_attribute" ):
                listener.enterTarget_attribute(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTarget_attribute" ):
                listener.exitTarget_attribute(self)




    def target_attribute(self):

        localctx = PBXProjParser.Target_attributeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 308, self.RULE_target_attribute)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1701
            self.match(PBXProjParser.REFERENCE)
            self.state = 1702
            self.match(PBXProjParser.T__2)
            self.state = 1703
            self.match(PBXProjParser.T__0)
            self.state = 1705
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==110:
                self.state = 1704
                self.created_on_tools_version()


            self.state = 1708
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,144,self._ctx)
            if la_ == 1:
                self.state = 1707
                self.test_target_id()


            self.state = 1711
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==112:
                self.state = 1710
                self.development_team()


            self.state = 1714
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==113:
                self.state = 1713
                self.development_team_name()


            self.state = 1717
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==102:
                self.state = 1716
                self.last_swift_migration()


            self.state = 1720
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==114:
                self.state = 1719
                self.provisioning_style()


            self.state = 1723
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==150:
                self.state = 1722
                self.system_capabilities()


            self.state = 1726
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==111:
                self.state = 1725
                self.test_target_id()


            self.state = 1728
            self.match(PBXProjParser.T__1)
            self.state = 1729
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Created_on_tools_versionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CREATED_ON_TOOLS_VERSION(self):
            return self.getToken(PBXProjParser.CREATED_ON_TOOLS_VERSION, 0)

        def NON_QUOTED_STRING(self):
            return self.getToken(PBXProjParser.NON_QUOTED_STRING, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_created_on_tools_version

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCreated_on_tools_version" ):
                listener.enterCreated_on_tools_version(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCreated_on_tools_version" ):
                listener.exitCreated_on_tools_version(self)




    def created_on_tools_version(self):

        localctx = PBXProjParser.Created_on_tools_versionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 310, self.RULE_created_on_tools_version)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1731
            self.match(PBXProjParser.CREATED_ON_TOOLS_VERSION)
            self.state = 1732
            self.match(PBXProjParser.T__2)
            self.state = 1733
            self.match(PBXProjParser.NON_QUOTED_STRING)
            self.state = 1734
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Test_target_idContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def TEST_TARGET_ID(self):
            return self.getToken(PBXProjParser.TEST_TARGET_ID, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_test_target_id

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTest_target_id" ):
                listener.enterTest_target_id(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTest_target_id" ):
                listener.exitTest_target_id(self)




    def test_target_id(self):

        localctx = PBXProjParser.Test_target_idContext(self, self._ctx, self.state)
        self.enterRule(localctx, 312, self.RULE_test_target_id)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1736
            self.match(PBXProjParser.TEST_TARGET_ID)
            self.state = 1737
            self.match(PBXProjParser.T__2)
            self.state = 1738
            self.match(PBXProjParser.REFERENCE)
            self.state = 1739
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Development_teamContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DEVELOPMENT_TEAM(self):
            return self.getToken(PBXProjParser.DEVELOPMENT_TEAM, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_development_team

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDevelopment_team" ):
                listener.enterDevelopment_team(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDevelopment_team" ):
                listener.exitDevelopment_team(self)




    def development_team(self):

        localctx = PBXProjParser.Development_teamContext(self, self._ctx, self.state)
        self.enterRule(localctx, 314, self.RULE_development_team)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1741
            self.match(PBXProjParser.DEVELOPMENT_TEAM)
            self.state = 1742
            self.match(PBXProjParser.T__2)
            self.state = 1743
            self.any_string()
            self.state = 1744
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Development_team_nameContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DEVELOPMENT_TEAM_NAME(self):
            return self.getToken(PBXProjParser.DEVELOPMENT_TEAM_NAME, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_development_team_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDevelopment_team_name" ):
                listener.enterDevelopment_team_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDevelopment_team_name" ):
                listener.exitDevelopment_team_name(self)




    def development_team_name(self):

        localctx = PBXProjParser.Development_team_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 316, self.RULE_development_team_name)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1746
            self.match(PBXProjParser.DEVELOPMENT_TEAM_NAME)
            self.state = 1747
            self.match(PBXProjParser.T__2)
            self.state = 1748
            self.any_string()
            self.state = 1749
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Provisioning_styleContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PROVISIONING_STYLE(self):
            return self.getToken(PBXProjParser.PROVISIONING_STYLE, 0)

        def NON_QUOTED_STRING(self):
            return self.getToken(PBXProjParser.NON_QUOTED_STRING, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_provisioning_style

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProvisioning_style" ):
                listener.enterProvisioning_style(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProvisioning_style" ):
                listener.exitProvisioning_style(self)




    def provisioning_style(self):

        localctx = PBXProjParser.Provisioning_styleContext(self, self._ctx, self.state)
        self.enterRule(localctx, 318, self.RULE_provisioning_style)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1751
            self.match(PBXProjParser.PROVISIONING_STYLE)
            self.state = 1752
            self.match(PBXProjParser.T__2)
            self.state = 1753
            self.match(PBXProjParser.NON_QUOTED_STRING)
            self.state = 1754
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Compatibility_versionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def COMPATIBILITY_VERSION(self):
            return self.getToken(PBXProjParser.COMPATIBILITY_VERSION, 0)

        def QUOTED_STRING(self):
            return self.getToken(PBXProjParser.QUOTED_STRING, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_compatibility_version

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCompatibility_version" ):
                listener.enterCompatibility_version(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCompatibility_version" ):
                listener.exitCompatibility_version(self)




    def compatibility_version(self):

        localctx = PBXProjParser.Compatibility_versionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 320, self.RULE_compatibility_version)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1756
            self.match(PBXProjParser.COMPATIBILITY_VERSION)
            self.state = 1757
            self.match(PBXProjParser.T__2)
            self.state = 1758
            self.match(PBXProjParser.QUOTED_STRING)
            self.state = 1759
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Development_regionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DEVELOPMENT_REGION(self):
            return self.getToken(PBXProjParser.DEVELOPMENT_REGION, 0)

        def NON_QUOTED_STRING(self):
            return self.getToken(PBXProjParser.NON_QUOTED_STRING, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_development_region

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDevelopment_region" ):
                listener.enterDevelopment_region(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDevelopment_region" ):
                listener.exitDevelopment_region(self)




    def development_region(self):

        localctx = PBXProjParser.Development_regionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 322, self.RULE_development_region)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1761
            self.match(PBXProjParser.DEVELOPMENT_REGION)
            self.state = 1762
            self.match(PBXProjParser.T__2)
            self.state = 1763
            self.match(PBXProjParser.NON_QUOTED_STRING)
            self.state = 1764
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Has_scanned_for_encodingsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def HAS_SCANNED_FOR_ENCODINGS(self):
            return self.getToken(PBXProjParser.HAS_SCANNED_FOR_ENCODINGS, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_has_scanned_for_encodings

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterHas_scanned_for_encodings" ):
                listener.enterHas_scanned_for_encodings(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitHas_scanned_for_encodings" ):
                listener.exitHas_scanned_for_encodings(self)




    def has_scanned_for_encodings(self):

        localctx = PBXProjParser.Has_scanned_for_encodingsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 324, self.RULE_has_scanned_for_encodings)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1766
            self.match(PBXProjParser.HAS_SCANNED_FOR_ENCODINGS)
            self.state = 1767
            self.match(PBXProjParser.T__2)
            self.state = 1768
            self.match(PBXProjParser.NUMBER)
            self.state = 1769
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Known_regionsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def KNOWN_REGIONS(self):
            return self.getToken(PBXProjParser.KNOWN_REGIONS, 0)

        def any_string_list(self):
            return self.getTypedRuleContext(PBXProjParser.Any_string_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_known_regions

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterKnown_regions" ):
                listener.enterKnown_regions(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitKnown_regions" ):
                listener.exitKnown_regions(self)




    def known_regions(self):

        localctx = PBXProjParser.Known_regionsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 326, self.RULE_known_regions)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1771
            self.match(PBXProjParser.KNOWN_REGIONS)
            self.state = 1772
            self.match(PBXProjParser.T__2)
            self.state = 1773
            self.any_string_list()
            self.state = 1774
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Main_groupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def MAIN_GROUP(self):
            return self.getToken(PBXProjParser.MAIN_GROUP, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_main_group

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterMain_group" ):
                listener.enterMain_group(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitMain_group" ):
                listener.exitMain_group(self)




    def main_group(self):

        localctx = PBXProjParser.Main_groupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 328, self.RULE_main_group)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1776
            self.match(PBXProjParser.MAIN_GROUP)
            self.state = 1777
            self.match(PBXProjParser.T__2)
            self.state = 1778
            self.match(PBXProjParser.REFERENCE)
            self.state = 1779
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Product_ref_groupContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PRODUCT_REF_GROUP(self):
            return self.getToken(PBXProjParser.PRODUCT_REF_GROUP, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_product_ref_group

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProduct_ref_group" ):
                listener.enterProduct_ref_group(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProduct_ref_group" ):
                listener.exitProduct_ref_group(self)




    def product_ref_group(self):

        localctx = PBXProjParser.Product_ref_groupContext(self, self._ctx, self.state)
        self.enterRule(localctx, 330, self.RULE_product_ref_group)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1781
            self.match(PBXProjParser.PRODUCT_REF_GROUP)
            self.state = 1782
            self.match(PBXProjParser.T__2)
            self.state = 1783
            self.match(PBXProjParser.REFERENCE)
            self.state = 1784
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Package_referencesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PACKAGE_REFERENCES(self):
            return self.getToken(PBXProjParser.PACKAGE_REFERENCES, 0)

        def reference_list(self):
            return self.getTypedRuleContext(PBXProjParser.Reference_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_package_references

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPackage_references" ):
                listener.enterPackage_references(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPackage_references" ):
                listener.exitPackage_references(self)




    def package_references(self):

        localctx = PBXProjParser.Package_referencesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 332, self.RULE_package_references)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1786
            self.match(PBXProjParser.PACKAGE_REFERENCES)
            self.state = 1787
            self.match(PBXProjParser.T__2)
            self.state = 1788
            self.reference_list()
            self.state = 1789
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Preferred_project_object_versionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PREFERRED_PROJECT_OBJECT_VERSION(self):
            return self.getToken(PBXProjParser.PREFERRED_PROJECT_OBJECT_VERSION, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_preferred_project_object_version

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPreferred_project_object_version" ):
                listener.enterPreferred_project_object_version(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPreferred_project_object_version" ):
                listener.exitPreferred_project_object_version(self)




    def preferred_project_object_version(self):

        localctx = PBXProjParser.Preferred_project_object_versionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 334, self.RULE_preferred_project_object_version)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1791
            self.match(PBXProjParser.PREFERRED_PROJECT_OBJECT_VERSION)
            self.state = 1792
            self.match(PBXProjParser.T__2)
            self.state = 1793
            self.match(PBXProjParser.NUMBER)
            self.state = 1794
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Project_dir_pathContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PRODUCT_DIR_PATH(self):
            return self.getToken(PBXProjParser.PRODUCT_DIR_PATH, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_project_dir_path

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProject_dir_path" ):
                listener.enterProject_dir_path(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProject_dir_path" ):
                listener.exitProject_dir_path(self)




    def project_dir_path(self):

        localctx = PBXProjParser.Project_dir_pathContext(self, self._ctx, self.state)
        self.enterRule(localctx, 336, self.RULE_project_dir_path)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1796
            self.match(PBXProjParser.PRODUCT_DIR_PATH)
            self.state = 1797
            self.match(PBXProjParser.T__2)
            self.state = 1798
            self.any_string()
            self.state = 1799
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Project_referencesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PROJECT_REFERENCES(self):
            return self.getToken(PBXProjParser.PROJECT_REFERENCES, 0)

        def str_number_variable(self):
            return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,0)


        def project_references_list(self):
            return self.getTypedRuleContext(PBXProjParser.Project_references_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_project_references

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProject_references" ):
                listener.enterProject_references(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProject_references" ):
                listener.exitProject_references(self)




    def project_references(self):

        localctx = PBXProjParser.Project_referencesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 338, self.RULE_project_references)
        try:
            self.state = 1813
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,151,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1801
                self.match(PBXProjParser.PROJECT_REFERENCES)
                self.state = 1802
                self.match(PBXProjParser.T__2)
                self.state = 1803
                self.str_number_variable()
                self.state = 1804
                self.match(PBXProjParser.T__3)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1806
                self.match(PBXProjParser.PROJECT_REFERENCES)
                self.state = 1807
                self.match(PBXProjParser.T__2)
                self.state = 1808
                self.match(PBXProjParser.T__4)
                self.state = 1809
                self.project_references_list()
                self.state = 1810
                self.match(PBXProjParser.T__6)
                self.state = 1811
                self.match(PBXProjParser.T__3)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Project_rootContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PROJECT_ROOT(self):
            return self.getToken(PBXProjParser.PROJECT_ROOT, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_project_root

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProject_root" ):
                listener.enterProject_root(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProject_root" ):
                listener.exitProject_root(self)




    def project_root(self):

        localctx = PBXProjParser.Project_rootContext(self, self._ctx, self.state)
        self.enterRule(localctx, 340, self.RULE_project_root)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1815
            self.match(PBXProjParser.PROJECT_ROOT)
            self.state = 1816
            self.match(PBXProjParser.T__2)
            self.state = 1817
            self.any_string()
            self.state = 1818
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TargetsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def TARGETS(self):
            return self.getToken(PBXProjParser.TARGETS, 0)

        def reference_list(self):
            return self.getTypedRuleContext(PBXProjParser.Reference_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_targets

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTargets" ):
                listener.enterTargets(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTargets" ):
                listener.exitTargets(self)




    def targets(self):

        localctx = PBXProjParser.TargetsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 342, self.RULE_targets)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1820
            self.match(PBXProjParser.TARGETS)
            self.state = 1821
            self.match(PBXProjParser.T__2)
            self.state = 1822
            self.reference_list()
            self.state = 1823
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Input_file_list_pathsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def INPUT_FILE_LIST_PATHS(self):
            return self.getToken(PBXProjParser.INPUT_FILE_LIST_PATHS, 0)

        def any_string_list(self):
            return self.getTypedRuleContext(PBXProjParser.Any_string_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_input_file_list_paths

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInput_file_list_paths" ):
                listener.enterInput_file_list_paths(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInput_file_list_paths" ):
                listener.exitInput_file_list_paths(self)




    def input_file_list_paths(self):

        localctx = PBXProjParser.Input_file_list_pathsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 344, self.RULE_input_file_list_paths)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1825
            self.match(PBXProjParser.INPUT_FILE_LIST_PATHS)
            self.state = 1826
            self.match(PBXProjParser.T__2)
            self.state = 1827
            self.any_string_list()
            self.state = 1828
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Input_pathsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def INPUT_PATHS(self):
            return self.getToken(PBXProjParser.INPUT_PATHS, 0)

        def any_string_list(self):
            return self.getTypedRuleContext(PBXProjParser.Any_string_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_input_paths

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterInput_paths" ):
                listener.enterInput_paths(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitInput_paths" ):
                listener.exitInput_paths(self)




    def input_paths(self):

        localctx = PBXProjParser.Input_pathsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 346, self.RULE_input_paths)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1830
            self.match(PBXProjParser.INPUT_PATHS)
            self.state = 1831
            self.match(PBXProjParser.T__2)
            self.state = 1832
            self.any_string_list()
            self.state = 1833
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Output_file_list_pathsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def OUTPUT_FILE_LIST_PATHS(self):
            return self.getToken(PBXProjParser.OUTPUT_FILE_LIST_PATHS, 0)

        def any_string_list(self):
            return self.getTypedRuleContext(PBXProjParser.Any_string_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_output_file_list_paths

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOutput_file_list_paths" ):
                listener.enterOutput_file_list_paths(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOutput_file_list_paths" ):
                listener.exitOutput_file_list_paths(self)




    def output_file_list_paths(self):

        localctx = PBXProjParser.Output_file_list_pathsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 348, self.RULE_output_file_list_paths)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1835
            self.match(PBXProjParser.OUTPUT_FILE_LIST_PATHS)
            self.state = 1836
            self.match(PBXProjParser.T__2)
            self.state = 1837
            self.any_string_list()
            self.state = 1838
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Output_pathsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def OUTPUT_PATHS(self):
            return self.getToken(PBXProjParser.OUTPUT_PATHS, 0)

        def any_string_list(self):
            return self.getTypedRuleContext(PBXProjParser.Any_string_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_output_paths

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterOutput_paths" ):
                listener.enterOutput_paths(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitOutput_paths" ):
                listener.exitOutput_paths(self)




    def output_paths(self):

        localctx = PBXProjParser.Output_pathsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 350, self.RULE_output_paths)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1840
            self.match(PBXProjParser.OUTPUT_PATHS)
            self.state = 1841
            self.match(PBXProjParser.T__2)
            self.state = 1842
            self.any_string_list()
            self.state = 1843
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Shell_pathContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SHELL_PATH(self):
            return self.getToken(PBXProjParser.SHELL_PATH, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_shell_path

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterShell_path" ):
                listener.enterShell_path(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitShell_path" ):
                listener.exitShell_path(self)




    def shell_path(self):

        localctx = PBXProjParser.Shell_pathContext(self, self._ctx, self.state)
        self.enterRule(localctx, 352, self.RULE_shell_path)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1845
            self.match(PBXProjParser.SHELL_PATH)
            self.state = 1846
            self.match(PBXProjParser.T__2)
            self.state = 1847
            self.any_string()
            self.state = 1848
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ShellContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SHELL(self):
            return self.getToken(PBXProjParser.SHELL, 0)

        def QUOTED_STRING(self):
            return self.getToken(PBXProjParser.QUOTED_STRING, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_shell

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterShell" ):
                listener.enterShell(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitShell" ):
                listener.exitShell(self)




    def shell(self):

        localctx = PBXProjParser.ShellContext(self, self._ctx, self.state)
        self.enterRule(localctx, 354, self.RULE_shell)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1850
            self.match(PBXProjParser.SHELL)
            self.state = 1851
            self.match(PBXProjParser.T__2)
            self.state = 1852
            self.match(PBXProjParser.QUOTED_STRING)
            self.state = 1853
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Shell_scriptContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SHELL_SCRIPT(self):
            return self.getToken(PBXProjParser.SHELL_SCRIPT, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_shell_script

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterShell_script" ):
                listener.enterShell_script(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitShell_script" ):
                listener.exitShell_script(self)




    def shell_script(self):

        localctx = PBXProjParser.Shell_scriptContext(self, self._ctx, self.state)
        self.enterRule(localctx, 356, self.RULE_shell_script)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1855
            self.match(PBXProjParser.SHELL_SCRIPT)
            self.state = 1856
            self.match(PBXProjParser.T__2)
            self.state = 1857
            self.any_string()
            self.state = 1858
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Show_env_vars_in_logContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SHOW_ENV_VARS_IN_LOG(self):
            return self.getToken(PBXProjParser.SHOW_ENV_VARS_IN_LOG, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_show_env_vars_in_log

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterShow_env_vars_in_log" ):
                listener.enterShow_env_vars_in_log(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitShow_env_vars_in_log" ):
                listener.exitShow_env_vars_in_log(self)




    def show_env_vars_in_log(self):

        localctx = PBXProjParser.Show_env_vars_in_logContext(self, self._ctx, self.state)
        self.enterRule(localctx, 358, self.RULE_show_env_vars_in_log)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1860
            self.match(PBXProjParser.SHOW_ENV_VARS_IN_LOG)
            self.state = 1861
            self.match(PBXProjParser.T__2)
            self.state = 1862
            self.match(PBXProjParser.NUMBER)
            self.state = 1863
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class TargetContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def TARGET(self):
            return self.getToken(PBXProjParser.TARGET, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_target

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTarget" ):
                listener.enterTarget(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTarget" ):
                listener.exitTarget(self)




    def target(self):

        localctx = PBXProjParser.TargetContext(self, self._ctx, self.state)
        self.enterRule(localctx, 360, self.RULE_target)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1865
            self.match(PBXProjParser.TARGET)
            self.state = 1866
            self.match(PBXProjParser.T__2)
            self.state = 1867
            self.match(PBXProjParser.REFERENCE)
            self.state = 1868
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Target_proxyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def TARGET_PROXY(self):
            return self.getToken(PBXProjParser.TARGET_PROXY, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_target_proxy

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterTarget_proxy" ):
                listener.enterTarget_proxy(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitTarget_proxy" ):
                listener.exitTarget_proxy(self)




    def target_proxy(self):

        localctx = PBXProjParser.Target_proxyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 362, self.RULE_target_proxy)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1870
            self.match(PBXProjParser.TARGET_PROXY)
            self.state = 1871
            self.match(PBXProjParser.T__2)
            self.state = 1872
            self.match(PBXProjParser.REFERENCE)
            self.state = 1873
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class File_typeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def FILE_TYPE(self):
            return self.getToken(PBXProjParser.FILE_TYPE, 0)

        def str_number_variable(self):
            return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_file_type

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterFile_type" ):
                listener.enterFile_type(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitFile_type" ):
                listener.exitFile_type(self)




    def file_type(self):

        localctx = PBXProjParser.File_typeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 364, self.RULE_file_type)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1875
            self.match(PBXProjParser.FILE_TYPE)
            self.state = 1876
            self.match(PBXProjParser.T__2)
            self.state = 1877
            self.str_number_variable()
            self.state = 1878
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Remote_refContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def REMOTE_REF(self):
            return self.getToken(PBXProjParser.REMOTE_REF, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_remote_ref

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRemote_ref" ):
                listener.enterRemote_ref(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRemote_ref" ):
                listener.exitRemote_ref(self)




    def remote_ref(self):

        localctx = PBXProjParser.Remote_refContext(self, self._ctx, self.state)
        self.enterRule(localctx, 366, self.RULE_remote_ref)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1880
            self.match(PBXProjParser.REMOTE_REF)
            self.state = 1881
            self.match(PBXProjParser.T__2)
            self.state = 1882
            self.match(PBXProjParser.REFERENCE)
            self.state = 1883
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Base_configuration_referenceContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BASE_CONFIGURATION_REFERENCE(self):
            return self.getToken(PBXProjParser.BASE_CONFIGURATION_REFERENCE, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_base_configuration_reference

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBase_configuration_reference" ):
                listener.enterBase_configuration_reference(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBase_configuration_reference" ):
                listener.exitBase_configuration_reference(self)




    def base_configuration_reference(self):

        localctx = PBXProjParser.Base_configuration_referenceContext(self, self._ctx, self.state)
        self.enterRule(localctx, 368, self.RULE_base_configuration_reference)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1885
            self.match(PBXProjParser.BASE_CONFIGURATION_REFERENCE)
            self.state = 1886
            self.match(PBXProjParser.T__2)
            self.state = 1887
            self.match(PBXProjParser.REFERENCE)
            self.state = 1888
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Build_settingsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BUILD_SETTINGS(self):
            return self.getToken(PBXProjParser.BUILD_SETTINGS, 0)

        def key_value(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Key_valueContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Key_valueContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_build_settings

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBuild_settings" ):
                listener.enterBuild_settings(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBuild_settings" ):
                listener.exitBuild_settings(self)




    def build_settings(self):

        localctx = PBXProjParser.Build_settingsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 370, self.RULE_build_settings)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1890
            self.match(PBXProjParser.BUILD_SETTINGS)
            self.state = 1891
            self.match(PBXProjParser.T__2)
            self.state = 1892
            self.match(PBXProjParser.T__0)
            self.state = 1896
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & -141015588143360) != 0) or ((((_la - 64)) & ~0x3f) == 0 and ((1 << (_la - 64)) & -1) != 0) or ((((_la - 128)) & ~0x3f) == 0 and ((1 << (_la - 128)) & 4026523647) != 0):
                self.state = 1893
                self.key_value()
                self.state = 1898
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 1899
            self.match(PBXProjParser.T__1)
            self.state = 1900
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Build_stylesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BUILD_STYLES(self):
            return self.getToken(PBXProjParser.BUILD_STYLES, 0)

        def reference_list(self):
            return self.getTypedRuleContext(PBXProjParser.Reference_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_build_styles

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBuild_styles" ):
                listener.enterBuild_styles(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBuild_styles" ):
                listener.exitBuild_styles(self)




    def build_styles(self):

        localctx = PBXProjParser.Build_stylesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 372, self.RULE_build_styles)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1902
            self.match(PBXProjParser.BUILD_STYLES)
            self.state = 1903
            self.match(PBXProjParser.T__2)
            self.state = 1904
            self.reference_list()
            self.state = 1905
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dst_pathContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DST_PATH(self):
            return self.getToken(PBXProjParser.DST_PATH, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_dst_path

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDst_path" ):
                listener.enterDst_path(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDst_path" ):
                listener.exitDst_path(self)




    def dst_path(self):

        localctx = PBXProjParser.Dst_pathContext(self, self._ctx, self.state)
        self.enterRule(localctx, 374, self.RULE_dst_path)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1907
            self.match(PBXProjParser.DST_PATH)
            self.state = 1908
            self.match(PBXProjParser.T__2)
            self.state = 1909
            self.any_string()
            self.state = 1910
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Dst_subfolder_specContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DST_SUBFOLDER_SPEC(self):
            return self.getToken(PBXProjParser.DST_SUBFOLDER_SPEC, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_dst_subfolder_spec

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDst_subfolder_spec" ):
                listener.enterDst_subfolder_spec(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDst_subfolder_spec" ):
                listener.exitDst_subfolder_spec(self)




    def dst_subfolder_spec(self):

        localctx = PBXProjParser.Dst_subfolder_specContext(self, self._ctx, self.state)
        self.enterRule(localctx, 376, self.RULE_dst_subfolder_spec)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1912
            self.match(PBXProjParser.DST_SUBFOLDER_SPEC)
            self.state = 1913
            self.match(PBXProjParser.T__2)
            self.state = 1914
            self.match(PBXProjParser.NUMBER)
            self.state = 1915
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Project_references_listContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def project_references_list_element(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Project_references_list_elementContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Project_references_list_elementContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_project_references_list

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProject_references_list" ):
                listener.enterProject_references_list(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProject_references_list" ):
                listener.exitProject_references_list(self)




    def project_references_list(self):

        localctx = PBXProjParser.Project_references_listContext(self, self._ctx, self.state)
        self.enterRule(localctx, 378, self.RULE_project_references_list)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1920
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==1:
                self.state = 1917
                self.project_references_list_element()
                self.state = 1922
                self._errHandler.sync(self)
                _la = self._input.LA(1)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Project_references_list_elementContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def PRODUCT_GROUP(self):
            return self.getToken(PBXProjParser.PRODUCT_GROUP, 0)

        def REFERENCE(self, i:int=None):
            if i is None:
                return self.getTokens(PBXProjParser.REFERENCE)
            else:
                return self.getToken(PBXProjParser.REFERENCE, i)

        def PROJECT_REF(self):
            return self.getToken(PBXProjParser.PROJECT_REF, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_project_references_list_element

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterProject_references_list_element" ):
                listener.enterProject_references_list_element(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitProject_references_list_element" ):
                listener.exitProject_references_list_element(self)




    def project_references_list_element(self):

        localctx = PBXProjParser.Project_references_list_elementContext(self, self._ctx, self.state)
        self.enterRule(localctx, 380, self.RULE_project_references_list_element)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1923
            self.match(PBXProjParser.T__0)
            self.state = 1924
            self.match(PBXProjParser.PRODUCT_GROUP)
            self.state = 1925
            self.match(PBXProjParser.T__2)
            self.state = 1926
            self.match(PBXProjParser.REFERENCE)
            self.state = 1927
            self.match(PBXProjParser.T__3)
            self.state = 1928
            self.match(PBXProjParser.PROJECT_REF)
            self.state = 1929
            self.match(PBXProjParser.T__2)
            self.state = 1930
            self.match(PBXProjParser.REFERENCE)
            self.state = 1931
            self.match(PBXProjParser.T__3)
            self.state = 1932
            self.match(PBXProjParser.T__1)
            self.state = 1933
            self.match(PBXProjParser.T__5)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Membership_exceptionsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def MEMBERSHIP_EXCEPTIONS(self):
            return self.getToken(PBXProjParser.MEMBERSHIP_EXCEPTIONS, 0)

        def any_string_list(self):
            return self.getTypedRuleContext(PBXProjParser.Any_string_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_membership_exceptions

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterMembership_exceptions" ):
                listener.enterMembership_exceptions(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitMembership_exceptions" ):
                listener.exitMembership_exceptions(self)




    def membership_exceptions(self):

        localctx = PBXProjParser.Membership_exceptionsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 382, self.RULE_membership_exceptions)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1935
            self.match(PBXProjParser.MEMBERSHIP_EXCEPTIONS)
            self.state = 1936
            self.match(PBXProjParser.T__2)
            self.state = 1937
            self.any_string_list()
            self.state = 1938
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class ExceptionsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EXCEPTIONS(self):
            return self.getToken(PBXProjParser.EXCEPTIONS, 0)

        def reference_list(self):
            return self.getTypedRuleContext(PBXProjParser.Reference_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_exceptions

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterExceptions" ):
                listener.enterExceptions(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitExceptions" ):
                listener.exitExceptions(self)




    def exceptions(self):

        localctx = PBXProjParser.ExceptionsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 384, self.RULE_exceptions)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1940
            self.match(PBXProjParser.EXCEPTIONS)
            self.state = 1941
            self.match(PBXProjParser.T__2)
            self.state = 1942
            self.reference_list()
            self.state = 1943
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Key_valueContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def str_number_variable(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Str_number_variableContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,i)


        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def ALPHA_NUMERIC(self):
            return self.getToken(PBXProjParser.ALPHA_NUMERIC, 0)

        def key_value(self):
            return self.getTypedRuleContext(PBXProjParser.Key_valueContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_key_value

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterKey_value" ):
                listener.enterKey_value(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitKey_value" ):
                listener.exitKey_value(self)




    def key_value(self):

        localctx = PBXProjParser.Key_valueContext(self, self._ctx, self.state)
        self.enterRule(localctx, 386, self.RULE_key_value)
        self._la = 0 # Token type
        try:
            self.state = 1986
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,157,self._ctx)
            if la_ == 1:
                self.enterOuterAlt(localctx, 1)
                self.state = 1945
                self.str_number_variable()
                self.state = 1946
                self.match(PBXProjParser.T__2)
                self.state = 1947
                self.str_number_variable()
                self.state = 1948
                self.match(PBXProjParser.T__3)
                pass

            elif la_ == 2:
                self.enterOuterAlt(localctx, 2)
                self.state = 1950
                self.str_number_variable()
                self.state = 1951
                self.match(PBXProjParser.T__2)
                self.state = 1952
                self.match(PBXProjParser.NUMBER)
                self.state = 1953
                self.match(PBXProjParser.T__3)
                pass

            elif la_ == 3:
                self.enterOuterAlt(localctx, 3)
                self.state = 1955
                self.str_number_variable()
                self.state = 1956
                self.match(PBXProjParser.T__2)
                self.state = 1957
                self.match(PBXProjParser.ALPHA_NUMERIC)
                self.state = 1958
                self.match(PBXProjParser.T__3)
                pass

            elif la_ == 4:
                self.enterOuterAlt(localctx, 4)
                self.state = 1960
                self.str_number_variable()
                self.state = 1961
                self.match(PBXProjParser.T__2)
                self.state = 1962
                self.match(PBXProjParser.T__0)
                self.state = 1963
                self.key_value()
                self.state = 1964
                self.match(PBXProjParser.T__1)
                self.state = 1965
                self.match(PBXProjParser.T__3)
                pass

            elif la_ == 5:
                self.enterOuterAlt(localctx, 5)
                self.state = 1967
                self.str_number_variable()
                self.state = 1968
                self.match(PBXProjParser.T__2)
                self.state = 1969
                self.match(PBXProjParser.T__4)
                self.state = 1971
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if (((_la) & ~0x3f) == 0 and ((1 << _la) & -141015588143360) != 0) or ((((_la - 64)) & ~0x3f) == 0 and ((1 << (_la - 64)) & -1) != 0) or ((((_la - 128)) & ~0x3f) == 0 and ((1 << (_la - 128)) & 4026523647) != 0):
                    self.state = 1970
                    self.str_number_variable()


                self.state = 1977
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,155,self._ctx)
                while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                    if _alt==1:
                        self.state = 1973
                        self.match(PBXProjParser.T__5)
                        self.state = 1974
                        self.str_number_variable() 
                    self.state = 1979
                    self._errHandler.sync(self)
                    _alt = self._interp.adaptivePredict(self._input,155,self._ctx)

                self.state = 1981
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if _la==6:
                    self.state = 1980
                    self.match(PBXProjParser.T__5)


                self.state = 1983
                self.match(PBXProjParser.T__6)
                self.state = 1984
                self.match(PBXProjParser.T__3)
                pass


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Build_configurationsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def BUILD_CONFIGURATIONS(self):
            return self.getToken(PBXProjParser.BUILD_CONFIGURATIONS, 0)

        def reference_list(self):
            return self.getTypedRuleContext(PBXProjParser.Reference_listContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_build_configurations

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBuild_configurations" ):
                listener.enterBuild_configurations(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBuild_configurations" ):
                listener.exitBuild_configurations(self)




    def build_configurations(self):

        localctx = PBXProjParser.Build_configurationsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 388, self.RULE_build_configurations)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1988
            self.match(PBXProjParser.BUILD_CONFIGURATIONS)
            self.state = 1989
            self.match(PBXProjParser.T__2)
            self.state = 1990
            self.reference_list()
            self.state = 1991
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Default_configuration_is_visibleContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DEFAULT_CONFIGURATION_IS_VISIBLE(self):
            return self.getToken(PBXProjParser.DEFAULT_CONFIGURATION_IS_VISIBLE, 0)

        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_default_configuration_is_visible

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDefault_configuration_is_visible" ):
                listener.enterDefault_configuration_is_visible(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDefault_configuration_is_visible" ):
                listener.exitDefault_configuration_is_visible(self)




    def default_configuration_is_visible(self):

        localctx = PBXProjParser.Default_configuration_is_visibleContext(self, self._ctx, self.state)
        self.enterRule(localctx, 390, self.RULE_default_configuration_is_visible)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1993
            self.match(PBXProjParser.DEFAULT_CONFIGURATION_IS_VISIBLE)
            self.state = 1994
            self.match(PBXProjParser.T__2)
            self.state = 1995
            self.match(PBXProjParser.NUMBER)
            self.state = 1996
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Default_configuration_nameContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def DEFAULT_CONFIGURATION_NAME(self):
            return self.getToken(PBXProjParser.DEFAULT_CONFIGURATION_NAME, 0)

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_default_configuration_name

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterDefault_configuration_name" ):
                listener.enterDefault_configuration_name(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitDefault_configuration_name" ):
                listener.exitDefault_configuration_name(self)




    def default_configuration_name(self):

        localctx = PBXProjParser.Default_configuration_nameContext(self, self._ctx, self.state)
        self.enterRule(localctx, 392, self.RULE_default_configuration_name)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 1998
            self.match(PBXProjParser.DEFAULT_CONFIGURATION_NAME)
            self.state = 1999
            self.match(PBXProjParser.T__2)
            self.state = 2000
            self.any_string()
            self.state = 2001
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class SettingsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SETTINGS(self):
            return self.getToken(PBXProjParser.SETTINGS, 0)

        def key_value(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Key_valueContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Key_valueContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_settings

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSettings" ):
                listener.enterSettings(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSettings" ):
                listener.exitSettings(self)




    def settings(self):

        localctx = PBXProjParser.SettingsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 394, self.RULE_settings)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2003
            self.match(PBXProjParser.SETTINGS)
            self.state = 2004
            self.match(PBXProjParser.T__2)
            self.state = 2005
            self.match(PBXProjParser.T__0)
            self.state = 2009
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & -141015588143360) != 0) or ((((_la - 64)) & ~0x3f) == 0 and ((1 << (_la - 64)) & -1) != 0) or ((((_la - 128)) & ~0x3f) == 0 and ((1 << (_la - 128)) & 4026523647) != 0):
                self.state = 2006
                self.key_value()
                self.state = 2011
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 2012
            self.match(PBXProjParser.T__1)
            self.state = 2013
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class System_capabilitiesContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def SYSTEM_CAPABILITIES(self):
            return self.getToken(PBXProjParser.SYSTEM_CAPABILITIES, 0)

        def key_value(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(PBXProjParser.Key_valueContext)
            else:
                return self.getTypedRuleContext(PBXProjParser.Key_valueContext,i)


        def getRuleIndex(self):
            return PBXProjParser.RULE_system_capabilities

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSystem_capabilities" ):
                listener.enterSystem_capabilities(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSystem_capabilities" ):
                listener.exitSystem_capabilities(self)




    def system_capabilities(self):

        localctx = PBXProjParser.System_capabilitiesContext(self, self._ctx, self.state)
        self.enterRule(localctx, 396, self.RULE_system_capabilities)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2015
            self.match(PBXProjParser.SYSTEM_CAPABILITIES)
            self.state = 2016
            self.match(PBXProjParser.T__2)
            self.state = 2017
            self.match(PBXProjParser.T__0)
            self.state = 2021
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & -141015588143360) != 0) or ((((_la - 64)) & ~0x3f) == 0 and ((1 << (_la - 64)) & -1) != 0) or ((((_la - 128)) & ~0x3f) == 0 and ((1 << (_la - 128)) & 4026523647) != 0):
                self.state = 2018
                self.key_value()
                self.state = 2023
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 2024
            self.match(PBXProjParser.T__1)
            self.state = 2025
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Current_versionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CURRENT_VERSION(self):
            return self.getToken(PBXProjParser.CURRENT_VERSION, 0)

        def REFERENCE(self):
            return self.getToken(PBXProjParser.REFERENCE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_current_version

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCurrent_version" ):
                listener.enterCurrent_version(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCurrent_version" ):
                listener.exitCurrent_version(self)




    def current_version(self):

        localctx = PBXProjParser.Current_versionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 398, self.RULE_current_version)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2027
            self.match(PBXProjParser.CURRENT_VERSION)
            self.state = 2028
            self.match(PBXProjParser.T__2)
            self.state = 2029
            self.match(PBXProjParser.REFERENCE)
            self.state = 2030
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Version_group_typeContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def VERSION_GROUP_TYPE(self):
            return self.getToken(PBXProjParser.VERSION_GROUP_TYPE, 0)

        def NON_QUOTED_STRING(self):
            return self.getToken(PBXProjParser.NON_QUOTED_STRING, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_version_group_type

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterVersion_group_type" ):
                listener.enterVersion_group_type(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitVersion_group_type" ):
                listener.exitVersion_group_type(self)




    def version_group_type(self):

        localctx = PBXProjParser.Version_group_typeContext(self, self._ctx, self.state)
        self.enterRule(localctx, 400, self.RULE_version_group_type)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2032
            self.match(PBXProjParser.VERSION_GROUP_TYPE)
            self.state = 2033
            self.match(PBXProjParser.T__2)
            self.state = 2034
            self.match(PBXProjParser.NON_QUOTED_STRING)
            self.state = 2035
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Class_prefixContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def CLASSPREFIX(self):
            return self.getToken(PBXProjParser.CLASSPREFIX, 0)

        def str_number_variable(self):
            return self.getTypedRuleContext(PBXProjParser.Str_number_variableContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_class_prefix

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterClass_prefix" ):
                listener.enterClass_prefix(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitClass_prefix" ):
                listener.exitClass_prefix(self)




    def class_prefix(self):

        localctx = PBXProjParser.Class_prefixContext(self, self._ctx, self.state)
        self.enterRule(localctx, 402, self.RULE_class_prefix)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2037
            self.match(PBXProjParser.CLASSPREFIX)
            self.state = 2038
            self.match(PBXProjParser.T__2)
            self.state = 2039
            self.str_number_variable()
            self.state = 2040
            self.match(PBXProjParser.T__3)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Any_stringContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def NON_QUOTED_STRING(self):
            return self.getToken(PBXProjParser.NON_QUOTED_STRING, 0)

        def QUOTED_STRING(self):
            return self.getToken(PBXProjParser.QUOTED_STRING, 0)

        def UNDERSCORE(self):
            return self.getToken(PBXProjParser.UNDERSCORE, 0)

        def DASH(self):
            return self.getToken(PBXProjParser.DASH, 0)

        def DOT(self):
            return self.getToken(PBXProjParser.DOT, 0)

        def any_token(self):
            return self.getTypedRuleContext(PBXProjParser.Any_tokenContext,0)


        def getRuleIndex(self):
            return PBXProjParser.RULE_any_string

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAny_string" ):
                listener.enterAny_string(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAny_string" ):
                listener.exitAny_string(self)




    def any_string(self):

        localctx = PBXProjParser.Any_stringContext(self, self._ctx, self.state)
        self.enterRule(localctx, 404, self.RULE_any_string)
        try:
            self.state = 2048
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [158]:
                self.enterOuterAlt(localctx, 1)
                self.state = 2042
                self.match(PBXProjParser.NON_QUOTED_STRING)
                pass
            elif token in [157]:
                self.enterOuterAlt(localctx, 2)
                self.state = 2043
                self.match(PBXProjParser.QUOTED_STRING)
                pass
            elif token in [18]:
                self.enterOuterAlt(localctx, 3)
                self.state = 2044
                self.match(PBXProjParser.UNDERSCORE)
                pass
            elif token in [10]:
                self.enterOuterAlt(localctx, 4)
                self.state = 2045
                self.match(PBXProjParser.DASH)
                pass
            elif token in [11]:
                self.enterOuterAlt(localctx, 5)
                self.state = 2046
                self.match(PBXProjParser.DOT)
                pass
            elif token in [8, 9, 12, 14, 15, 16, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 32, 33, 34, 35, 36, 37, 39, 40, 41, 42, 43, 44, 45, 46, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155]:
                self.enterOuterAlt(localctx, 6)
                self.state = 2047
                self.any_token()
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Str_number_variableContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def any_string(self):
            return self.getTypedRuleContext(PBXProjParser.Any_stringContext,0)


        def NUMBER(self):
            return self.getToken(PBXProjParser.NUMBER, 0)

        def VARIABLE(self):
            return self.getToken(PBXProjParser.VARIABLE, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_str_number_variable

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterStr_number_variable" ):
                listener.enterStr_number_variable(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitStr_number_variable" ):
                listener.exitStr_number_variable(self)




    def str_number_variable(self):

        localctx = PBXProjParser.Str_number_variableContext(self, self._ctx, self.state)
        self.enterRule(localctx, 406, self.RULE_str_number_variable)
        try:
            self.state = 2053
            self._errHandler.sync(self)
            token = self._input.LA(1)
            if token in [8, 9, 10, 11, 12, 14, 15, 16, 18, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 32, 33, 34, 35, 36, 37, 39, 40, 41, 42, 43, 44, 45, 46, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 157, 158]:
                self.enterOuterAlt(localctx, 1)
                self.state = 2050
                self.any_string()
                pass
            elif token in [13]:
                self.enterOuterAlt(localctx, 2)
                self.state = 2051
                self.match(PBXProjParser.NUMBER)
                pass
            elif token in [159]:
                self.enterOuterAlt(localctx, 3)
                self.state = 2052
                self.match(PBXProjParser.VARIABLE)
                pass
            else:
                raise NoViableAltException(self)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Any_tokenContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def ARCHIVE_VERSION(self):
            return self.getToken(PBXProjParser.ARCHIVE_VERSION, 0)

        def CLASSES(self):
            return self.getToken(PBXProjParser.CLASSES, 0)

        def ISA(self):
            return self.getToken(PBXProjParser.ISA, 0)

        def OBJECT_VERSION(self):
            return self.getToken(PBXProjParser.OBJECT_VERSION, 0)

        def OBJECTS(self):
            return self.getToken(PBXProjParser.OBJECTS, 0)

        def ROOT_OBJECT(self):
            return self.getToken(PBXProjParser.ROOT_OBJECT, 0)

        def PBX_AGGREGATE_TARGET(self):
            return self.getToken(PBXProjParser.PBX_AGGREGATE_TARGET, 0)

        def PBX_BUILD_FILE(self):
            return self.getToken(PBXProjParser.PBX_BUILD_FILE, 0)

        def PBX_BUILD_RULE(self):
            return self.getToken(PBXProjParser.PBX_BUILD_RULE, 0)

        def PBX_BUILD_STYLE(self):
            return self.getToken(PBXProjParser.PBX_BUILD_STYLE, 0)

        def PBX_CONTAINER_ITEM_PROXY(self):
            return self.getToken(PBXProjParser.PBX_CONTAINER_ITEM_PROXY, 0)

        def PBX_COPY_FILES_BUILD_PHASE(self):
            return self.getToken(PBXProjParser.PBX_COPY_FILES_BUILD_PHASE, 0)

        def PBX_FILE_REFERENCE(self):
            return self.getToken(PBXProjParser.PBX_FILE_REFERENCE, 0)

        def PBX_FILE_SYSTEM_SYNCHRONIZED_BUILD_FILE_EXCEPTION_SET(self):
            return self.getToken(PBXProjParser.PBX_FILE_SYSTEM_SYNCHRONIZED_BUILD_FILE_EXCEPTION_SET, 0)

        def PBX_FILE_SYSTEM_SYNCHRONIZED_ROOT_GROUP(self):
            return self.getToken(PBXProjParser.PBX_FILE_SYSTEM_SYNCHRONIZED_ROOT_GROUP, 0)

        def PBX_FRAMEWORKS_BUILD_PHASE(self):
            return self.getToken(PBXProjParser.PBX_FRAMEWORKS_BUILD_PHASE, 0)

        def PBX_NATIVE_TARGET(self):
            return self.getToken(PBXProjParser.PBX_NATIVE_TARGET, 0)

        def PBX_LEGACY_TARGET(self):
            return self.getToken(PBXProjParser.PBX_LEGACY_TARGET, 0)

        def PBX_PROJECT(self):
            return self.getToken(PBXProjParser.PBX_PROJECT, 0)

        def PBX_REFERENCE_PROXY(self):
            return self.getToken(PBXProjParser.PBX_REFERENCE_PROXY, 0)

        def PBX_RESOURCES_BUILD_PHASE(self):
            return self.getToken(PBXProjParser.PBX_RESOURCES_BUILD_PHASE, 0)

        def PBX_SHELL_SCRIPT_BUILD_PHASE(self):
            return self.getToken(PBXProjParser.PBX_SHELL_SCRIPT_BUILD_PHASE, 0)

        def PBX_SOURCES_BUILD_PHASE(self):
            return self.getToken(PBXProjParser.PBX_SOURCES_BUILD_PHASE, 0)

        def PBX_TARGET_DEPENDENCY(self):
            return self.getToken(PBXProjParser.PBX_TARGET_DEPENDENCY, 0)

        def PBX_VARIANT_GROUP(self):
            return self.getToken(PBXProjParser.PBX_VARIANT_GROUP, 0)

        def PREFERRED_PROJECT_OBJECT_VERSION(self):
            return self.getToken(PBXProjParser.PREFERRED_PROJECT_OBJECT_VERSION, 0)

        def XC_BUILD_CONFIGURATION(self):
            return self.getToken(PBXProjParser.XC_BUILD_CONFIGURATION, 0)

        def XC_CONFIGURATION_LIST(self):
            return self.getToken(PBXProjParser.XC_CONFIGURATION_LIST, 0)

        def XC_REMOTE_SWIFT_PACKAGE_REFERENCE(self):
            return self.getToken(PBXProjParser.XC_REMOTE_SWIFT_PACKAGE_REFERENCE, 0)

        def XC_SWIFT_PACKAGE_PRODUCT_DEPENDENCY(self):
            return self.getToken(PBXProjParser.XC_SWIFT_PACKAGE_PRODUCT_DEPENDENCY, 0)

        def XC_VERSION_GROUP(self):
            return self.getToken(PBXProjParser.XC_VERSION_GROUP, 0)

        def FILE_REF(self):
            return self.getToken(PBXProjParser.FILE_REF, 0)

        def PRODUCT_REF(self):
            return self.getToken(PBXProjParser.PRODUCT_REF, 0)

        def CONTAINER_PORTAL(self):
            return self.getToken(PBXProjParser.CONTAINER_PORTAL, 0)

        def PROXY_TYPE(self):
            return self.getToken(PBXProjParser.PROXY_TYPE, 0)

        def REMOTE_GLOBAL_ID_STRING(self):
            return self.getToken(PBXProjParser.REMOTE_GLOBAL_ID_STRING, 0)

        def REMOTE_INFO(self):
            return self.getToken(PBXProjParser.REMOTE_INFO, 0)

        def FILE_ENCODING(self):
            return self.getToken(PBXProjParser.FILE_ENCODING, 0)

        def COMMENTS(self):
            return self.getToken(PBXProjParser.COMMENTS, 0)

        def EXPLICIT_FILE_TYPE(self):
            return self.getToken(PBXProjParser.EXPLICIT_FILE_TYPE, 0)

        def EXPLICIT_FILE_TYPES(self):
            return self.getToken(PBXProjParser.EXPLICIT_FILE_TYPES, 0)

        def EXPLICIT_FOLDERS(self):
            return self.getToken(PBXProjParser.EXPLICIT_FOLDERS, 0)

        def LAST_KNOWN_FILE_TYPE(self):
            return self.getToken(PBXProjParser.LAST_KNOWN_FILE_TYPE, 0)

        def INCLUDE_IN_INDEX(self):
            return self.getToken(PBXProjParser.INCLUDE_IN_INDEX, 0)

        def INDENT_WIDTH(self):
            return self.getToken(PBXProjParser.INDENT_WIDTH, 0)

        def TAB_WIDTH(self):
            return self.getToken(PBXProjParser.TAB_WIDTH, 0)

        def USES_TABS(self):
            return self.getToken(PBXProjParser.USES_TABS, 0)

        def WRAPS_LINES(self):
            return self.getToken(PBXProjParser.WRAPS_LINES, 0)

        def PLATFORM_FILTER(self):
            return self.getToken(PBXProjParser.PLATFORM_FILTER, 0)

        def PLATFORM_FILTERS(self):
            return self.getToken(PBXProjParser.PLATFORM_FILTERS, 0)

        def CHILDREN(self):
            return self.getToken(PBXProjParser.CHILDREN, 0)

        def PRODUCT_INSTALL_PATH(self):
            return self.getToken(PBXProjParser.PRODUCT_INSTALL_PATH, 0)

        def REPOSITORY_URL(self):
            return self.getToken(PBXProjParser.REPOSITORY_URL, 0)

        def REQUIREMENT(self):
            return self.getToken(PBXProjParser.REQUIREMENT, 0)

        def PACKAGE(self):
            return self.getToken(PBXProjParser.PACKAGE, 0)

        def PACKAGE_PRODUCT_DEPENDENCIES(self):
            return self.getToken(PBXProjParser.PACKAGE_PRODUCT_DEPENDENCIES, 0)

        def NAME(self):
            return self.getToken(PBXProjParser.NAME, 0)

        def PATH(self):
            return self.getToken(PBXProjParser.PATH, 0)

        def SOURCE_TREE(self):
            return self.getToken(PBXProjParser.SOURCE_TREE, 0)

        def BUILD_ACTION_MASK(self):
            return self.getToken(PBXProjParser.BUILD_ACTION_MASK, 0)

        def FILES(self):
            return self.getToken(PBXProjParser.FILES, 0)

        def RUN_ONLY_FOR_DEPLOYMENT_POSTPROCESSING(self):
            return self.getToken(PBXProjParser.RUN_ONLY_FOR_DEPLOYMENT_POSTPROCESSING, 0)

        def BUILD_CONFIGURATION_LIST(self):
            return self.getToken(PBXProjParser.BUILD_CONFIGURATION_LIST, 0)

        def BUILD_PHASES(self):
            return self.getToken(PBXProjParser.BUILD_PHASES, 0)

        def BUILD_RULES(self):
            return self.getToken(PBXProjParser.BUILD_RULES, 0)

        def BUILD_ARGUMENTS_STRING(self):
            return self.getToken(PBXProjParser.BUILD_ARGUMENTS_STRING, 0)

        def BUILD_TOOL_PATH(self):
            return self.getToken(PBXProjParser.BUILD_TOOL_PATH, 0)

        def BUILD_WORKING_DIRECTORY(self):
            return self.getToken(PBXProjParser.BUILD_WORKING_DIRECTORY, 0)

        def PASS_BUILD_SETTINGS_IN_ENVIRONMENT(self):
            return self.getToken(PBXProjParser.PASS_BUILD_SETTINGS_IN_ENVIRONMENT, 0)

        def DEPENDENCIES(self):
            return self.getToken(PBXProjParser.DEPENDENCIES, 0)

        def PRODUCT_NAME(self):
            return self.getToken(PBXProjParser.PRODUCT_NAME, 0)

        def PRODUCT_REFERENCE(self):
            return self.getToken(PBXProjParser.PRODUCT_REFERENCE, 0)

        def PRODUCT_TYPE(self):
            return self.getToken(PBXProjParser.PRODUCT_TYPE, 0)

        def LINE_ENDING(self):
            return self.getToken(PBXProjParser.LINE_ENDING, 0)

        def XC_LANGUAGE_SPECIFICATION_IDENTIFIER(self):
            return self.getToken(PBXProjParser.XC_LANGUAGE_SPECIFICATION_IDENTIFIER, 0)

        def PLIST_STRUCTURE_DEFINITION_IDENTIFIER(self):
            return self.getToken(PBXProjParser.PLIST_STRUCTURE_DEFINITION_IDENTIFIER, 0)

        def REF_TYPE(self):
            return self.getToken(PBXProjParser.REF_TYPE, 0)

        def COMPILER_SPEC(self):
            return self.getToken(PBXProjParser.COMPILER_SPEC, 0)

        def FILE_PATTERNS(self):
            return self.getToken(PBXProjParser.FILE_PATTERNS, 0)

        def INPUT_FILES(self):
            return self.getToken(PBXProjParser.INPUT_FILES, 0)

        def IS_EDITABLE(self):
            return self.getToken(PBXProjParser.IS_EDITABLE, 0)

        def OUTPUT_FILES(self):
            return self.getToken(PBXProjParser.OUTPUT_FILES, 0)

        def RUN_ONCE_PER_ARCH(self):
            return self.getToken(PBXProjParser.RUN_ONCE_PER_ARCH, 0)

        def SCRIPT(self):
            return self.getToken(PBXProjParser.SCRIPT, 0)

        def ATTRIBUTES(self):
            return self.getToken(PBXProjParser.ATTRIBUTES, 0)

        def LAST_SWIFT_MIGRATION(self):
            return self.getToken(PBXProjParser.LAST_SWIFT_MIGRATION, 0)

        def DEFAULT_BUILD_SYSTEM_TYPE_FOR_WORKSPACE(self):
            return self.getToken(PBXProjParser.DEFAULT_BUILD_SYSTEM_TYPE_FOR_WORKSPACE, 0)

        def LAST_SWIFT_UPDATE_CHECK(self):
            return self.getToken(PBXProjParser.LAST_SWIFT_UPDATE_CHECK, 0)

        def BUILD_INDEPENDENT_TARGETS_IN_PARALLEL(self):
            return self.getToken(PBXProjParser.BUILD_INDEPENDENT_TARGETS_IN_PARALLEL, 0)

        def LAST_TESTING_UPGRADE_CHECK(self):
            return self.getToken(PBXProjParser.LAST_TESTING_UPGRADE_CHECK, 0)

        def LAST_UPGRADE_CHECK(self):
            return self.getToken(PBXProjParser.LAST_UPGRADE_CHECK, 0)

        def ORGANIZATION_NAME(self):
            return self.getToken(PBXProjParser.ORGANIZATION_NAME, 0)

        def TARGET_ATTRIBUTES(self):
            return self.getToken(PBXProjParser.TARGET_ATTRIBUTES, 0)

        def CREATED_ON_TOOLS_VERSION(self):
            return self.getToken(PBXProjParser.CREATED_ON_TOOLS_VERSION, 0)

        def TEST_TARGET_ID(self):
            return self.getToken(PBXProjParser.TEST_TARGET_ID, 0)

        def DEVELOPMENT_TEAM(self):
            return self.getToken(PBXProjParser.DEVELOPMENT_TEAM, 0)

        def DEVELOPMENT_TEAM_NAME(self):
            return self.getToken(PBXProjParser.DEVELOPMENT_TEAM_NAME, 0)

        def PROVISIONING_STYLE(self):
            return self.getToken(PBXProjParser.PROVISIONING_STYLE, 0)

        def COMPATIBILITY_VERSION(self):
            return self.getToken(PBXProjParser.COMPATIBILITY_VERSION, 0)

        def DEVELOPMENT_REGION(self):
            return self.getToken(PBXProjParser.DEVELOPMENT_REGION, 0)

        def HAS_SCANNED_FOR_ENCODINGS(self):
            return self.getToken(PBXProjParser.HAS_SCANNED_FOR_ENCODINGS, 0)

        def KNOWN_REGIONS(self):
            return self.getToken(PBXProjParser.KNOWN_REGIONS, 0)

        def MAIN_GROUP(self):
            return self.getToken(PBXProjParser.MAIN_GROUP, 0)

        def PRODUCT_REF_GROUP(self):
            return self.getToken(PBXProjParser.PRODUCT_REF_GROUP, 0)

        def PACKAGE_REFERENCES(self):
            return self.getToken(PBXProjParser.PACKAGE_REFERENCES, 0)

        def PRODUCT_DIR_PATH(self):
            return self.getToken(PBXProjParser.PRODUCT_DIR_PATH, 0)

        def PROJECT_REFERENCES(self):
            return self.getToken(PBXProjParser.PROJECT_REFERENCES, 0)

        def PROJECT_ROOT(self):
            return self.getToken(PBXProjParser.PROJECT_ROOT, 0)

        def TARGETS(self):
            return self.getToken(PBXProjParser.TARGETS, 0)

        def INPUT_FILE_LIST_PATHS(self):
            return self.getToken(PBXProjParser.INPUT_FILE_LIST_PATHS, 0)

        def INPUT_PATHS(self):
            return self.getToken(PBXProjParser.INPUT_PATHS, 0)

        def OUTPUT_FILE_LIST_PATHS(self):
            return self.getToken(PBXProjParser.OUTPUT_FILE_LIST_PATHS, 0)

        def OUTPUT_PATHS(self):
            return self.getToken(PBXProjParser.OUTPUT_PATHS, 0)

        def SHELL_PATH(self):
            return self.getToken(PBXProjParser.SHELL_PATH, 0)

        def SHELL(self):
            return self.getToken(PBXProjParser.SHELL, 0)

        def SHELL_SCRIPT(self):
            return self.getToken(PBXProjParser.SHELL_SCRIPT, 0)

        def SHOW_ENV_VARS_IN_LOG(self):
            return self.getToken(PBXProjParser.SHOW_ENV_VARS_IN_LOG, 0)

        def TARGET(self):
            return self.getToken(PBXProjParser.TARGET, 0)

        def TARGET_PROXY(self):
            return self.getToken(PBXProjParser.TARGET_PROXY, 0)

        def FILE_TYPE(self):
            return self.getToken(PBXProjParser.FILE_TYPE, 0)

        def REMOTE_REF(self):
            return self.getToken(PBXProjParser.REMOTE_REF, 0)

        def BASE_CONFIGURATION_REFERENCE(self):
            return self.getToken(PBXProjParser.BASE_CONFIGURATION_REFERENCE, 0)

        def BUILD_SETTINGS(self):
            return self.getToken(PBXProjParser.BUILD_SETTINGS, 0)

        def DST_PATH(self):
            return self.getToken(PBXProjParser.DST_PATH, 0)

        def DST_SUBFOLDER_SPEC(self):
            return self.getToken(PBXProjParser.DST_SUBFOLDER_SPEC, 0)

        def PRODUCT_GROUP(self):
            return self.getToken(PBXProjParser.PRODUCT_GROUP, 0)

        def PROJECT_REF(self):
            return self.getToken(PBXProjParser.PROJECT_REF, 0)

        def BUILD_CONFIGURATIONS(self):
            return self.getToken(PBXProjParser.BUILD_CONFIGURATIONS, 0)

        def DEFAULT_CONFIGURATION_IS_VISIBLE(self):
            return self.getToken(PBXProjParser.DEFAULT_CONFIGURATION_IS_VISIBLE, 0)

        def DEFAULT_CONFIGURATION_NAME(self):
            return self.getToken(PBXProjParser.DEFAULT_CONFIGURATION_NAME, 0)

        def SETTINGS(self):
            return self.getToken(PBXProjParser.SETTINGS, 0)

        def SYSTEM_CAPABILITIES(self):
            return self.getToken(PBXProjParser.SYSTEM_CAPABILITIES, 0)

        def CURRENT_VERSION(self):
            return self.getToken(PBXProjParser.CURRENT_VERSION, 0)

        def VERSION_GROUP_TYPE(self):
            return self.getToken(PBXProjParser.VERSION_GROUP_TYPE, 0)

        def MEMBERSHIP_EXCEPTIONS(self):
            return self.getToken(PBXProjParser.MEMBERSHIP_EXCEPTIONS, 0)

        def EXCEPTIONS(self):
            return self.getToken(PBXProjParser.EXCEPTIONS, 0)

        def CLASSPREFIX(self):
            return self.getToken(PBXProjParser.CLASSPREFIX, 0)

        def getRuleIndex(self):
            return PBXProjParser.RULE_any_token

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAny_token" ):
                listener.enterAny_token(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAny_token" ):
                listener.exitAny_token(self)




    def any_token(self):

        localctx = PBXProjParser.Any_tokenContext(self, self._ctx, self.state)
        self.enterRule(localctx, 408, self.RULE_any_token)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 2055
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & -141015588416768) != 0) or ((((_la - 64)) & ~0x3f) == 0 and ((1 << (_la - 64)) & -1) != 0) or ((((_la - 128)) & ~0x3f) == 0 and ((1 << (_la - 128)) & 268427263) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx





